@@ -25,18 +25,18 @@
 */
 
 #include <config.h>
-#include "eel-background.h"
-#include "eel-gdk-extensions.h"
-#include "eel-glib-extensions.h"
-#include "eel-lib-self-check-functions.h"
 #include <gtk/gtk.h>
-#include <eel/eel-canvas.h>
 #include <cairo-xlib.h>
 #include <gdk/gdkx.h>
 #include <gio/gio.h>
 #include <math.h>
 #include <stdio.h>
-#include <libcaja-private/caja-global-preferences.h>
+
+#include "eel-background.h"
+#include "eel-gdk-extensions.h"
+#include "eel-glib-extensions.h"
+#include "eel-lib-self-check-functions.h"
+#include "eel-canvas.h"
 
 enum
 {
@@ -158,9 +158,9 @@ static void
 make_color_inactive (EelBackground *self,
                      GdkRGBA       *color)
 {
-    double intensity, saturation;
-
     if (!self->details->is_active) {
+        double intensity, saturation;
+
         saturation = 0.7;
         intensity = color->red * 0.30 + color->green * 0.59 + color->blue * 0.11;
         color->red = SATURATE (color->red);
@@ -191,7 +191,7 @@ eel_bg_get_desktop_color (EelBackground *self)
 {
     MateBGColorType type;
     GdkRGBA    primary, secondary;
-    char      *start_color, *end_color, *color_spec;
+    char      *start_color, *color_spec;
     gboolean   use_gradient = TRUE;
     gboolean   is_horizontal = FALSE;
 
@@ -214,6 +214,8 @@ eel_bg_get_desktop_color (EelBackground *self)
 
     if (use_gradient)
     {
+        char *end_color;
+
         end_color  = eel_gdk_rgb_to_color_spec (eel_gdk_rgba_to_rgb (&secondary));
         color_spec = eel_gradient_new (start_color, end_color, is_horizontal);
         g_free (end_color);
@@ -427,6 +429,7 @@ set_root_surface (EelBackground *self,
 static void
 init_fade (EelBackground *self)
 {
+    GSettings *mate_background_preferences;
     GtkWidget *widget = self->details->widget;
     gboolean do_fade;
 
@@ -434,8 +437,11 @@ init_fade (EelBackground *self)
         return;
     }
 
+    mate_background_preferences = g_settings_new ("org.mate.background");
     do_fade = g_settings_get_boolean (mate_background_preferences,
                                       MATE_BG_KEY_BACKGROUND_FADE);
+    g_object_unref (mate_background_preferences);
+
     if (!do_fade) {
     	return;
     }
@@ -661,7 +667,7 @@ widget_realize_cb (GtkWidget *widget,
 
     widget_realized_setup (widget, self);
 
-    eel_background_set_up_widget (self);    
+    eel_background_set_up_widget (self);
 }
 
 static void
