@@ -28,10 +28,6 @@
 
 #include <gdk/gdk.h>
 
-#ifndef GTK_CHECK_VERSION
-#include <gtk/gtk.h>
-#endif
-
 #define EEL_RGB_COLOR_RED	0xFF0000
 #define EEL_RGB_COLOR_GREEN	0x00FF00
 #define EEL_RGB_COLOR_BLUE	0x0000FF
