@@ -29,7 +29,7 @@
 #define EEL_GTK_EXTENSIONS_H
 
 #include <gtk/gtk.h>
-#include <eel/eel-gdk-extensions.h>
+#include "eel-gdk-extensions.h"
 
 /* GtkWindow */
 void                  eel_gtk_window_set_initial_geometry             (GtkWindow            *window,
@@ -73,4 +73,7 @@ GtkWidget *           eel_image_menu_item_new_from_icon               (const gch
 GtkWidget *           eel_image_menu_item_new_from_surface              (cairo_surface_t    *icon_surface,
                                                                          const gchar        *label_name);
 
+gboolean              eel_dialog_page_scroll_event_callback           (GtkWidget            *widget,
+                                                                       GdkEventScroll       *event,
+                                                                       GtkWindow            *window);
 #endif /* EEL_GTK_EXTENSIONS_H */
