@@ -363,7 +363,6 @@ eel_labeled_image_draw (GtkWidget *widget,
     EelLabeledImage *labeled_image;
     EelIRect label_bounds;
     GtkStyleContext *context;
-    GdkWindow *window;
 
     g_assert (EEL_IS_LABELED_IMAGE (widget));
     g_assert (gtk_widget_get_realized (widget));
@@ -373,7 +372,6 @@ eel_labeled_image_draw (GtkWidget *widget,
     context = gtk_widget_get_style_context (widget);
     gtk_style_context_save (context);
 
-    window = gtk_widget_get_window (widget);
     if (gtk_widget_get_state_flags (widget) == GTK_STATE_FLAG_SELECTED ||
             gtk_widget_get_state_flags (widget) == GTK_STATE_FLAG_ACTIVE)
     {
@@ -1050,11 +1048,11 @@ labeled_image_update_alignments (EelLabeledImage *labeled_image)
 
     if (labeled_image->details->label != NULL)
     {
-        float x_alignment;
-        float y_alignment;
-
         if (labeled_image->details->fill)
         {
+            float x_alignment;
+            float y_alignment;
+
             x_alignment = gtk_label_get_xalign (GTK_LABEL (labeled_image->details->label));
             y_alignment = gtk_label_get_yalign (GTK_LABEL (labeled_image->details->label));
 
@@ -1099,11 +1097,11 @@ labeled_image_update_alignments (EelLabeledImage *labeled_image)
 
     if (labeled_image->details->image != NULL)
     {
-        float x_alignment;
-        float y_alignment;
-
         if (labeled_image->details->fill)
         {
+            float x_alignment;
+            float y_alignment;
+
             x_alignment = gtk_widget_get_halign (labeled_image->details->image);
             y_alignment = gtk_widget_get_valign (labeled_image->details->image);
 
