@@ -42,7 +42,7 @@ enum
 };
 
 /* Detail member struct */
-struct EelWrapTableDetails
+struct EelWrapTablePrivate
 {
     guint x_spacing;
     guint y_spacing;
@@ -70,16 +70,14 @@ static gboolean      wrap_table_child_focus_in           (GtkWidget           *w
 static void          wrap_table_layout                   (EelWrapTable        *wrap_table);
 
 
-G_DEFINE_TYPE (EelWrapTable, eel_wrap_table, GTK_TYPE_CONTAINER)
+G_DEFINE_TYPE_WITH_PRIVATE (EelWrapTable, eel_wrap_table, GTK_TYPE_CONTAINER)
 
 static void
 eel_wrap_table_init (EelWrapTable *wrap_table)
 {
     gtk_widget_set_has_window (GTK_WIDGET (wrap_table), FALSE);
 
-    wrap_table->details = G_TYPE_INSTANCE_GET_PRIVATE (wrap_table,
-    						       EEL_TYPE_WRAP_TABLE,
-    						       EelWrapTableDetails);
+    wrap_table->details = eel_wrap_table_get_instance_private (wrap_table);
     wrap_table->details->x_justification = EEL_JUSTIFICATION_BEGINNING;
     wrap_table->details->y_justification = EEL_JUSTIFICATION_END;
     wrap_table->details->cols = 1;
@@ -485,7 +483,6 @@ eel_wrap_table_class_init (EelWrapTableClass *wrap_table_class)
      g_param_spec_boolean ("homogeneous", NULL, NULL,
                            FALSE, G_PARAM_READWRITE));
 
-    g_type_class_add_private (wrap_table_class, sizeof (EelWrapTableDetails));
 }
 
 /* Private EelWrapTable methods */
@@ -766,7 +763,6 @@ wrap_table_child_focus_in (GtkWidget *widget,
 {
     gint x, y;
     GtkWidget *container, *viewport = NULL;
-    GtkAdjustment *hadj, *vadj;
 
     container = gtk_widget_get_parent (widget);
     if (container)
@@ -779,6 +775,8 @@ wrap_table_child_focus_in (GtkWidget *widget,
 
     if (!wrap_table_child_visible_in (widget, viewport))
     {
+        GtkAdjustment *hadj, *vadj;
+
         hadj = gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (viewport));
         vadj = gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (viewport));
 
