@@ -147,6 +147,7 @@ received_clipboard_contents (GtkClipboard     *clipboard,
 
     action_group = data;
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (action_group,
                                           "Paste");
     if (action != NULL)
@@ -154,6 +155,7 @@ received_clipboard_contents (GtkClipboard     *clipboard,
         gtk_action_set_sensitive (action,
                                   gtk_selection_data_targets_include_text (selection_data));
     }
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     g_object_unref (action_group);
 }
@@ -162,7 +164,6 @@ received_clipboard_contents (GtkClipboard     *clipboard,
 static void
 set_paste_sensitive_if_clipboard_contains_data (GtkActionGroup *action_group)
 {
-    GtkAction *action;
     if (gdk_display_supports_selection_notification (gdk_display_get_default ()))
     {
         gtk_clipboard_request_contents (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD),
@@ -172,10 +173,14 @@ set_paste_sensitive_if_clipboard_contains_data (GtkActionGroup *action_group)
     }
     else
     {
+        GtkAction *action;
+
         /* If selection notification isn't supported, always activate Paste */
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
         action = gtk_action_group_get_action (action_group,
                                               "Paste");
         gtk_action_set_sensitive (action, TRUE);
+        G_GNUC_END_IGNORE_DEPRECATIONS;
     }
 }
 
@@ -184,12 +189,14 @@ set_clipboard_menu_items_sensitive (GtkActionGroup *action_group)
 {
     GtkAction *action;
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (action_group,
                                           "Cut");
     gtk_action_set_sensitive (action, TRUE);
     action = gtk_action_group_get_action (action_group,
                                           "Copy");
     gtk_action_set_sensitive (action, TRUE);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 static void
@@ -197,12 +204,14 @@ set_clipboard_menu_items_insensitive (GtkActionGroup *action_group)
 {
     GtkAction *action;
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (action_group,
                                           "Cut");
     gtk_action_set_sensitive (action, FALSE);
     action = gtk_action_group_get_action (action_group,
                                           "Copy");
     gtk_action_set_sensitive (action, FALSE);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 static gboolean
@@ -451,22 +460,22 @@ target_data_free (TargetCallbackData *target_data)
 
 static const GtkActionEntry clipboard_entries[] =
 {
-    /* name, stock id */      { "Cut", GTK_STOCK_CUT,
-        /* label, accelerator */    NULL, NULL,
+    /* name, icon name */      { "Cut", "edit-cut",
+        /* label, accelerator */    N_("Cu_t"), NULL,
         /* tooltip */               N_("Cut the selected text to the clipboard"),
         G_CALLBACK (action_cut_callback)
     },
-    /* name, stock id */      { "Copy", GTK_STOCK_COPY,
-        /* label, accelerator */    NULL, NULL,
+    /* name, icon name */      { "Copy", "edit-copy",
+        /* label, accelerator */    N_("_Copy"), NULL,
         /* tooltip */               N_("Copy the selected text to the clipboard"),
         G_CALLBACK (action_copy_callback)
     },
-    /* name, stock id */      { "Paste", GTK_STOCK_PASTE,
-        /* label, accelerator */    NULL, NULL,
+    /* name, icon name */      { "Paste", "edit-paste",
+        /* label, accelerator */    N_("_Paste"), NULL,
         /* tooltip */               N_("Paste the text stored on the clipboard"),
         G_CALLBACK (action_paste_callback)
     },
-    /* name, stock id */      { "Select All", NULL,
+    /* name, icon name */      { "Select All", NULL,
         /* label, accelerator */    N_("Select _All"), "<control>A",
         /* tooltip */               N_("Select all the text in a text field"),
         G_CALLBACK (action_select_all_callback)
@@ -484,11 +493,13 @@ initialize_clipboard_component_with_callback_data (GtkEditable *target,
     GtkActionGroup *action_group;
     TargetCallbackData *target_data;
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action_group = gtk_action_group_new ("ClipboardActions");
     gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
     gtk_action_group_add_actions (action_group,
                                   clipboard_entries, G_N_ELEMENTS (clipboard_entries),
                                   target);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     /* Do the actual connection of the UI to the container at
      * focus time, and disconnect at both focus and destroy
@@ -614,7 +625,6 @@ caja_clipboard_get_uri_list_from_selection_data (GtkSelectionData *selection_dat
         GdkAtom copied_files_atom)
 {
     GList *items;
-    char **lines;
 
     if (gtk_selection_data_get_data_type (selection_data) != copied_files_atom
             || gtk_selection_data_get_length (selection_data) <= 0)
@@ -623,6 +633,7 @@ caja_clipboard_get_uri_list_from_selection_data (GtkSelectionData *selection_dat
     }
     else
     {
+        char **lines;
         guchar *data;
         /* Not sure why it's legal to assume there's an extra byte
          * past the end of the selection data that it's safe to write
