@@ -23,7 +23,8 @@
 */
 
 #include <gdk/gdk.h>
-#include <libcaja-private/caja-file.h>
+
+#include "caja-file.h"
 
 typedef struct
 {
