@@ -23,8 +23,13 @@
 */
 
 #include <config.h>
-#include "caja-directory-private.h"
+#include <gtk/gtk.h>
+#include <string.h>
 
+#include <eel/eel-glib-extensions.h>
+#include <eel/eel-gtk-macros.h>
+
+#include "caja-directory-private.h"
 #include "caja-directory-notify.h"
 #include "caja-file-attributes.h"
 #include "caja-file-private.h"
@@ -35,10 +40,6 @@
 #include "caja-metadata.h"
 #include "caja-desktop-directory.h"
 #include "caja-vfs-directory.h"
-#include <eel/eel-glib-extensions.h>
-#include <eel/eel-gtk-macros.h>
-#include <gtk/gtk.h>
-#include <string.h>
 
 enum
 {
@@ -54,8 +55,6 @@ static guint signals[LAST_SIGNAL] = { 0 };
 static GHashTable *directories;
 
 static void               caja_directory_finalize         (GObject                *object);
-static void               caja_directory_init             (CajaDirectory *directory);
-static void               caja_directory_class_init (CajaDirectoryClass *klass);
 static CajaDirectory *caja_directory_new              (GFile                  *location);
 static char *             real_get_name_for_self_as_new_file  (CajaDirectory      *directory);
 static GList *            real_get_file_list                  (CajaDirectory      *directory);
@@ -236,7 +235,7 @@ void
 emit_change_signals_for_all_files_in_all_directories (void)
 {
     GList *dirs, *l;
-    CajaDirectory *directory;
+    CajaDirectory *directory = NULL;
 
     dirs = NULL;
     g_hash_table_foreach (directories,
@@ -360,11 +359,12 @@ CajaFile *
 caja_directory_get_corresponding_file (CajaDirectory *directory)
 {
     CajaFile *file;
-    char *uri;
 
     file = caja_directory_get_existing_corresponding_file (directory);
     if (file == NULL)
     {
+        char *uri;
+
         uri = caja_directory_get_uri (directory);
         file = caja_file_get_by_uri (uri);
         g_free (uri);
@@ -527,7 +527,7 @@ add_to_hash_table (CajaDirectory *directory, CajaFile *file, GList *node)
 {
     const char *name;
 
-    name = eel_ref_str_peek (file->details->name);
+    name = file->details->name;
 
     g_assert (node != NULL);
     g_assert (g_hash_table_lookup (directory->details->file_hash,
@@ -541,7 +541,7 @@ extract_from_hash_table (CajaDirectory *directory, CajaFile *file)
     const char *name;
     GList *node;
 
-    name = eel_ref_str_peek (file->details->name);
+    name = file->details->name;
     if (name == NULL)
     {
         return NULL;
@@ -718,12 +718,13 @@ caja_directory_emit_load_error (CajaDirectory *directory,
 static CajaDirectory *
 get_parent_directory (GFile *location)
 {
-    CajaDirectory *directory;
     GFile *parent;
 
     parent = g_file_get_parent (location);
     if (parent)
     {
+        CajaDirectory *directory;
+
         directory = caja_directory_get_internal (parent, TRUE);
         g_object_unref (parent);
         return directory;
@@ -737,12 +738,13 @@ get_parent_directory (GFile *location)
 static CajaDirectory *
 get_parent_directory_if_exists (GFile *location)
 {
-    CajaDirectory *directory;
     GFile *parent;
 
     parent = g_file_get_parent (location);
     if (parent)
     {
+        CajaDirectory *directory;
+
         directory = caja_directory_get_internal (parent, FALSE);
         g_object_unref (parent);
         return directory;
@@ -777,7 +779,7 @@ static void
 call_files_changed_common (CajaDirectory *directory, GList *file_list)
 {
     GList *node;
-    CajaFile *file;
+    CajaFile *file = NULL;
 
     for (node = file_list; node != NULL; node = node->next)
     {
@@ -858,10 +860,11 @@ caja_directory_notify_files_added (GList *files)
 {
     GHashTable *added_lists;
     GList *p;
-    CajaDirectory *directory;
     GHashTable *parent_directories;
     CajaFile *file;
-    GFile *location, *parent;
+    GFile *parent;
+    CajaDirectory *directory = NULL;
+    GFile *location = NULL;
 
     /* Make a list of added files in each directory. */
     added_lists = g_hash_table_new (NULL, NULL);
@@ -947,8 +950,8 @@ caja_directory_notify_files_changed (GList *files)
 {
     GHashTable *changed_lists;
     GList *node;
-    GFile *location;
-    CajaFile *file;
+    GFile *location = NULL;
+    CajaFile *file = NULL;
 
     /* Make a list of changed files in each directory. */
     changed_lists = g_hash_table_new (NULL, NULL);
@@ -985,10 +988,10 @@ caja_directory_notify_files_removed (GList *files)
 {
     GHashTable *changed_lists;
     GList *p;
-    CajaDirectory *directory;
     GHashTable *parent_directories;
-    CajaFile *file;
-    GFile *location;
+    CajaDirectory *directory = NULL;
+    CajaFile *file = NULL;
+    GFile *location = NULL;
 
     /* Make a list of changed files in each directory. */
     changed_lists = g_hash_table_new (NULL, NULL);
@@ -1094,10 +1097,10 @@ caja_directory_moved_internal (GFile *old_location,
                                GFile *new_location)
 {
     CollectData collection;
-    CajaDirectory *directory;
     GList *node, *affected_files;
-    GFile *new_directory_location;
     char *relative_path;
+    CajaDirectory *directory = NULL;
+    GFile *new_directory_location = NULL;
 
     collection.container = old_location;
     collection.directories = NULL;
@@ -1160,9 +1163,9 @@ caja_directory_moved (const char *old_uri,
 {
     GList *list, *node;
     GHashTable *hash;
-    CajaFile *file;
     GFile *old_location;
     GFile *new_location;
+    CajaFile *file = NULL;
 
     hash = g_hash_table_new (NULL, NULL);
 
@@ -1198,7 +1201,8 @@ caja_directory_notify_files_moved (GList *file_pairs)
     GHashTable *added_lists, *changed_lists;
     char *name;
     CajaFileAttributes cancel_attributes;
-    GFile *to_location, *from_location;
+    GFile *to_location = NULL;
+    GFile *from_location = NULL;
 
     /* Make a list of added and changed files in each directory. */
     new_files_list = NULL;
@@ -1317,10 +1321,10 @@ void
 caja_directory_schedule_position_set (GList *position_setting_list)
 {
     GList *p;
-    const CajaFileChangesQueuePosition *item;
-    CajaFile *file;
     char str[64];
     time_t now;
+    const CajaFileChangesQueuePosition *item = NULL;
+    CajaFile *file = NULL;
 
     time (&now);
 
