@@ -27,22 +27,23 @@
 /* FIXME: This should really be back in Caja, not here in Eel. */
 
 #include <config.h>
-#include "caja-dnd.h"
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+#include <stdio.h>
+#include <string.h>
 
+#include <eel/eel-glib-extensions.h>
+#include <eel/eel-gtk-extensions.h>
+#include <eel/eel-string.h>
+#include <eel/eel-vfs-extensions.h>
+
+#include "caja-dnd.h"
 #include "caja-program-choosing.h"
 #include "caja-link.h"
 #include "caja-window-slot-info.h"
 #include "caja-window-info.h"
 #include "caja-view.h"
-#include <eel/eel-glib-extensions.h>
-#include <eel/eel-gtk-extensions.h>
-#include <eel/eel-string.h>
-#include <eel/eel-vfs-extensions.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-#include <libcaja-private/caja-file-utilities.h>
-#include <stdio.h>
-#include <string.h>
+#include "caja-file-utilities.h"
 
 /* a set of defines stolen from the eel-icon-dnd.c file.
  * These are in microseconds.
@@ -124,9 +125,9 @@ caja_drag_destroy_selection_list (GList *list)
 GList *
 caja_drag_uri_list_from_selection_list (const GList *selection_list)
 {
-    CajaDragSelectionItem *selection_item;
     GList *uri_list;
     const GList *l;
+    CajaDragSelectionItem *selection_item = NULL;
 
     uri_list = NULL;
     for (l = selection_list; l != NULL; l = l->next)
@@ -368,13 +369,14 @@ static gboolean
 check_same_fs (CajaFile *file1,
                CajaFile *file2)
 {
-    char *id1, *id2;
     gboolean result;
 
     result = FALSE;
 
     if (file1 != NULL && file2 != NULL)
     {
+        char *id1, *id2;
+
         id1 = caja_file_get_filesystem_id (file1);
         id2 = caja_file_get_filesystem_id (file2);
 
@@ -636,7 +638,6 @@ static void
 add_one_compatible_uri (const char *uri, int x, int y, int w, int h, gpointer data)
 {
     GString *result;
-    char *local_path;
 
     result = (GString *) data;
 
@@ -653,6 +654,8 @@ add_one_compatible_uri (const char *uri, int x, int y, int w, int h, gpointer da
     }
     else
     {
+        char *local_path;
+
         local_path = g_filename_from_uri (uri, NULL, NULL);
 
         /* Check for characters that confuse the old
@@ -827,8 +830,7 @@ caja_drag_drop_action_ask (GtkWidget *widget,
 
     gtk_grab_add (menu);
 
-    gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
-                    NULL, NULL, 0, GDK_CURRENT_TIME);
+    gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
 
     g_main_loop_run (damd.loop);
 
@@ -881,8 +883,7 @@ caja_drag_drop_background_ask (GtkWidget *widget,
 
     gtk_grab_add (menu);
 
-    gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
-                    NULL, NULL, 0, GDK_CURRENT_TIME);
+    gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
 
     g_main_loop_run (damd.loop);
 
@@ -1007,7 +1008,7 @@ caja_drag_autoscroll_start (CajaDragInfo *drag_info,
         if (drag_info->auto_scroll_timeout_id == 0)
         {
             drag_info->waiting_to_autoscroll = TRUE;
-            drag_info->start_auto_scroll_in = eel_get_system_time()
+            drag_info->start_auto_scroll_in = g_get_monotonic_time()
                                               + AUTOSCROLL_INITIAL_DELAY;
 
             drag_info->auto_scroll_timeout_id = g_timeout_add
@@ -1040,10 +1041,11 @@ gboolean
 caja_drag_selection_includes_special_link (GList *selection_list)
 {
     GList *node;
-    char *uri;
 
     for (node = selection_list; node != NULL; node = node->next)
     {
+        char *uri;
+
         uri = ((CajaDragSelectionItem *) node->data)->uri;
 
         if (eel_uri_is_desktop (uri))
@@ -1227,7 +1229,6 @@ slot_proxy_handle_drop (GtkWidget                *widget,
     CajaWindowSlotInfo *target_slot;
     CajaView *target_view;
     char *target_uri;
-    GList *uri_list;
 
     if (!drag_info->have_data ||
             !drag_info->have_valid_data)
@@ -1269,6 +1270,8 @@ slot_proxy_handle_drop (GtkWidget                *widget,
     {
         if (drag_info->info == CAJA_ICON_DND_MATE_ICON_LIST)
         {
+            GList *uri_list;
+
             uri_list = caja_drag_uri_list_from_selection_list (drag_info->data.selection_list);
             g_assert (uri_list != NULL);
 
