@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, write to the Free
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
+ *  Software Foundation, Inc., 51 Franklin St, Fifth Floor,
  *  Boston, MA 02110-1301, USA.
  *
  *  Author: Alexander van der Meij <alexandervdm@gliese.me>
@@ -25,6 +25,7 @@
 
 #include "caja-global-preferences.h"
 #include "caja-module.h"
+#include "caja-debug-log.h"
 
 #include <string.h>
 
@@ -36,6 +37,7 @@ static GList *caja_extensions = NULL;
 static Extension *
 extension_new (gchar *filename, gboolean state, gboolean python, GObject *module)
 {
+    GError *error = NULL;
     Extension *ext;
     GKeyFile *extension_file;
     gchar *extension_filename;
@@ -53,17 +55,22 @@ extension_new (gchar *filename, gboolean state, gboolean python, GObject *module
 
     extension_file = g_key_file_new ();
     extension_filename = g_strdup_printf(CAJA_DATADIR "/extensions/%s.caja-extension", filename);
-    if (g_key_file_load_from_file (extension_file, extension_filename, G_KEY_FILE_NONE, NULL))
+    if (g_key_file_load_from_file (extension_file, extension_filename, G_KEY_FILE_NONE, &error))
     {
         ext->name = g_key_file_get_locale_string (extension_file, CAJA_EXTENSION_GROUP, "Name", NULL, NULL);
         ext->description = g_key_file_get_locale_string (extension_file, CAJA_EXTENSION_GROUP, "Description", NULL, NULL);
         ext->icon = g_key_file_get_string (extension_file, CAJA_EXTENSION_GROUP, "Icon", NULL);
         ext->author = g_key_file_get_string_list (extension_file, CAJA_EXTENSION_GROUP, "Author", NULL, NULL);
-        ext->copyright = g_key_file_get_string (extension_file, CAJA_EXTENSION_GROUP, "Copyright", NULL);
+        ext->copyright = g_key_file_get_locale_string (extension_file, CAJA_EXTENSION_GROUP, "Copyright", NULL, NULL);
         ext->version = g_key_file_get_string (extension_file, CAJA_EXTENSION_GROUP, "Version", NULL);
         ext->website = g_key_file_get_string (extension_file, CAJA_EXTENSION_GROUP, "Website", NULL);
+        g_key_file_free (extension_file);
+    }
+    else
+    {
+        caja_debug_log (FALSE, CAJA_DEBUG_LOG_DOMAIN_USER, "Error loading keys from file: %s\n", error->message);
+        g_error_free (error);
     }
-    g_key_file_free (extension_file);
     g_free (extension_filename);
 
     if (python)
@@ -82,8 +89,8 @@ gsettings_key_has_value (const gchar *value)
 {
     gchar **list;
     gint i;
-    
-    list = g_settings_get_strv (caja_extension_preferences, 
+
+    list = g_settings_get_strv (caja_extension_preferences,
                                 CAJA_PREFERENCES_DISABLED_EXTENSIONS);
 
     if (list != NULL)
@@ -108,21 +115,21 @@ gsettings_append_to_list (const char *value)
     gchar **new;
     gint size;
     gboolean retval;
-    
-    current = g_settings_get_strv (caja_extension_preferences, 
+
+    current = g_settings_get_strv (caja_extension_preferences,
                                    CAJA_PREFERENCES_DISABLED_EXTENSIONS);
-    
+
     for (size = 0; current[size] != NULL; size++);
 
     size += 1;
     size += 1;
-    
+
     new = g_realloc_n (current, size, sizeof (gchar *));
 
     new[size - 2] = g_strdup (value);
     new[size - 1] = NULL;
-    
-    retval = g_settings_set_strv (caja_extension_preferences, 
+
+    retval = g_settings_set_strv (caja_extension_preferences,
                                   CAJA_PREFERENCES_DISABLED_EXTENSIONS,
                                  (const gchar **) new);
 
@@ -137,19 +144,19 @@ gsettings_remove_from_list (const char *value)
     GArray *array;
     gint i;
     gboolean retval;
-    
-    current = g_settings_get_strv (caja_extension_preferences, 
+
+    current = g_settings_get_strv (caja_extension_preferences,
                                    CAJA_PREFERENCES_DISABLED_EXTENSIONS);
-                                   
+
     array = g_array_new (TRUE, TRUE, sizeof (gchar *));
-    
-    for (i = 0; current[i] != NULL; i++) 
+
+    for (i = 0; current[i] != NULL; i++)
     {
         if (g_strcmp0 (current[i], value) != 0)
             array = g_array_append_val (array, current[i]);
     }
-    
-    retval = g_settings_set_strv (caja_extension_preferences, 
+
+    retval = g_settings_set_strv (caja_extension_preferences,
                                   CAJA_PREFERENCES_DISABLED_EXTENSIONS,
                                  (const gchar **) array->data);
 
@@ -221,7 +228,7 @@ caja_extension_set_state (Extension *ext, gboolean new_state)
         g_return_val_if_fail (ext->state != new_state, FALSE);
         ext->state = new_state;
     }
-   
+
     gboolean retval;
     if (new_state) {
         retval = gsettings_remove_from_list (ext->filename);
@@ -229,7 +236,7 @@ caja_extension_set_state (Extension *ext, gboolean new_state)
     else {
         retval = gsettings_append_to_list (ext->filename);
     }
-    
+
     g_return_val_if_fail (retval == TRUE, FALSE);
     return TRUE;
 }
