@@ -26,9 +26,10 @@
 #define CAJA_ICON_CONTAINER_PRIVATE_H
 
 #include <eel/eel-glib-extensions.h>
-#include <libcaja-private/caja-icon-canvas-item.h>
-#include <libcaja-private/caja-icon-container.h>
-#include <libcaja-private/caja-icon-dnd.h>
+
+#include "caja-icon-canvas-item.h"
+#include "caja-icon-container.h"
+#include "caja-icon-dnd.h"
 
 /* An Icon. */
 
@@ -271,6 +272,7 @@ struct CajaIconContainerDetails
     GQueue* a11y_item_action_queue;
 
     eel_boolean_bit is_loading : 1;
+    eel_boolean_bit is_populating_container : 1;
 
     eel_boolean_bit store_layout_timestamps : 1;
     eel_boolean_bit store_layout_timestamps_when_finishing_new_icons : 1;
