@@ -26,8 +26,6 @@
 #include <config.h>
 #include "caja-keep-last-vertical-box.h"
 
-static void     caja_keep_last_vertical_box_class_init  (CajaKeepLastVerticalBoxClass *class);
-static void     caja_keep_last_vertical_box_init        (CajaKeepLastVerticalBox      *box);
 static void	caja_keep_last_vertical_box_size_allocate 	  (GtkWidget 			    *widget,
         GtkAllocation 		    *allocation);
 
@@ -89,8 +87,6 @@ static void
 caja_keep_last_vertical_box_size_allocate (GtkWidget *widget,
         GtkAllocation *allocation)
 {
-    GtkBox *box;
-    GtkWidget *last_child, *child;
     GList *children, *l;
     GtkAllocation last_child_allocation, child_allocation, tiny_allocation;
 
@@ -99,12 +95,13 @@ caja_keep_last_vertical_box_size_allocate (GtkWidget *widget,
 
     GTK_WIDGET_CLASS (caja_keep_last_vertical_box_parent_class)->size_allocate (widget, allocation);
 
-    box = GTK_BOX (widget);
     children = gtk_container_get_children (GTK_CONTAINER (widget));
     l = g_list_last (children);
 
     if (l != NULL)
     {
+        GtkWidget *last_child;
+
         last_child = l->data;
         l = l->prev;
 
@@ -116,6 +113,7 @@ caja_keep_last_vertical_box_size_allocate (GtkWidget *widget,
         if (last_child_allocation.y + last_child_allocation.height >
                 allocation->y + allocation->height)
         {
+            GtkWidget *child = NULL;
 
             while (l != NULL)
             {
