@@ -24,11 +24,16 @@
 
 #include <config.h>
 #include <math.h>
+#include <string.h>
+
+#include <libnotify/notify.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+
 #include <eel/eel-glib-extensions.h>
+
 #include "caja-progress-info.h"
-#include <string.h>
+#include "caja-global-preferences.h"
 
 enum
 {
@@ -105,7 +110,7 @@ caja_get_all_progress_info (void)
 
     G_LOCK (progress_info);
 
-    l = eel_g_object_list_copy (active_progress_infos);
+    l = g_list_copy_deep (active_progress_infos, (GCopyFunc) g_object_ref, NULL);
 
     G_UNLOCK (progress_info);
 
@@ -303,7 +308,7 @@ progress_widget_data_free (ProgressWidgetData *data)
 static void
 update_data (ProgressWidgetData *data)
 {
-    char *status, *details, *curstat, *t;
+    char *status, *details, *curstat;
     char *markup;
 
     status = caja_progress_info_get_status (data->info);
@@ -326,6 +331,8 @@ update_data (ProgressWidgetData *data)
     }
 
     if (curstat != NULL) {
+        char *t;
+
         t = status;
         status = g_strconcat (status, " \xE2\x80\x94 ", curstat, NULL);
         g_free (t);
@@ -372,9 +379,9 @@ get_running_operations ()
 static void
 foreach_get_queued_widget (GtkWidget * widget, GtkWidget ** out)
 {
-    ProgressWidgetData *data;
-
     if (*out == NULL) {
+        ProgressWidgetData *data;
+
         data = (ProgressWidgetData*) g_object_get_data (
                 G_OBJECT(widget), "data");
 
@@ -405,10 +412,14 @@ start_button_update_view (ProgressWidgetData *data)
     if (state == STATE_RUNNING || state == STATE_QUEUING) {
         toapply = g_object_get_data (G_OBJECT(button),
                                     STARTBT_DATA_IMAGE_PAUSE);
+        atk_object_set_name (gtk_widget_get_accessible (button), _("Pause"));
+        gtk_widget_set_tooltip_text (button, _("Pause"));
         as_pause = TRUE;
     } else {
         toapply = g_object_get_data (G_OBJECT(button),
                                     STARTBT_DATA_IMAGE_RESUME);
+        atk_object_set_name (gtk_widget_get_accessible (button), _("Resume"));
+        gtk_widget_set_tooltip_text (button, _("Resume"));
         as_pause = FALSE;
     }
 
@@ -459,10 +470,10 @@ widget_reposition_as_queued (GtkWidget * widget)
 static void
 widget_reposition_as_paused (GtkWidget * widget)
 {
-    ProgressWidgetData *data;
+    int i;
     GList *children, *child;
+    ProgressWidgetData *data = NULL;
     gboolean abort = FALSE;
-    int i, mypos = -1;
     GtkWidget * container = get_widgets_container();
 
     children = gtk_container_get_children (GTK_CONTAINER(container));
@@ -472,9 +483,6 @@ widget_reposition_as_paused (GtkWidget * widget)
         data = (ProgressWidgetData*) g_object_get_data (
             G_OBJECT(child->data), "data");
 
-        if (child->data == widget)
-            mypos = i;
-
         if (child->data != widget && is_op_paused(data->state)) {
             abort = TRUE;
             i--;
@@ -494,8 +502,8 @@ widget_reposition_as_paused (GtkWidget * widget)
 static void
 widget_reposition_as_running (GtkWidget * widget)
 {
-    ProgressWidgetData *data;
     GList *children, *child;
+    ProgressWidgetData *data = NULL;
     gboolean abort = FALSE;
     int i, mypos = -1;
     GtkWidget * container = get_widgets_container();
@@ -560,13 +568,14 @@ widget_state_transit_to (ProgressWidgetData *data,
 static void
 update_queue ()
 {
-    GtkWidget *next;
-    ProgressWidgetData *data;
-
     if (get_running_operations () == 0) {
+        GtkWidget *next;
+
         next = get_first_queued_widget ();
 
         if (next != NULL) {
+            ProgressWidgetData *data;
+
             data = (ProgressWidgetData*) g_object_get_data (
                     G_OBJECT(next), "data");
             widget_state_transit_to (data, STATE_RUNNING);
@@ -595,14 +604,8 @@ update_status_icon_and_window (void)
 {
     char *tooltip;
     gboolean toshow;
-    GIcon *icon;
-    GNotification *notification;
     static gboolean window_shown = FALSE;
 
-    notification = g_notification_new ("caja");
-    icon = g_themed_icon_new ("system-file-manager");
-    g_notification_set_icon (notification, icon);
-
     tooltip = g_strdup_printf (ngettext ("%'d file operation active",
                                          "%'d file operations active",
                                          n_progress_ops),
@@ -619,9 +622,21 @@ update_status_icon_and_window (void)
 
         if (window_shown)
         {
+            if (g_settings_get_boolean (caja_preferences, CAJA_PREFERENCES_SHOW_NOTIFICATIONS) &&
+                !gtk_window_is_active (GTK_WINDOW (get_progress_window ())))
+            {
+                NotifyNotification *notification;
+
+                notification = notify_notification_new ("caja",
+                                                        _("Process completed"),
+                                                        "system-file-manager");
+
+                notify_notification_show (notification, NULL);
+
+                g_object_unref (notification);
+            }
+
             gtk_widget_hide (get_progress_window ());
-            g_notification_set_body (notification, _("Process completed"));
-            g_application_send_notification (g_application_get_default (), "caja", notification);
             window_shown = FALSE;
         }
     }
@@ -630,8 +645,6 @@ update_status_icon_and_window (void)
         gtk_widget_show_all (get_progress_window ());
         gtk_status_icon_set_visible (status_icon, TRUE);
         gtk_window_present (GTK_WINDOW (get_progress_window ()));
-        g_notification_set_body (notification, _("Working..."));
-        g_application_send_notification (g_application_get_default (), "caja", notification);
         window_shown = TRUE;
     }
 }
@@ -790,6 +803,8 @@ queue_button_init (ProgressWidgetData *data)
     image = gtk_image_new_from_icon_name ("undo", GTK_ICON_SIZE_BUTTON);
 
     gtk_container_add (GTK_CONTAINER (button), image);
+    atk_object_set_name (gtk_widget_get_accessible (button), _("Queue"));
+    gtk_widget_set_tooltip_text (button, _("Queue"));
 
     g_signal_connect (button, "clicked", (GCallback)queue_clicked, data);
 }
@@ -831,6 +846,8 @@ progress_widget_new (CajaProgressInfo *info)
 
     btcancel = gtk_button_new ();
     gtk_container_add (GTK_CONTAINER (btcancel), imgcancel);
+    atk_object_set_name (gtk_widget_get_accessible (btcancel), _("Cancel"));
+    gtk_widget_set_tooltip_text (btcancel, _("Cancel"));
     g_signal_connect (btcancel, "clicked", (GCallback)cancel_clicked, data);
 
     progress_bar = gtk_progress_bar_new ();
@@ -933,8 +950,6 @@ delayed_window_showup (CajaProgressInfo *info)
 static void
 new_op_started (CajaProgressInfo *info)
 {
-    GtkWidget * container;
-
     g_signal_handlers_disconnect_by_func (info, (GCallback)new_op_started, NULL);
 
     if (!caja_progress_info_get_is_finished (info)) {
