@@ -24,18 +24,20 @@
 */
 
 #include <config.h>
-#include "caja-search-directory-file.h"
+#include <string.h>
 
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+
+#include <eel/eel-glib-extensions.h>
+
+#include "caja-search-directory-file.h"
 #include "caja-directory-notify.h"
 #include "caja-directory-private.h"
 #include "caja-file-attributes.h"
 #include "caja-file-private.h"
 #include "caja-file-utilities.h"
-#include <eel/eel-glib-extensions.h>
 #include "caja-search-directory.h"
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-#include <string.h>
 
 struct CajaSearchDirectoryFileDetails
 {
@@ -98,10 +100,10 @@ search_directory_file_get_item_count (CajaFile *file,
                                       guint *count,
                                       gboolean *count_unreadable)
 {
-    GList *file_list;
-
     if (count)
     {
+        GList *file_list;
+
         file_list = caja_directory_get_file_list (file->details->directory);
 
         *count = g_list_length (file_list);
@@ -120,10 +122,10 @@ search_directory_file_get_deep_counts (CajaFile *file,
                                        goffset *total_size,
                                        goffset *total_size_on_disk)
 {
-    CajaFile *dir_file;
     GList *file_list, *l;
     guint dirs, files;
     GFileType type;
+    CajaFile *dir_file = NULL;
 
     file_list = caja_directory_get_file_list (file->details->directory);
 
@@ -180,8 +182,6 @@ void
 caja_search_directory_file_update_display_name (CajaSearchDirectoryFile *search_file)
 {
     CajaFile *file;
-    CajaSearchDirectory *search_dir;
-    CajaQuery *query;
     char *display_name;
     gboolean changed;
 
@@ -190,6 +190,9 @@ caja_search_directory_file_update_display_name (CajaSearchDirectoryFile *search_
     file = CAJA_FILE (search_file);
     if (file->details->directory)
     {
+        CajaSearchDirectory *search_dir;
+        CajaQuery *query;
+
         search_dir = CAJA_SEARCH_DIRECTORY (file->details->directory);
         query = caja_search_directory_get_query (search_dir);
 
@@ -220,7 +223,7 @@ caja_search_directory_file_init (CajaSearchDirectoryFile *search_file)
     file = CAJA_FILE (search_file);
 
     file->details->got_file_info = TRUE;
-    file->details->mime_type = eel_ref_str_get_unique ("x-directory/normal");
+    file->details->mime_type = g_ref_string_new_intern ("x-directory/normal");
     file->details->type = G_FILE_TYPE_DIRECTORY;
     file->details->size = 0;
 
