@@ -23,16 +23,18 @@
 */
 
 #include <config.h>
-#include "caja-ui-utilities.h"
-#include "caja-file-utilities.h"
-#include "caja-icon-info.h"
-#include <gio/gio.h>
 
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gio/gio.h>
+
 #include <eel/eel-debug.h>
 #include <eel/eel-graphic-effects.h>
 
+#include "caja-ui-utilities.h"
+#include "caja-file-utilities.h"
+#include "caja-icon-info.h"
+
 void
 caja_ui_unmerge_ui (GtkUIManager *ui_manager,
                     guint *merge_id,
@@ -59,8 +61,10 @@ caja_ui_prepare_merge_ui (GtkUIManager *ui_manager,
                           GtkActionGroup **action_group)
 {
     *merge_id = gtk_ui_manager_new_merge_id (ui_manager);
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     *action_group = gtk_action_group_new (name);
     gtk_action_group_set_translation_domain (*action_group, GETTEXT_PACKAGE);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
     gtk_ui_manager_insert_action_group (ui_manager, *action_group, 0);
     g_object_unref (*action_group); /* owned by ui manager */
 }
@@ -91,7 +95,6 @@ caja_ui_string_get (const char *filename)
 {
     static GHashTable *ui_cache = NULL;
     char *ui;
-    char *path;
 
     if (ui_cache == NULL)
     {
@@ -102,6 +105,8 @@ caja_ui_string_get (const char *filename)
     ui = g_hash_table_lookup (ui_cache, filename);
     if (ui == NULL)
     {
+        char *path;
+
         path = caja_ui_file (filename);
         if (path == NULL || !g_file_get_contents (path, &ui, NULL, NULL))
         {
@@ -134,7 +139,9 @@ extension_action_sensitive_callback (CajaMenuItem *item,
                   "sensitive", &value,
                   NULL);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     gtk_action_set_sensitive (GTK_ACTION (user_data), value);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 static cairo_surface_t *
@@ -169,7 +176,6 @@ caja_action_from_menu_item (CajaMenuItem *item,
     char *name, *label, *tip, *icon_name;
     gboolean sensitive, priority;
     GtkAction *action;
-    cairo_surface_t *surface;
 
     g_object_get (G_OBJECT (item),
                   "name", &name, "label", &label,
@@ -178,13 +184,17 @@ caja_action_from_menu_item (CajaMenuItem *item,
                   "priority", &priority,
                   NULL);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_new (name,
                              label,
                              tip,
                              icon_name);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     if (icon_name != NULL)
     {
+        cairo_surface_t *surface;
+
         surface = get_action_icon (icon_name,
                                    caja_get_icon_size_for_stock_size (GTK_ICON_SIZE_MENU),
                                    parent_widget);
@@ -192,11 +202,13 @@ caja_action_from_menu_item (CajaMenuItem *item,
         {
             g_object_set_data_full (G_OBJECT (action), "menu-icon",
                                     surface,
-                                    cairo_surface_destroy);
+                                    (GDestroyNotify)cairo_surface_destroy);
         }
     }
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     gtk_action_set_sensitive (action, sensitive);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
     g_object_set (action, "is-important", priority, NULL);
 
     g_signal_connect_data (action, "activate",
@@ -218,7 +230,6 @@ caja_toolbar_action_from_menu_item (CajaMenuItem *item, GtkWidget *parent_widget
     char *name, *label, *tip, *icon_name;
     gboolean sensitive, priority;
     GtkAction *action;
-    cairo_surface_t *surface;
 
     g_object_get (G_OBJECT (item),
                   "name", &name, "label", &label,
@@ -227,13 +238,17 @@ caja_toolbar_action_from_menu_item (CajaMenuItem *item, GtkWidget *parent_widget
                   "priority", &priority,
                   NULL);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_new (name,
                              label,
                              tip,
                              icon_name);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     if (icon_name != NULL)
     {
+        cairo_surface_t *surface;
+
         surface = get_action_icon (icon_name,
                                    caja_get_icon_size_for_stock_size (GTK_ICON_SIZE_LARGE_TOOLBAR),
                                    parent_widget);
@@ -241,11 +256,13 @@ caja_toolbar_action_from_menu_item (CajaMenuItem *item, GtkWidget *parent_widget
         {
             g_object_set_data_full (G_OBJECT (action), "toolbar-icon",
                                     surface,
-                                    cairo_surface_destroy);
+                                    (GDestroyNotify)cairo_surface_destroy);
         }
     }
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     gtk_action_set_sensitive (action, sensitive);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
     g_object_set (action, "is-important", priority, NULL);
 
     g_signal_connect_data (action, "activate",
@@ -269,11 +286,12 @@ caja_toolbar_action_from_menu_item (CajaMenuItem *item, GtkWidget *parent_widget
 static GdkPixbuf *
 caja_get_thumbnail_frame (void)
 {
-    char *image_path;
     static GdkPixbuf *thumbnail_frame = NULL;
 
     if (thumbnail_frame == NULL)
     {
+        char *image_path;
+
         image_path = caja_pixmap_file ("thumbnail_frame.png");
         if (image_path != NULL)
         {
