@@ -27,45 +27,27 @@
  */
 
 #include <config.h>
-#include "caja-application.h"
-
-#include "file-manager/fm-desktop-icon-view.h"
-#include "file-manager/fm-icon-view.h"
-#include "file-manager/fm-list-view.h"
-#include "file-manager/fm-tree-view.h"
-#if ENABLE_EMPTY_VIEW
-#include "file-manager/fm-empty-view.h"
-#endif /* ENABLE_EMPTY_VIEW */
-#include "caja-information-panel.h"
-#include "caja-history-sidebar.h"
-#include "caja-places-sidebar.h"
-#include "caja-self-check-functions.h"
-#include "caja-notes-viewer.h"
-#include "caja-emblem-sidebar.h"
-#include "caja-image-properties-page.h"
 #include <fcntl.h>
 #include <string.h>
 #include <unistd.h>
-#include "caja-desktop-window.h"
-#include "caja-spatial-window.h"
-#include "caja-navigation-window.h"
-#include "caja-window-slot.h"
-#include "caja-navigation-window-slot.h"
-#include "caja-window-bookmarks.h"
-#include "libcaja-private/caja-file-operations.h"
-#include "caja-window-private.h"
-#include "caja-window-manage-views.h"
-#include "caja-freedesktop-dbus.h"
+#include <fcntl.h>
+
 #include <libxml/xmlsave.h>
 #include <glib/gstdio.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-#include <eel/eel-gtk-extensions.h>
-#include <eel/eel-gtk-macros.h>
-#include <eel/eel-stock-dialogs.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <libnotify/notify.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#define MATE_DESKTOP_USE_UNSTABLE_API
+#include <libmate-desktop/mate-bg.h>
+
+#include <eel/eel-gtk-extensions.h>
+#include <eel/eel-gtk-macros.h>
+#include <eel/eel-stock-dialogs.h>
+
 #include <libcaja-private/caja-debug-log.h>
 #include <libcaja-private/caja-file-utilities.h>
 #include <libcaja-private/caja-global-preferences.h>
@@ -77,12 +59,34 @@
 #include <libcaja-private/caja-signaller.h>
 #include <libcaja-extension/caja-menu-provider.h>
 #include <libcaja-private/caja-autorun.h>
-#define MATE_DESKTOP_USE_UNSTABLE_API
-#include <libmate-desktop/mate-bg.h>
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
+#if ENABLE_EMPTY_VIEW
+#include "file-manager/fm-empty-view.h"
+#endif /* ENABLE_EMPTY_VIEW */
+#include "file-manager/fm-desktop-icon-view.h"
+#include "file-manager/fm-icon-view.h"
+#include "file-manager/fm-list-view.h"
+#include "file-manager/fm-tree-view.h"
+#include "file-manager/fm-widget-view.h"
+
+#include "caja-application.h"
+#include "caja-information-panel.h"
+#include "caja-history-sidebar.h"
+#include "caja-places-sidebar.h"
+#include "caja-self-check-functions.h"
+#include "caja-notes-viewer.h"
+#include "caja-emblem-sidebar.h"
+#include "caja-image-properties-page.h"
+#include "caja-desktop-window.h"
+#include "caja-spatial-window.h"
+#include "caja-navigation-window.h"
+#include "caja-window-slot.h"
+#include "caja-navigation-window-slot.h"
+#include "caja-window-bookmarks.h"
+#include "libcaja-private/caja-file-operations.h"
+#include "caja-window-private.h"
+#include "caja-window-manage-views.h"
+#include "caja-freedesktop-dbus.h"
 
 /* Keep window from shrinking down ridiculously small; numbers are somewhat arbitrary */
 #define APPLICATION_WINDOW_MIN_WIDTH	300
@@ -133,13 +137,14 @@ static void
 automount_all_volumes (CajaApplication *application)
 {
     GList *volumes, *l;
-    GMount *mount;
-    GVolume *volume;
 
     if (g_settings_get_boolean (caja_media_preferences, CAJA_PREFERENCES_MEDIA_AUTOMOUNT))
     {
         /* automount all mountable volumes at start-up */
 
+        GVolume *volume = NULL;
+        GMount *mount = NULL;
+
         volumes = g_volume_monitor_get_volumes (application->priv->volume_monitor);
 
         for (l = volumes; l != NULL; l = l->next)
@@ -175,7 +180,7 @@ smclient_save_state_cb (EggSMClient   *client,
     char *data;
     data = caja_application_get_session_data (application);
 
-    if (data != NULL) 
+    if (data != NULL)
     {
         g_key_file_set_string (state_file,
                                "Caja",
@@ -219,9 +224,9 @@ caja_empty_callback_to_ensure_read() {
 
 static void
 open_window (CajaApplication *application,
-             GFile *location, 
-             GdkScreen *screen, 
-             const char *geometry, 
+             GFile *location,
+             GdkScreen *screen,
+             const char *geometry,
              gboolean browser_window)
 {
     CajaApplication *self = CAJA_APPLICATION (application);
@@ -267,10 +272,10 @@ open_window (CajaApplication *application,
 
 static void
 open_tabs (CajaApplication *application,
-           GFile **locations, 
-           guint n_files, 
-           GdkScreen *screen, 
-           const char *geometry, 
+           GFile **locations,
+           guint n_files,
+           GdkScreen *screen,
+           const char *geometry,
            gboolean browser_window)
 {
     CajaApplication *self = CAJA_APPLICATION (application);
@@ -279,7 +284,7 @@ open_tabs (CajaApplication *application,
 
     /* monitor the preference to use browser or spatial windows */
     /* connect before trying to read or this preference won't be read by root or after change */
-    g_signal_connect_swapped (caja_preferences, 
+    g_signal_connect_swapped (caja_preferences,
                               "changed::"CAJA_PREFERENCES_ALWAYS_USE_BROWSER,
                               G_CALLBACK (caja_empty_callback_to_ensure_read),
                               self);
@@ -301,7 +306,7 @@ open_tabs (CajaApplication *application,
     caja_window_go_to (window, locations[0]);
     g_free (uri);
     for (int i = 1; i< n_files;i++) {
-        /* open tabs in reverse order because each 
+        /* open tabs in reverse order because each
          * tab is opened before the previous one */
         guint tab = n_files-i;
         uri = g_file_get_uri (locations[tab]);
@@ -341,9 +346,9 @@ open_windows (CajaApplication *application,
             /* Open one window with one tab at each requested location */
             open_tabs (application, files, n_files, screen, geometry, browser_window);
         } else {
-            /* Open windows at each requested location. */ 
+            /* Open windows at each requested location. */
             i = 0;
-            while (i < n_files) { 
+            while (i < n_files) {
                 open_window (application, files[i], screen, geometry, browser_window);
                 i++ ;
             }
@@ -412,7 +417,7 @@ caja_application_open_location (CajaApplication *application,
     }
 
     caja_window_slot_open_location_full (caja_window_get_active_slot (window), location,
-                                         open_in_tabs, CAJA_WINDOW_OPEN_FLAG_NEW_WINDOW, 
+                                         open_in_tabs, CAJA_WINDOW_OPEN_FLAG_NEW_WINDOW,
                                          sel_list, NULL, NULL);
 
     if (sel_list != NULL) {
@@ -468,7 +473,7 @@ caja_application_finalize (GObject *object)
 	{
 		g_bus_unwatch_name (application->ss_watch_id);
 	}
-	
+
 	if (application->volume_queue != NULL)
 	{
 		g_list_free_full (application->volume_queue, g_object_unref);
@@ -615,183 +620,6 @@ automount_all_volumes_idle_cb (gpointer data)
     return FALSE;
 }
 
-static void
-check_volume_queue (CajaApplication *application)
-{
-        GList *l, *next;
-        GVolume *volume;
-
-        l = application->volume_queue;
-
-        if (application->screensaver_active)
-        {
-                return;
-        }
-
-        while (l != NULL) {
-		volume = l->data;
-		next = l->next;
-
-		caja_file_operations_mount_volume (NULL, volume, TRUE);
-		application->volume_queue =
-			g_list_remove (application->volume_queue, volume);
-
-		g_object_unref (volume);
-		l = next;
-        }
-
-        application->volume_queue = NULL;
-}
-
-#define SCREENSAVER_NAME "org.mate.ScreenSaver"
-#define SCREENSAVER_PATH "/org/mate/ScreenSaver"
-#define SCREENSAVER_INTERFACE "org.mate.ScreenSaver"
-
-static void
-screensaver_signal_callback (GDBusProxy *proxy,
-                             const gchar *sender_name,
-                             const gchar *signal_name,
-                             GVariant *parameters,
-                             gpointer user_data)
-{
-	CajaApplication *application = user_data;
-
-	if (g_strcmp0 (signal_name, "ActiveChanged") == 0)
-	{
-		g_variant_get (parameters, "(b)", &application->screensaver_active);
-		g_debug ("Screensaver active changed to %d", application->screensaver_active);
-
-		check_volume_queue (application);
-	}
-}
-
-static void
-screensaver_get_active_ready_cb (GObject *source,
-				 GAsyncResult *res,
-				 gpointer user_data)
-{
-	CajaApplication *application = user_data;
-	GDBusProxy *proxy = application->ss_proxy;
-	GVariant *result;
-	GError *error = NULL;
-
-	result = g_dbus_proxy_call_finish (proxy,
-					   res,
-					   &error);
-
-	if (error != NULL) {
-		g_warning ("Can't call GetActive() on the ScreenSaver object: %s",
-			   error->message);
-		g_error_free (error);
-
-		return;
-	}
-
-	g_variant_get (result, "(b)", &application->screensaver_active);
-	g_variant_unref (result);
-
-	g_debug ("Screensaver GetActive() returned %d", application->screensaver_active);
-}
-
-static void
-screensaver_proxy_ready_cb (GObject *source,
-			    GAsyncResult *res,
-			    gpointer user_data)
-{
-	CajaApplication *application = user_data;
-	GError *error = NULL;
-	GDBusProxy *ss_proxy;
-	
-	ss_proxy = g_dbus_proxy_new_finish (res, &error);
-
-	if (error != NULL)
-	{
-		g_warning ("Can't get proxy for the ScreenSaver object: %s",
-			   error->message);
-		g_error_free (error);
-
-		return;
-	}
-
-	g_debug ("ScreenSaver proxy ready");
-
-	application->ss_proxy = ss_proxy;
-
-	g_signal_connect (ss_proxy, "g-signal",
-			  G_CALLBACK (screensaver_signal_callback), application);
-
-	g_dbus_proxy_call (ss_proxy,
-			   "GetActive",
-			   NULL,
-			   G_DBUS_CALL_FLAGS_NO_AUTO_START,
-			   -1,
-			   NULL,
-			   screensaver_get_active_ready_cb,
-			   application);
-}
-
-static void
-screensaver_appeared_callback (GDBusConnection *connection,
-			       const gchar *name,
-			       const gchar *name_owner,
-			       gpointer user_data)
-{
-	CajaApplication *application = user_data;
-
-	g_debug ("ScreenSaver name appeared");
-
-	application->screensaver_active = FALSE;
-
-	g_dbus_proxy_new (connection,
-			  G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START,
-			  NULL,
-			  name,
-			  SCREENSAVER_PATH,
-			  SCREENSAVER_INTERFACE,
-			  NULL,
-			  screensaver_proxy_ready_cb,
-			  application);
-}
-
-static void
-screensaver_vanished_callback (GDBusConnection *connection,
-			       const gchar *name,
-			       gpointer user_data)
-{
-	CajaApplication *application = user_data;
-
-	g_debug ("ScreenSaver name vanished");
-
-	application->screensaver_active = FALSE;
-	if (application->ss_proxy != NULL)
-	{
-		g_object_unref (application->ss_proxy);
-		application->ss_proxy = NULL;
-	}
-
-	/* in this case force a clear of the volume queue, without
-	 * mounting them.
-	 */
-	if (application->volume_queue != NULL)
-	{
-		g_list_free_full (application->volume_queue, g_object_unref);
-		application->volume_queue = NULL;
-	}
-}
-
-static void
-do_initialize_screensaver (CajaApplication *application)
-{
-	application->ss_watch_id =
-		g_bus_watch_name (G_BUS_TYPE_SESSION,
-				  SCREENSAVER_NAME,
-				  G_BUS_NAME_WATCHER_FLAGS_NONE,
-				  screensaver_appeared_callback,
-				  screensaver_vanished_callback,
-				  application,
-				  NULL);
-}
-
 static void
 selection_get_cb (GtkWidget          *widget,
                   GtkSelectionData   *selection_data,
@@ -864,7 +692,6 @@ static void
 caja_application_create_desktop_windows (CajaApplication *application)
 {
     GdkDisplay *display;
-    CajaDesktopWindow *window;
     GtkWidget *selection_widget;
 
     g_return_if_fail (caja_application_desktop_windows == NULL);
@@ -872,8 +699,11 @@ caja_application_create_desktop_windows (CajaApplication *application)
     display = gdk_display_get_default ();
 
     selection_widget = get_desktop_manager_selection (display);
+
     if (selection_widget != NULL)
     {
+        CajaDesktopWindow *window;
+
         window = caja_desktop_window_new (application, gdk_display_get_default_screen (display));
 
         g_signal_connect (selection_widget, "selection_clear_event",
@@ -951,7 +781,7 @@ caja_application_get_existing_spatial_window (GFile *location)
 {
     GList *l;
     CajaWindowSlot *slot;
-    GFile *window_location;
+    GFile *window_location = NULL;
 
     for (l = caja_application_get_spatial_window_list ();
             l != NULL; l = l->next) {
@@ -1279,7 +1109,7 @@ check_screen_lock_and_mount (CajaApplication *application,
         } else {
                 /* mount it immediately */
 		caja_file_operations_mount_volume (NULL, volume, TRUE);
-        }       
+        }
 }
 
 static void
@@ -1321,13 +1151,15 @@ drive_eject_cb (GObject *source_object,
                 gpointer user_data)
 {
     GError *error;
-    char *primary;
-    char *name;
     error = NULL;
+
     if (!g_drive_eject_with_operation_finish (G_DRIVE (source_object), res, &error))
     {
         if (error->code != G_IO_ERROR_FAILED_HANDLED)
         {
+            char *primary;
+            char *name;
+
             name = g_drive_get_name (G_DRIVE (source_object));
             primary = g_strdup_printf (_("Unable to eject %s"), name);
             g_free (name);
@@ -1374,10 +1206,8 @@ autorun_show_window (GMount *mount, gpointer user_data)
     GFile *location;
     CajaApplication *application = user_data;
     CajaWindow *window;
-    gboolean existing;
 
     location = g_mount_get_root (mount);
-    existing = FALSE;
 
     /* There should probably be an easier way to do this */
     if (g_settings_get_boolean (caja_preferences, CAJA_PREFERENCES_ALWAYS_USE_BROWSER)) {
@@ -1407,13 +1237,13 @@ mount_added_callback (GVolumeMonitor *monitor,
     CajaDirectory *directory;
     GFile *root;
     gchar *uri;
-        
+
     root = g_mount_get_root (mount);
     uri = g_file_get_uri (root);
 
     g_debug ("Added mount at uri %s", uri);
     g_free (uri);
-    
+
     directory = caja_directory_get_existing (root);
     g_object_unref (root);
     if (directory != NULL) {
@@ -1546,53 +1376,6 @@ mount_removed_callback (GVolumeMonitor *monitor,
     g_list_free (close_list);
 }
 
-static char *
-icon_to_string (GIcon *icon)
-{
-    const char * const *names;
-    GFile *file;
-
-    if (icon == NULL)
-    {
-        return NULL;
-    }
-    else if (G_IS_THEMED_ICON (icon))
-    {
-        names = g_themed_icon_get_names (G_THEMED_ICON (icon));
-        return g_strjoinv (":", (char **)names);
-    }
-    else if (G_IS_FILE_ICON (icon))
-    {
-        file = g_file_icon_get_file (G_FILE_ICON (icon));
-        return g_file_get_path (file);
-    }
-    return NULL;
-}
-
-static GIcon *
-icon_from_string (const char *string)
-{
-    GFile *file;
-    GIcon *icon;
-    gchar **names;
-
-    if (g_path_is_absolute (string))
-    {
-        file = g_file_new_for_path (string);
-        icon = g_file_icon_new (file);
-        g_object_unref (file);
-        return icon;
-    }
-    else
-    {
-        names = g_strsplit (string, ":", 0);
-        icon = g_themed_icon_new_from_names (names, -1);
-        g_strfreev (names);
-        return icon;
-    }
-    return NULL;
-}
-
 static char *
 caja_application_get_session_data (CajaApplication *self)
 {
@@ -1652,9 +1435,10 @@ caja_application_get_session_data (CajaApplication *self)
     for (l = window_list; l != NULL; l = l->next) {
         xmlNodePtr win_node, slot_node;
         CajaWindow *window;
-        CajaWindowSlot *slot, *active_slot;
         GList *slots, *m;
         char *tmp;
+        CajaWindowSlot *active_slot;
+        CajaWindowSlot *slot = NULL;
 
         window = l->data;
 
@@ -1672,10 +1456,10 @@ caja_application_get_session_data (CajaApplication *self)
         }
 
         win_node = xmlNewChild (root_node, NULL, "window", NULL);
-        
+
         xmlNewProp (win_node, "location", tmp);
         g_free (tmp);
-        
+
         xmlNewProp (win_node, "type", CAJA_IS_NAVIGATION_WINDOW (window) ? "navigation" : "spatial");
 
         if (CAJA_IS_NAVIGATION_WINDOW (window)) { /* spatial windows store their state as file metadata */
@@ -1727,7 +1511,7 @@ caja_application_get_session_data (CajaApplication *self)
         xmlSaveFlush (ctx) < 0) {
         g_message ("failed to save session");
     }
-    
+
     xmlSaveClose(ctx);
     data = g_strndup (buffer->content, buffer->use);
     xmlBufferFree (buffer);
@@ -1768,7 +1552,7 @@ caja_application_load_session (CajaApplication *application)
     }
 
     bail = TRUE;
-    
+
     doc = xmlReadMemory (data, strlen (data), NULL, "UTF-8", 0);
     if (doc != NULL && (root_node = xmlDocGetRootElement (doc)) != NULL)
     {
@@ -1844,10 +1628,9 @@ caja_application_load_session (CajaApplication *application)
 
             {
                 CajaWindow *window;
-                xmlChar *type, *location_uri, *slot_uri;
+                xmlChar *type, *location_uri;
                 xmlNodePtr slot_node;
                 GFile *location;
-                int i;
 
                 type = xmlGetProp (node, "type");
                 if (type == NULL)
@@ -1869,6 +1652,8 @@ caja_application_load_session (CajaApplication *application)
                 if (g_strcmp0 (type, "navigation") == 0)
                 {
                     xmlChar *geometry;
+                    int i;
+
                     window = caja_application_create_navigation_window (application, gdk_screen_get_default ());
                     geometry = xmlGetProp (node, "geometry");
                     if (geometry != NULL)
@@ -1913,6 +1698,8 @@ caja_application_load_session (CajaApplication *application)
                     {
                         if (g_strcmp0 (slot_node->name, "slot") == 0)
                         {
+                            xmlChar *slot_uri;
+
                             slot_uri = xmlGetProp (slot_node, "location");
                             if (slot_uri != NULL)
                             {
@@ -1952,7 +1739,7 @@ caja_application_load_session (CajaApplication *application)
                 else if (g_strcmp0 (type, "spatial") == 0)
                 {
                     location = g_file_new_for_uri (location_uri);
-                    window = caja_application_get_spatial_window (application, NULL, NULL, 
+                    window = caja_application_get_spatial_window (application, NULL, NULL,
                     											  location, gdk_screen_get_default (),
                     											  NULL);
 
@@ -2078,7 +1865,7 @@ caja_application_local_command_line (GApplication *application,
 
     const GOptionEntry options[] = {
 #ifndef CAJA_OMIT_SELF_CHECK
-        { "check", 'c', 0, G_OPTION_ARG_NONE, &perform_self_check, 
+        { "check", 'c', 0, G_OPTION_ARG_NONE, &perform_self_check,
           N_("Perform a quick set of self-check tests."), NULL },
 #endif
         { "version", '\0', 0, G_OPTION_ARG_NONE, &version,
@@ -2091,11 +1878,11 @@ caja_application_local_command_line (GApplication *application,
           N_("Do not manage the desktop (ignore the preference set in the preferences dialog)."), NULL },
         { "force-desktop", '\0', 0, G_OPTION_ARG_NONE, &self->priv->force_desktop,
           N_("Manage the desktop regardless of set preferences or environment (on new startup only)"), NULL },
-        { "tabs", 't', 0, G_OPTION_ARG_NONE, &open_in_tabs, 
+        { "tabs", 't', 0, G_OPTION_ARG_NONE, &open_in_tabs,
           N_("Open URIs in tabs."), NULL },
-        { "browser", '\0', 0, G_OPTION_ARG_NONE, &browser_window, 
+        { "browser", '\0', 0, G_OPTION_ARG_NONE, &browser_window,
           N_("Open a browser window."), NULL },
-        { "quit", 'q', 0, G_OPTION_ARG_NONE, &kill_shell, 
+        { "quit", 'q', 0, G_OPTION_ARG_NONE, &kill_shell,
           N_("Quit Caja."), NULL },
         { G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &remaining, NULL,  N_("[URI...]") },
 
@@ -2188,8 +1975,8 @@ caja_application_local_command_line (GApplication *application,
 
     /* Convert args to GFiles */
     if (remaining != NULL) {
-        GFile *file;
         GPtrArray *file_array;
+        GFile *file = NULL;
 
         file_array = g_ptr_array_new ();
 
@@ -2235,46 +2022,76 @@ caja_application_local_command_line (GApplication *application,
  out:
     g_option_context_free (context);
 
-    return TRUE;    
+    return TRUE;
 }
 
+static void
+load_custom_css (GtkCssProvider *provider,
+                 const gchar *filename,
+                 guint priority)
+{
+    GError *error = NULL;
+    gchar *path = g_build_filename (CAJA_DATADIR, filename, NULL);
+
+    if (provider)
+        g_object_ref (provider);
+    else
+        provider = gtk_css_provider_new ();
+
+    gtk_css_provider_load_from_path (provider, path, &error);
+
+    if (error != NULL) {
+        g_warning ("Can't parse Caja' CSS custom description '%s': %s\n",
+                   filename, error->message);
+        g_error_free (error);
+    } else {
+        gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
+                                                   GTK_STYLE_PROVIDER (provider),
+                                                   priority);
+    }
+
+    g_object_unref (provider);
+    g_free (path);
+}
+
+static void
+reload_theme_css (GtkSettings    *settings,
+                  GParamSpec     *unused G_GNUC_UNUSED,
+                  GtkCssProvider *provider)
+{
+    gchar *theme_name;
+    gchar *css_theme_name;
+    gchar *path;
+
+    g_object_get (settings, "gtk-theme-name", &theme_name, NULL);
+    css_theme_name = g_strconcat ("caja-desktop-", theme_name, ".css", NULL);
+    path = g_build_filename (CAJA_DATADIR, css_theme_name, NULL);
+
+    if (g_file_test (path, G_FILE_TEST_EXISTS))
+        load_custom_css (provider, css_theme_name, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    else /* just empty the provider */
+        gtk_css_provider_load_from_data (provider, "", 0, NULL);
+
+    g_free (path);
+    g_free (css_theme_name);
+    g_free (theme_name);
+}
 
 static void
 init_icons_and_styles (void)
 {
+    GtkSettings *settings = gtk_settings_get_default ();
     GtkCssProvider *provider;
-    GError *error = NULL;
 
     /* add our custom CSS provider */
+    load_custom_css (NULL, "caja.css", GTK_STYLE_PROVIDER_PRIORITY_THEME);
+    /* add our desktop CSS provider,  ensures the desktop background does not get covered */
+    load_custom_css (NULL, "caja-desktop.css", GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    /* add theme-specific desktop CSS */
     provider = gtk_css_provider_new ();
-    gtk_css_provider_load_from_path (provider,
-				CAJA_DATADIR G_DIR_SEPARATOR_S "caja.css", &error);
-
-    if (error != NULL) {
-        g_warning ("Can't parse Caja' CSS custom description: %s\n", error->message);
-        g_error_free (error);
-    } else {
-        gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-                               GTK_STYLE_PROVIDER (provider),
-                               GTK_STYLE_PROVIDER_PRIORITY_THEME);
-    }
-
-/* add our desktop CSS provider,  ensures the desktop background does not get covered */
-    provider = gtk_css_provider_new ();
-
-    gtk_css_provider_load_from_path (provider, CAJA_DATADIR G_DIR_SEPARATOR_S "caja-desktop.css", &error);
-
-    if (error != NULL) {
-        g_warning ("Can't parse Caja' CSS custom description: %s\n", error->message);
-        g_error_free (error);
-    } else {
-        gtk_style_context_add_provider_for_screen (gdk_screen_get_default (),
-                               GTK_STYLE_PROVIDER (provider),
-                               GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-    }
-
-
-    g_object_unref (provider);
+    reload_theme_css (settings, NULL, provider);
+    g_signal_connect_data (settings, "notify::gtk-theme-name", G_CALLBACK (reload_theme_css),
+                           provider, (GClosureNotify) g_object_unref, 0);
 
     /* initialize search path for custom icons */
     gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
@@ -2309,7 +2126,7 @@ init_desktop (CajaApplication *self)
                   self);
 }
 
-static gboolean 
+static gboolean
 caja_application_save_accel_map (gpointer data)
 {
     if (save_of_accel_map_requested) {
@@ -2325,14 +2142,14 @@ caja_application_save_accel_map (gpointer data)
     return FALSE;
 }
 
-static void 
+static void
 queue_accel_map_save_callback (GtkAccelMap *object, gchar *accel_path,
         guint accel_key, GdkModifierType accel_mods,
         gpointer user_data)
 {
     if (!save_of_accel_map_requested) {
         save_of_accel_map_requested = TRUE;
-        g_timeout_add_seconds (CAJA_ACCEL_MAP_SAVE_DELAY, 
+        g_timeout_add_seconds (CAJA_ACCEL_MAP_SAVE_DELAY,
                 caja_application_save_accel_map, NULL);
     }
 }
@@ -2357,10 +2174,7 @@ init_gtk_accels (void)
 static void
 caja_application_startup (GApplication *app)
 {
-    GList *drives;
-    CajaApplication *application;
     CajaApplication *self = CAJA_APPLICATION (app);
-    GApplication *instance;
     gboolean exit_with_last_window;
     exit_with_last_window = TRUE;
 
@@ -2386,6 +2200,7 @@ caja_application_startup (GApplication *app)
     fm_desktop_icon_view_register ();
     fm_list_view_register ();
     fm_compact_view_register ();
+    fm_widget_view_register ();
 #if ENABLE_EMPTY_VIEW
     fm_empty_view_register ();
 #endif /* ENABLE_EMPTY_VIEW */
@@ -2404,15 +2219,15 @@ caja_application_startup (GApplication *app)
     /* initialize theming */
     init_icons_and_styles ();
     init_gtk_accels ();
-    
+
     /* initialize caja modules */
     caja_module_setup ();
 
     /* attach menu-provider module callback */
     menu_provider_init_callback ();
-    
+
     /* Initialize notifications for eject operations */
-    notify_init (GETTEXT_PACKAGE);  
+    notify_init (GETTEXT_PACKAGE);
 
     /* Watch for unmounts so we can close open windows */
     /* TODO-gio: This should be using the UNMOUNTED feature of GFileMonitor instead */
@@ -2431,7 +2246,6 @@ caja_application_startup (GApplication *app)
                              G_CALLBACK (drive_connected_callback), self, 0);
 
     /* listen for eject button presses */
-    drives = g_volume_monitor_get_connected_drives ( self->priv->volume_monitor);
     self->automount_idle_id =
     g_idle_add_full (G_PRIORITY_LOW,
                      automount_all_volumes_idle_cb,
@@ -2444,13 +2258,15 @@ caja_application_startup (GApplication *app)
     init_desktop (self);
 
     /* exit_with_last_window is already set to TRUE, and we need to keep that value
-     * on other desktops, running from the command line,  or when running caja as root. 
+     * on other desktops, running from the command line,  or when running caja as root.
      * Otherwise, we read the value from the configuration.
      */
 
     if (running_in_mate () && !running_as_root())
     {
-        exit_with_last_window = g_settings_get_boolean (caja_preferences,   
+        GApplication *instance;
+
+        exit_with_last_window = g_settings_get_boolean (caja_preferences,
                                 CAJA_PREFERENCES_EXIT_WITH_LAST_WINDOW);
         /*Keep this inside the running as mate/not as root block */
         /*So other desktop don't get unkillable caja instances holding open */
