@@ -22,10 +22,13 @@
  */
 
 #include <config.h>
+
 #include <gio/gio.h>
-#include "caja-connect-server-dialog.h"
+
 #include <libcaja-private/caja-global-preferences.h>
 
+#include "caja-connect-server-dialog.h"
+
 /* This file contains the glue for the calls from the connect to server dialog
  * to the main caja binary. A different version of this glue is in
  * caja-connect-server-dialog-main.c for the standalone version.
@@ -38,10 +41,6 @@ window_go_to_cb (CajaWindow *window,
 		 GError *error,
 		 gpointer user_data)
 {
-    CajaConnectServerDialog *self;
-
-    self = user_data;
-
     if (error != NULL) {
     	g_simple_async_result_set_from_error (display_location_res, error);
     }
