@@ -23,19 +23,22 @@
  */
 
 #include <config.h>
-#include "caja-desktop-window.h"
-#include "caja-window-private.h"
-#include "caja-actions.h"
 
 #include <X11/Xatom.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
+#include <gio/gio.h>
+#include <glib/gi18n.h>
+
 #include <eel/eel-background.h>
 #include <eel/eel-vfs-extensions.h>
+
 #include <libcaja-private/caja-file-utilities.h>
 #include <libcaja-private/caja-icon-names.h>
-#include <gio/gio.h>
-#include <glib/gi18n.h>    
+
+#include "caja-desktop-window.h"
+#include "caja-window-private.h"
+#include "caja-actions.h"
 
 /* Tell screen readers that this is a desktop window */
 
@@ -72,14 +75,14 @@ caja_desktop_window_accessible_class_init (CajaDesktopWindowAccessibleClass *kla
     aclass->get_attributes = desktop_get_attributes;
 }
 
-struct CajaDesktopWindowDetails
+struct _CajaDesktopWindowPrivate
 {
     gulong size_changed_id;
 
     gboolean loaded;
 };
 
-G_DEFINE_TYPE (CajaDesktopWindow, caja_desktop_window,
+G_DEFINE_TYPE_WITH_PRIVATE (CajaDesktopWindow, caja_desktop_window,
                CAJA_TYPE_SPATIAL_WINDOW);
 
 static void
@@ -88,8 +91,7 @@ caja_desktop_window_init (CajaDesktopWindow *window)
     GtkAction *action;
     AtkObject *accessible;
 
-    window->details = G_TYPE_INSTANCE_GET_PRIVATE (window, CAJA_TYPE_DESKTOP_WINDOW,
-                                                   CajaDesktopWindowDetails);
+    window->details = caja_desktop_window_get_instance_private (window);
 
     GtkStyleContext *context;
 
@@ -111,9 +113,11 @@ caja_desktop_window_init (CajaDesktopWindow *window)
     gtk_widget_hide (CAJA_WINDOW (window)->details->menubar);
 
     /* Don't allow close action on desktop */
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (CAJA_WINDOW (window)->details->main_action_group,
                                           CAJA_ACTION_CLOSE);
     gtk_action_set_sensitive (action, FALSE);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     /* Set the accessible name so that it doesn't inherit the cryptic desktop URI. */
     accessible = gtk_widget_get_accessible (GTK_WIDGET (window));
@@ -200,6 +204,8 @@ caja_desktop_window_new (CajaApplication *application,
         XFree(xch);
     }
 
+    gdk_window_set_title (gdkwin, _("Desktop"));
+
     g_signal_connect (window, "delete_event", G_CALLBACK (caja_desktop_window_delete_event), NULL);
 
     /* Point window at the desktop folder.
@@ -222,7 +228,7 @@ static void
 unrealize (GtkWidget *widget)
 {
     CajaDesktopWindow *window;
-    CajaDesktopWindowDetails *details;
+    CajaDesktopWindowPrivate *details;
     GdkWindow *root_window;
 
     window = CAJA_DESKTOP_WINDOW (widget);
@@ -280,7 +286,7 @@ static void
 realize (GtkWidget *widget)
 {
     CajaDesktopWindow *window;
-    CajaDesktopWindowDetails *details;
+    CajaDesktopWindowPrivate *details;
     window = CAJA_DESKTOP_WINDOW (widget);
     details = window->details;
 
@@ -309,12 +315,6 @@ draw (GtkWidget *widget,
     return GTK_WIDGET_CLASS (caja_desktop_window_parent_class)->draw (widget, cr);
 }
 
-static char *
-real_get_title (CajaWindow *window)
-{
-    return g_strdup (_("Desktop"));
-}
-
 static CajaIconInfo *
 real_get_icon (CajaWindow *window,
                CajaWindowSlot *slot)
@@ -337,10 +337,7 @@ caja_desktop_window_class_init (CajaDesktopWindowClass *klass)
     gtk_widget_class_set_accessible_type (wclass, CAJA_TYPE_DESKTOP_WINDOW_ACCESSIBLE);
 
     nclass->window_type = CAJA_WINDOW_DESKTOP;
-    nclass->get_title = real_get_title;
     nclass->get_icon = real_get_icon;
-
-    g_type_class_add_private (klass, sizeof (CajaDesktopWindowDetails));
 }
 
 gboolean
