@@ -29,18 +29,19 @@
  */
 
 #include <config.h>
-#include "caja-emblem-sidebar.h"
-
 #include <stdio.h>
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+
 #include <eel/eel-wrap-table.h>
 #include <eel/eel-labeled-image.h>
 #include <eel/eel-graphic-effects.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-gtk-extensions.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
+
 #include <libcaja-private/caja-icon-dnd.h>
 #include <libcaja-private/caja-emblem-utils.h>
 #include <libcaja-private/caja-file-utilities.h>
@@ -48,6 +49,8 @@
 #include <libcaja-private/caja-module.h>
 #include <libcaja-private/caja-signaller.h>
 
+#include "caja-emblem-sidebar.h"
+
 struct CajaEmblemSidebarDetails
 {
     CajaWindowInfo *window;
@@ -212,14 +215,14 @@ static void
 caja_emblem_sidebar_delete_cb (GtkWidget *menu_item,
                                CajaEmblemSidebar *emblem_sidebar)
 {
-    char *error;
-
     if (caja_emblem_remove_emblem (emblem_sidebar->details->popup_emblem_keyword))
     {
         send_emblems_changed ();
     }
     else
     {
+        char *error;
+
         error = g_strdup_printf (_("Could not remove emblem with name '%s'."), emblem_sidebar->details->popup_emblem_display_name);
         eel_show_error_dialog (error, _("This is probably because the emblem is a permanent one, and not one that you added yourself."),
                                NULL);
@@ -232,7 +235,7 @@ rename_dialog_response_cb (GtkWidget *dialog, int response,
                            CajaEmblemSidebar *emblem_sidebar)
 {
     GtkWidget *entry;
-    char *keyword, *name, *error;
+    char *keyword, *name;
 
     keyword = g_object_get_data (G_OBJECT (dialog), "emblem-keyword");
 
@@ -260,6 +263,8 @@ rename_dialog_response_cb (GtkWidget *dialog, int response,
     }
     else
     {
+        char *error;
+
         error = g_strdup_printf (_("Could not rename emblem with name '%s'."), name);
         eel_show_error_dialog (error, _("This is probably because the emblem is a permanent one, and not one that you added yourself."),
                                NULL);
@@ -529,11 +534,13 @@ static GtkWidget *
 create_add_emblems_dialog (CajaEmblemSidebar *emblem_sidebar,
                            GSList *emblems)
 {
-    GtkWidget *dialog, *label, *table, *image;
-    GtkWidget *first_entry, *entry, *scroller, *hbox;
-    Emblem *emblem;
+    GtkWidget *dialog, *label, *table;
+    GtkWidget *first_entry, *entry, *scroller;
     GSList *list;
     int num_emblems;
+    GtkWidget *image = NULL;
+    GtkWidget *hbox = NULL;
+    Emblem *emblem = NULL;
 
     first_entry = NULL;
 
@@ -747,7 +754,7 @@ caja_emblem_sidebar_drag_received_cb (GtkWidget *widget,
     GSList *emblems;
     Emblem *emblem;
     GdkPixbuf *pixbuf;
-    char *uri, *error, *uri_utf8;
+    char *uri, *error;
     char **uris;
     GFile *f;
     int i;
@@ -851,6 +858,8 @@ caja_emblem_sidebar_drag_received_cb (GtkWidget *widget,
         }
         else
         {
+            char *uri_utf8;
+
             uri_utf8 = g_file_get_parse_name (f);
 
             if (uri_utf8)
@@ -972,7 +981,6 @@ caja_emblem_sidebar_populate (CajaEmblemSidebar *emblem_sidebar)
 {
     GList *icons, *l, *widgets;
     GtkWidget *emblem_widget;
-    char *name;
     char *path;
     GdkPixbuf *erase_pixbuf;
 
@@ -1003,6 +1011,8 @@ caja_emblem_sidebar_populate (CajaEmblemSidebar *emblem_sidebar)
     widgets = NULL;
     while (l != NULL)
     {
+        char *name;
+
         name = (char *)l->data;
         l = l->next;
 
@@ -1075,9 +1085,6 @@ caja_emblem_sidebar_class_init (CajaEmblemSidebarClass *object_klass)
 {
     GObjectClass *gobject_class;
 
-    CajaEmblemSidebarClass *klass;
-
-    klass = CAJA_EMBLEM_SIDEBAR_CLASS (object_klass);
     gobject_class = G_OBJECT_CLASS (object_klass);
 
     gobject_class->finalize = caja_emblem_sidebar_finalize;
