@@ -24,16 +24,11 @@
  */
 
 #include <config.h>
-#include "caja-image-properties-page.h"
+#include <string.h>
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-#include <eel/eel-vfs-extensions.h>
-#include <libcaja-extension/caja-property-page-provider.h>
-#include <libcaja-private/caja-module.h>
-#include <string.h>
-
 #ifdef HAVE_EXIF
 #include <libexif/exif-data.h>
 #include <libexif/exif-ifd.h>
@@ -44,9 +39,16 @@
 #include <exempi/xmpconsts.h>
 #endif /*HAVE_EXEMPI*/
 
+#include <eel/eel-vfs-extensions.h>
+
+#include <libcaja-extension/caja-property-page-provider.h>
+#include <libcaja-private/caja-module.h>
+
+#include "caja-image-properties-page.h"
+
 #define LOAD_BUFFER_SIZE 8192
 
-struct CajaImagePropertiesPageDetails
+struct _CajaImagePropertiesPagePrivate
 {
     GCancellable *cancellable;
     GtkWidget *vbox;
@@ -93,7 +95,7 @@ typedef struct
 static GType caja_image_properties_page_provider_get_type (void);
 static void  property_page_provider_iface_init                (CajaPropertyPageProviderIface *iface);
 
-G_DEFINE_TYPE (CajaImagePropertiesPage, caja_image_properties_page, GTK_TYPE_BOX);
+G_DEFINE_TYPE_WITH_PRIVATE (CajaImagePropertiesPage, caja_image_properties_page, GTK_TYPE_BOX);
 
 G_DEFINE_TYPE_WITH_CODE (CajaImagePropertiesPageProvider, caja_image_properties_page_provider, G_TYPE_OBJECT,
                          G_IMPLEMENT_INTERFACE (CAJA_TYPE_PROPERTY_PAGE_PROVIDER,
@@ -376,9 +378,6 @@ append_xmpdata_string (XmpPtr xmp, CajaImagePropertiesPage *page)
 static void
 load_finished (CajaImagePropertiesPage *page)
 {
-    GdkPixbufFormat *format;
-    char *name, *desc;
-
     gtk_widget_destroy (page->details->loading_label);
 
     if (page->details->loader != NULL) {
@@ -387,6 +386,8 @@ load_finished (CajaImagePropertiesPage *page)
 
     if (page->details->got_size)
     {
+        GdkPixbufFormat *format;
+        char *name, *desc;
 #ifdef HAVE_EXIF
         ExifData *exif_data;
 #endif /*HAVE_EXIF*/
@@ -459,7 +460,6 @@ file_read_callback (GObject      *object,
     GInputStream *stream;
     gssize count_read;
     GError *error;
-    int exif_still_loading;
     gboolean done_reading;
 
     page = CAJA_IMAGE_PROPERTIES_PAGE (data);
@@ -471,6 +471,7 @@ file_read_callback (GObject      *object,
 
     if (count_read > 0)
     {
+        int exif_still_loading;
 
         g_assert (count_read <= sizeof(page->details->buffer));
 
@@ -635,16 +636,12 @@ caja_image_properties_page_class_init (CajaImagePropertiesPageClass *class)
     object_class = G_OBJECT_CLASS (class);
 
     object_class->finalize = caja_image_properties_page_finalize;
-
-    g_type_class_add_private (object_class, sizeof(CajaImagePropertiesPageDetails));
 }
 
 static void
 caja_image_properties_page_init (CajaImagePropertiesPage *page)
 {
-    page->details = G_TYPE_INSTANCE_GET_PRIVATE (page,
-                    CAJA_TYPE_IMAGE_PROPERTIES_PAGE,
-                    CajaImagePropertiesPageDetails);
+    page->details = caja_image_properties_page_get_instance_private (page);
 
     gtk_orientable_set_orientation (GTK_ORIENTABLE (page), GTK_ORIENTATION_VERTICAL);
 
