@@ -28,35 +28,38 @@
 /* caja-main.c: Implementation of the routines that drive program lifecycle and main window creation/destruction. */
 
 #include <config.h>
-#include "caja-window.h"
 #include <dlfcn.h>
 #include <signal.h>
-#include <eel/eel-debug.h>
-#include <eel/eel-glib-extensions.h>
-#include <eel/eel-self-checks.h>
-#include <libegg/eggdesktopfile.h>
-#include <gdk/gdkx.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-#include <gio/gdesktopappinfo.h>
-#include <libcaja-private/caja-debug-log.h>
-#include <libcaja-private/caja-global-preferences.h>
-#include <libcaja-private/caja-icon-names.h>
-#include <libxml/parser.h>
 #ifdef HAVE_LOCALE_H
-	#include <locale.h>
+#include <locale.h>
 #endif
 #ifdef HAVE_MALLOC_H
-	#include <malloc.h>
+#include <malloc.h>
 #endif
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 
+#include <gdk/gdkx.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+#include <gio/gdesktopappinfo.h>
+#include <libxml/parser.h>
 #ifdef HAVE_EXEMPI
-	#include <exempi/xmp.h>
+#include <exempi/xmp.h>
 #endif
 
+#include <eel/eel-debug.h>
+#include <eel/eel-glib-extensions.h>
+#include <eel/eel-self-checks.h>
+
+#include <libcaja-private/caja-debug-log.h>
+#include <libcaja-private/caja-global-preferences.h>
+#include <libcaja-private/caja-icon-names.h>
+
+#include <libegg/eggdesktopfile.h>
+
+#include "caja-window.h"
 
 static void dump_debug_log (void)
 {
@@ -216,20 +219,6 @@ setup_debug_log (void)
     setup_debug_log_glog ();
 }
 
-static gboolean
-running_in_mate (void)
-{
-    return (g_strcmp0 (g_getenv ("XDG_CURRENT_DESKTOP"), "MATE") == 0)
-        || (g_strcmp0 (g_getenv ("XDG_SESSION_DESKTOP"), "MATE") == 0)
-        || (g_strcmp0 (g_getenv ("DESKTOP_SESSION"), "MATE") == 0);
-}
-
-static gboolean
-running_as_root (void)
-{
-    return geteuid () == 0;
-}
-
 int
 main (int argc, char *argv[])
 {
@@ -253,7 +242,7 @@ main (int argc, char *argv[])
 	if (g_getenv ("CAJA_DEBUG") != NULL) {
 		eel_make_warnings_and_criticals_stop_in_debugger ();
 	}
-	
+
 	/* Initialize gettext support */
 	bindtextdomain (GETTEXT_PACKAGE, MATELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -266,7 +255,7 @@ main (int argc, char *argv[])
 	if (g_file_test (DATADIR "/applications/caja.desktop", G_FILE_TEST_EXISTS)) {
 		egg_set_desktop_file (DATADIR "/applications/caja.desktop");
 	}
-	
+
 #ifdef HAVE_EXEMPI
 	xmp_init();
 #endif
