@@ -26,9 +26,23 @@
  *                           split into separate file just for convenience.
  */
 #include <config.h>
-
 #include <locale.h>
 
+#include <libxml/parser.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+
+#include <eel/eel-glib-extensions.h>
+#include <eel/eel-mate-extensions.h>
+#include <eel/eel-stock-dialogs.h>
+#include <eel/eel-string.h>
+
+#include <libcaja-private/caja-file-utilities.h>
+#include <libcaja-private/caja-global-preferences.h>
+#include <libcaja-private/caja-ui-utilities.h>
+#include <libcaja-private/caja-search-engine.h>
+#include <libcaja-private/caja-signaller.h>
+
 #include "caja-actions.h"
 #include "caja-notebook.h"
 #include "caja-navigation-action.h"
@@ -43,18 +57,6 @@
 #include "caja-window-private.h"
 #include "caja-window-bookmarks.h"
 #include "caja-navigation-window-pane.h"
-#include <eel/eel-glib-extensions.h>
-#include <eel/eel-mate-extensions.h>
-#include <eel/eel-stock-dialogs.h>
-#include <eel/eel-string.h>
-#include <libxml/parser.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-#include <libcaja-private/caja-file-utilities.h>
-#include <libcaja-private/caja-global-preferences.h>
-#include <libcaja-private/caja-ui-utilities.h>
-#include <libcaja-private/caja-search-engine.h>
-#include <libcaja-private/caja-signaller.h>
 
 #define MENU_PATH_HISTORY_PLACEHOLDER			"/MenuBar/Other Menus/Go/History Placeholder"
 
@@ -131,8 +133,8 @@ forget_history_if_confirmed (CajaWindow *window)
     dialog = eel_create_question_dialog (_("Are you sure you want to clear the list "
                                            "of locations you have visited?"),
                                          NULL,
-                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                         GTK_STOCK_CLEAR, RESPONSE_FORGET,
+                                         "process-stop", GTK_RESPONSE_CANCEL,
+                                         "edit-clear", RESPONSE_FORGET,
                                          GTK_WINDOW (window));
 
     gtk_widget_show (GTK_WIDGET (dialog));
@@ -188,6 +190,7 @@ action_show_hide_toolbar_callback (GtkAction *action,
 
     window = CAJA_NAVIGATION_WINDOW (user_data);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
     {
         caja_navigation_window_show_toolbar (window);
@@ -196,6 +199,7 @@ action_show_hide_toolbar_callback (GtkAction *action,
     {
         caja_navigation_window_hide_toolbar (window);
     }
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 
@@ -208,6 +212,7 @@ action_show_hide_sidebar_callback (GtkAction *action,
 
     window = CAJA_NAVIGATION_WINDOW (user_data);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
     {
         caja_navigation_window_show_sidebar (window);
@@ -216,6 +221,7 @@ action_show_hide_sidebar_callback (GtkAction *action,
     {
         caja_navigation_window_hide_sidebar (window);
     }
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 static void
@@ -244,7 +250,9 @@ action_show_hide_location_bar_callback (GtkAction *action,
 
     window = CAJA_WINDOW (user_data);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     is_active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     /* Do the active pane first, because this will trigger an update of the menu items,
      * which in turn relies on the active pane. */
@@ -264,6 +272,7 @@ action_show_hide_statusbar_callback (GtkAction *action,
 
     window = CAJA_NAVIGATION_WINDOW (user_data);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
     {
         caja_navigation_window_show_status_bar (window);
@@ -272,6 +281,7 @@ action_show_hide_statusbar_callback (GtkAction *action,
     {
         caja_navigation_window_hide_status_bar (window);
     }
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 static void
@@ -283,7 +293,9 @@ action_split_view_callback (GtkAction *action,
 
     window = CAJA_NAVIGATION_WINDOW (user_data);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     is_active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
+    G_GNUC_END_IGNORE_DEPRECATIONS;
     if (is_active != caja_navigation_window_split_view_showing (window))
     {
         CajaWindow *caja_window;
@@ -311,6 +323,7 @@ caja_navigation_window_update_show_hide_menu_items (CajaNavigationWindow *window
 
     g_assert (CAJA_IS_NAVIGATION_WINDOW (window));
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (window->details->navigation_action_group,
                                           CAJA_ACTION_SHOW_HIDE_TOOLBAR);
     gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
@@ -335,6 +348,7 @@ caja_navigation_window_update_show_hide_menu_items (CajaNavigationWindow *window
                                           CAJA_ACTION_SHOW_HIDE_EXTRA_PANE);
     gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
                                   caja_navigation_window_split_view_showing (window));
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 void
@@ -344,10 +358,12 @@ caja_navigation_window_update_spatial_menu_item (CajaNavigationWindow *window)
 
     g_assert (CAJA_IS_NAVIGATION_WINDOW (window));
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (window->details->navigation_action_group,
                                           CAJA_ACTION_FOLDER_WINDOW);
     gtk_action_set_visible (action,
                             !g_settings_get_boolean (caja_preferences, CAJA_PREFERENCES_ALWAYS_USE_BROWSER));
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 static void
@@ -434,16 +450,6 @@ connect_proxy_cb (GtkActionGroup *action_group,
     gtk_label_set_max_width_chars (label, MENU_ITEM_MAX_WIDTH_CHARS);
 }
 
-static const char* icon_entries[] =
-{
-    "/MenuBar/Other Menus/Go/Home",
-    "/MenuBar/Other Menus/Go/Computer",
-    "/MenuBar/Other Menus/Go/Go to Templates",
-    "/MenuBar/Other Menus/Go/Go to Trash",
-    "/MenuBar/Other Menus/Go/Go to Network",
-    "/MenuBar/Other Menus/Go/Go to Location"
-};
-
 /**
  * refresh_go_menu:
  *
@@ -455,9 +461,7 @@ refresh_go_menu (CajaNavigationWindow *window)
 {
     GtkUIManager *ui_manager;
     GList *node;
-    GtkWidget *menuitem;
     int index;
-    int i;
 
     g_assert (CAJA_IS_NAVIGATION_WINDOW (window));
 
@@ -470,7 +474,9 @@ refresh_go_menu (CajaNavigationWindow *window)
     ui_manager = caja_window_get_ui_manager (CAJA_WINDOW (window));
 
     window->details->go_menu_merge_id = gtk_ui_manager_new_merge_id (ui_manager);
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     window->details->go_menu_action_group = gtk_action_group_new ("GoMenuGroup");
+    G_GNUC_END_IGNORE_DEPRECATIONS;
     g_signal_connect (window->details->go_menu_action_group, "connect-proxy",
                       G_CALLBACK (connect_proxy_cb), NULL);
 
@@ -479,16 +485,6 @@ refresh_go_menu (CajaNavigationWindow *window)
                                         -1);
     g_object_unref (window->details->go_menu_action_group);
 
-    for (i = 0; i < G_N_ELEMENTS (icon_entries); i++)
-    {
-        menuitem = gtk_ui_manager_get_widget (
-                       ui_manager,
-                       icon_entries[i]);
-
-        gtk_image_menu_item_set_always_show_image (
-            GTK_IMAGE_MENU_ITEM (menuitem), TRUE);
-    }
-
     /* Add in a new set of history items. */
     for (node = caja_get_history_list (), index = 0;
             node != NULL && index < 10;
@@ -585,6 +581,7 @@ caja_navigation_window_update_split_view_actions_sensitivity (CajaNavigationWind
         next_pane_is_in_same_location = FALSE;
     }
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     /* switch to next pane */
     action = gtk_action_group_get_action (action_group, "SplitViewNextPane");
     gtk_action_set_sensitive (action, have_multiple_panes);
@@ -592,6 +589,7 @@ caja_navigation_window_update_split_view_actions_sensitivity (CajaNavigationWind
     /* same location */
     action = gtk_action_group_get_action (action_group, "SplitViewSameLocation");
     gtk_action_set_sensitive (action, have_multiple_panes && !next_pane_is_in_same_location);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     /* clean up */
     if (active_pane_location)
@@ -609,15 +607,12 @@ action_new_window_callback (GtkAction *action,
                             gpointer user_data)
 {
     CajaWindow *current_window;
-    CajaWindow *new_window;
 
-    current_window = CAJA_WINDOW (user_data);
-    new_window = caja_application_create_navigation_window (
-                     current_window->application,
-                     gtk_window_get_screen (GTK_WINDOW (current_window)));
-    caja_window_go_home (new_window);
+    current_window = CAJA_WINDOW (user_data);   
+    caja_window_new_window (current_window);
 }
 
+
 static void
 action_new_tab_callback (GtkAction *action,
                          gpointer user_data)
@@ -677,6 +672,7 @@ action_show_search_callback (GtkAction *action,
 
     window = CAJA_NAVIGATION_WINDOW (user_data);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     search_action =
         gtk_action_group_get_action (window->details->navigation_action_group,
                                      CAJA_ACTION_SEARCH);
@@ -692,12 +688,14 @@ action_show_search_callback (GtkAction *action,
         gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (search_action),
                                       TRUE);
     }
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 static void
 action_show_hide_search_callback (GtkAction *action,
                                   gpointer user_data)
 {
+    gboolean var_action;
     CajaNavigationWindow *window;
 
     /* This is used when toggling the action for updating the UI
@@ -709,7 +707,11 @@ action_show_hide_search_callback (GtkAction *action,
 
     window = CAJA_NAVIGATION_WINDOW (user_data);
 
-    if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
+    var_action = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
+    G_GNUC_END_IGNORE_DEPRECATIONS;
+
+    if (var_action)
     {
         caja_navigation_window_show_search (window);
     }
@@ -729,11 +731,12 @@ action_show_hide_search_callback (GtkAction *action,
         else
         {
             CajaQuery *query;
-            char *uri;
 
             query = caja_query_editor_get_query (slot->query_editor);
             if (query != NULL)
             {
+                char *uri;
+
                 uri = caja_query_get_location (query);
                 if (uri != NULL)
                 {
@@ -821,46 +824,46 @@ action_tab_change_action_activate_callback (GtkAction *action, gpointer user_dat
 
 static const GtkActionEntry navigation_entries[] =
 {
-    /* name, stock id, label */  { "Go", NULL, N_("_Go") },
-    /* name, stock id, label */  { "Bookmarks", NULL, N_("_Bookmarks") },
-    /* name, stock id, label */  { "Tabs", NULL, N_("_Tabs") },
-    /* name, stock id, label */  { "New Window", "window-new", N_("New _Window"),
+    /* name, icon name, label */ { "Go", NULL, N_("_Go") },
+    /* name, icon name, label */ { "Bookmarks", NULL, N_("_Bookmarks") },
+    /* name, icon name, label */ { "Tabs", NULL, N_("_Tabs") },
+    /* name, icon name, label */ { "New Window", "window-new", N_("New _Window"),
         "<control>N", N_("Open another Caja window for the displayed location"),
         G_CALLBACK (action_new_window_callback)
     },
-    /* name, stock id, label */  { "New Tab", "tab-new", N_("New _Tab"),
+    /* name, icon name, label */ { "New Tab", "tab-new", N_("New _Tab"),
         "<control>T", N_("Open another tab for the displayed location"),
         G_CALLBACK (action_new_tab_callback)
     },
-    /* name, stock id, label */  { "Folder Window", "folder", N_("Open Folder W_indow"),
+    /* name, icon name, label */ { "Folder Window", "folder", N_("Open Folder W_indow"),
         NULL, N_("Open a folder window for the displayed location"),
         G_CALLBACK (action_folder_window_callback)
     },
-    /* name, stock id, label */  { "Close All Windows", NULL, N_("Close _All Windows"),
+    /* name, icon name, label */ { "Close All Windows", NULL, N_("Close _All Windows"),
         "<control>Q", N_("Close all Navigation windows"),
         G_CALLBACK (action_close_all_windows_callback)
     },
-    /* name, stock id, label */  { "Go to Location", NULL, N_("_Location..."),
+    /* name, icon name, label */ { "Go to Location", NULL, N_("_Location..."),
         "<control>L", N_("Specify a location to open"),
         G_CALLBACK (action_go_to_location_callback)
     },
-    /* name, stock id, label */  { "Clear History", NULL, N_("Clea_r History"),
+    /* name, icon name, label */ { "Clear History", NULL, N_("Clea_r History"),
         NULL, N_("Clear contents of Go menu and Back/Forward lists"),
         G_CALLBACK (action_clear_history_callback)
     },
-    /* name, stock id, label */  { "SplitViewNextPane", NULL, N_("S_witch to Other Pane"),
+    /* name, icon name, label */ { "SplitViewNextPane", NULL, N_("S_witch to Other Pane"),
         "F6", N_("Move focus to the other pane in a split view window"),
         G_CALLBACK (action_split_view_switch_next_pane_callback)
     },
-    /* name, stock id, label */  { "SplitViewSameLocation", NULL, N_("Sa_me Location as Other Pane"),
+    /* name, icon name, label */ { "SplitViewSameLocation", NULL, N_("Sa_me Location as Other Pane"),
         NULL, N_("Go to the same location as in the extra pane"),
         G_CALLBACK (action_split_view_same_location_callback)
     },
-    /* name, stock id, label */  { "Add Bookmark", GTK_STOCK_ADD, N_("_Add Bookmark"),
+    /* name, icon name, label */ { "Add Bookmark", "list-add", N_("_Add Bookmark"),
         "<control>d", N_("Add a bookmark for the current location to this menu"),
         G_CALLBACK (action_add_bookmark_callback)
     },
-    /* name, stock id, label */  { "Edit Bookmarks", NULL, N_("_Edit Bookmarks..."),
+    /* name, icon name, label */ { "Edit Bookmarks", NULL, N_("_Edit Bookmarks..."),
         "<control>b", N_("Display a window that allows editing the bookmarks in this menu"),
         G_CALLBACK (action_edit_bookmarks_callback)
     },
@@ -893,38 +896,38 @@ static const GtkActionEntry navigation_entries[] =
 
 static const GtkToggleActionEntry navigation_toggle_entries[] =
 {
-    /* name, stock id */     { "Show Hide Toolbar", NULL,
+    /* name, icon name */    { "Show Hide Toolbar", NULL,
         /* label, accelerator */   N_("_Main Toolbar"), NULL,
         /* tooltip */              N_("Change the visibility of this window's main toolbar"),
         G_CALLBACK (action_show_hide_toolbar_callback),
         /* is_active */            TRUE
     },
-    /* name, stock id */     { "Show Hide Sidebar", NULL,
+    /* name, icon name */    { "Show Hide Sidebar", NULL,
         /* label, accelerator */   N_("_Side Pane"), "F9",
         /* tooltip */              N_("Change the visibility of this window's side pane"),
         G_CALLBACK (action_show_hide_sidebar_callback),
         /* is_active */            TRUE
     },
-    /* name, stock id */     { "Show Hide Location Bar", NULL,
+    /* name, icon name */    { "Show Hide Location Bar", NULL,
         /* label, accelerator */   N_("Location _Bar"), NULL,
         /* tooltip */              N_("Change the visibility of this window's location bar"),
         G_CALLBACK (action_show_hide_location_bar_callback),
         /* is_active */            TRUE
     },
-    /* name, stock id */     { "Show Hide Statusbar", NULL,
+    /* name, icon name */    { "Show Hide Statusbar", NULL,
         /* label, accelerator */   N_("St_atusbar"), NULL,
         /* tooltip */              N_("Change the visibility of this window's statusbar"),
         G_CALLBACK (action_show_hide_statusbar_callback),
         /* is_active */            TRUE
     },
-    /* name, stock id */     { "Search", "gtk-find",
+    /* name, icon name */    { "Search", "edit-find",
         /* label, accelerator */   N_("_Search for Files..."),
         /* Accelerator is in ShowSearch */"",
         /* tooltip */              N_("Search documents and folders by name"),
         G_CALLBACK (action_show_hide_search_callback),
         /* is_active */            FALSE
     },
-    /* name, stock id */     {
+    /* name, icon name */    {
         CAJA_ACTION_SHOW_HIDE_EXTRA_PANE, NULL,
         /* label, accelerator */   N_("E_xtra Pane"), "F3",
         /* tooltip */              N_("Open an extra folder view side-by-side"),
@@ -941,6 +944,7 @@ caja_navigation_window_initialize_actions (CajaNavigationWindow *window)
     GtkAction *action;
     int i;
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action_group = gtk_action_group_new ("NavigationActions");
     gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
     window->details->navigation_action_group = action_group;
@@ -954,7 +958,7 @@ caja_navigation_window_initialize_actions (CajaNavigationWindow *window)
     action = g_object_new (CAJA_TYPE_NAVIGATION_ACTION,
                            "name", "Back",
                            "label", _("_Back"),
-                           "stock_id", GTK_STOCK_GO_BACK,
+                           "icon-name", "go-previous",
                            "tooltip", _("Go to the previous visited location"),
                            "arrow-tooltip", _("Back history"),
                            "window", window,
@@ -971,7 +975,7 @@ caja_navigation_window_initialize_actions (CajaNavigationWindow *window)
     action = g_object_new (CAJA_TYPE_NAVIGATION_ACTION,
                            "name", "Forward",
                            "label", _("_Forward"),
-                           "stock_id", GTK_STOCK_GO_FORWARD,
+                           "icon-name", "go-next",
                            "tooltip", _("Go to the next visited location"),
                            "arrow-tooltip", _("Forward history"),
                            "window", window,
@@ -1005,6 +1009,7 @@ caja_navigation_window_initialize_actions (CajaNavigationWindow *window)
     gtk_action_group_add_action (action_group,
                                  action);
     g_object_unref (action);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     ui_manager = caja_window_get_ui_manager (CAJA_WINDOW (window));
 
@@ -1015,6 +1020,7 @@ caja_navigation_window_initialize_actions (CajaNavigationWindow *window)
         gchar accelerator[80];
 
         snprintf(action_name, sizeof (action_name), "Tab%d", i);
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
         action = gtk_action_new (action_name, NULL, NULL, NULL);
         g_object_set_data (G_OBJECT (action), "num", GINT_TO_POINTER (i));
         g_signal_connect (action, "activate",
@@ -1022,6 +1028,7 @@ caja_navigation_window_initialize_actions (CajaNavigationWindow *window)
         snprintf(accelerator, sizeof (accelerator), "<alt>%d", (i+1)%10);
         gtk_action_group_add_action_with_accel (action_group, action, accelerator);
         g_object_unref (action);
+        G_GNUC_END_IGNORE_DEPRECATIONS;
         gtk_ui_manager_add_ui (ui_manager,
                                gtk_ui_manager_new_merge_id (ui_manager),
                                "/",
@@ -1032,11 +1039,13 @@ caja_navigation_window_initialize_actions (CajaNavigationWindow *window)
 
     }
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (action_group, CAJA_ACTION_SEARCH);
     g_object_set (action, "short_label", _("_Search"), NULL);
 
     action = gtk_action_group_get_action (action_group, "ShowSearch");
     gtk_action_set_sensitive (action, TRUE);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
     g_object_unref (action_group); /* owned by ui_manager */
