@@ -29,21 +29,8 @@
 /* caja-window.c: Implementation of the main window object */
 
 #include <config.h>
-#include "caja-window-private.h"
+#include <math.h>
 
-#include "caja-actions.h"
-#include "caja-application.h"
-#include "caja-bookmarks-window.h"
-#include "caja-location-bar.h"
-#include "caja-query-editor.h"
-#include "caja-search-bar.h"
-#include "caja-navigation-window-slot.h"
-#include "caja-notebook.h"
-#include "caja-window-manage-views.h"
-#include "caja-navigation-window-pane.h"
-#include <eel/eel-gtk-extensions.h>
-#include <eel/eel-gtk-macros.h>
-#include <eel/eel-string.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
@@ -51,6 +38,12 @@
 #ifdef HAVE_X11_XF86KEYSYM_H
 #include <X11/XF86keysym.h>
 #endif
+#include <sys/time.h>
+
+#include <eel/eel-gtk-extensions.h>
+#include <eel/eel-gtk-macros.h>
+#include <eel/eel-string.h>
+
 #include <libcaja-private/caja-file-utilities.h>
 #include <libcaja-private/caja-file-attributes.h>
 #include <libcaja-private/caja-global-preferences.h>
@@ -65,8 +58,19 @@
 #include <libcaja-private/caja-sidebar-provider.h>
 #include <libcaja-private/caja-search-directory.h>
 #include <libcaja-private/caja-signaller.h>
-#include <math.h>
-#include <sys/time.h>
+
+#include "caja-navigation-window.h"
+#include "caja-window-private.h"
+#include "caja-actions.h"
+#include "caja-application.h"
+#include "caja-bookmarks-window.h"
+#include "caja-location-bar.h"
+#include "caja-query-editor.h"
+#include "caja-search-bar.h"
+#include "caja-navigation-window-slot.h"
+#include "caja-notebook.h"
+#include "caja-window-manage-views.h"
+#include "caja-navigation-window-pane.h"
 
 #define MAX_TITLE_LENGTH 180
 
@@ -88,7 +92,7 @@ static void use_extra_mouse_buttons_changed          (gpointer
 static CajaWindowSlot *create_extra_pane         (CajaNavigationWindow *window);
 
 
-G_DEFINE_TYPE (CajaNavigationWindow, caja_navigation_window, CAJA_TYPE_WINDOW)
+G_DEFINE_TYPE_WITH_PRIVATE (CajaNavigationWindow, caja_navigation_window, CAJA_TYPE_WINDOW)
 #define parent_class caja_navigation_window_parent_class
 
 static const struct
@@ -115,7 +119,7 @@ caja_navigation_window_init (CajaNavigationWindow *window)
 
     win = CAJA_WINDOW (window);
 
-    window->details = G_TYPE_INSTANCE_GET_PRIVATE (window, CAJA_TYPE_NAVIGATION_WINDOW, CajaNavigationWindowDetails);
+    window->details = caja_navigation_window_get_instance_private (window);
 
     GtkStyleContext *context;
 
@@ -140,7 +144,7 @@ caja_navigation_window_init (CajaNavigationWindow *window)
     gtk_paned_pack2 (GTK_PANED (window->details->content_paned), vbox,
     		     TRUE, FALSE);
     gtk_widget_show (vbox);
-   
+
     hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_box_pack_start (GTK_BOX (vbox), hpaned, TRUE, TRUE, 0);
     gtk_widget_show (hpaned);
@@ -473,7 +477,7 @@ static void
 caja_navigation_window_tear_down_sidebar (CajaNavigationWindow *window)
 {
     GList *node, *next;
-    CajaSidebar *sidebar_panel;
+    CajaSidebar *sidebar_panel = NULL;
 
     g_signal_handlers_disconnect_by_func (window->sidebar,
                                           side_pane_switch_page_callback,
@@ -520,12 +524,59 @@ caja_navigation_window_key_press_event (GtkWidget *widget,
 
     window = CAJA_NAVIGATION_WINDOW (widget);
 
+    if (event->state & GDK_CONTROL_MASK)
+    {
+        GSettings *settings = g_settings_new ("org.mate.caja.preferences");
+        gboolean handled = FALSE;
+
+        if (g_settings_get_boolean (settings, "ctrl-tab-switch-tabs"))
+        {
+            CajaWindow *cajawin;
+            CajaWindowSlot *slot;
+            CajaNavigationWindowPane *pane;
+            CajaNotebook *cajanotebook;
+            GtkNotebook *notebook;
+            int pages;
+            int page_num;
+
+            cajawin = CAJA_WINDOW (window);
+            slot = caja_window_get_active_slot (cajawin);
+            pane = CAJA_NAVIGATION_WINDOW_PANE (slot->pane);
+            cajanotebook = CAJA_NOTEBOOK (pane->notebook);
+            notebook = GTK_NOTEBOOK (cajanotebook);
+            pages = gtk_notebook_get_n_pages (notebook);
+            page_num = gtk_notebook_get_current_page (notebook);
+
+            if (event->keyval == GDK_KEY_ISO_Left_Tab)
+            {
+                if (page_num != 0)
+                    gtk_notebook_prev_page (notebook);
+                else
+                    gtk_notebook_set_current_page (notebook, (pages - 1));
+                handled = TRUE;
+            }
+            if (event->keyval == GDK_KEY_Tab)
+            {
+                if (page_num != (pages -1))
+                    gtk_notebook_next_page (notebook);
+                else
+                    gtk_notebook_set_current_page (notebook, 0);
+                handled = TRUE;
+            }
+        }
+        g_object_unref (settings);
+
+        if (handled)
+            return TRUE;
+    }
+
     for (i = 0; i < G_N_ELEMENTS (extra_navigation_window_keybindings); i++)
     {
         if (extra_navigation_window_keybindings[i].keyval == event->keyval)
         {
             GtkAction *action;
 
+            G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
             action = gtk_action_group_get_action (window->details->navigation_action_group,
                                                   extra_navigation_window_keybindings[i].action);
 
@@ -535,6 +586,7 @@ caja_navigation_window_key_press_event (GtkWidget *widget,
                 gtk_action_activate (action);
                 return TRUE;
             }
+            G_GNUC_END_IGNORE_DEPRECATIONS;
 
             break;
         }
@@ -704,10 +756,12 @@ caja_navigation_window_allow_back (CajaNavigationWindow *window, gboolean allow)
 {
     GtkAction *action;
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (window->details->navigation_action_group,
                                           CAJA_ACTION_BACK);
 
     gtk_action_set_sensitive (action, allow);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 void
@@ -715,10 +769,12 @@ caja_navigation_window_allow_forward (CajaNavigationWindow *window, gboolean all
 {
     GtkAction *action;
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (window->details->navigation_action_group,
                                           CAJA_ACTION_FORWARD);
 
     gtk_action_set_sensitive (action, allow);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 static void
@@ -727,19 +783,21 @@ real_sync_title (CajaWindow *window,
 {
     CajaNavigationWindowPane *pane;
     CajaNotebook *notebook;
-    char *full_title;
-    char *window_title;
 
     EEL_CALL_PARENT (CAJA_WINDOW_CLASS,
                      sync_title, (window, slot));
 
     if (slot == window->details->active_pane->active_slot)
     {
+        char *window_title;
+
         /* if spatial mode is default, we keep "File Browser" in the window title
          * to recognize browser windows. Otherwise, we default to the directory name.
          */
         if (!g_settings_get_boolean (caja_preferences, CAJA_PREFERENCES_ALWAYS_USE_BROWSER))
         {
+            char *full_title;
+
             full_title = g_strdup_printf (_("%s - File Browser"), slot->title);
             window_title = eel_str_middle_truncate (full_title, MAX_TITLE_LENGTH);
             g_free (full_title);
@@ -841,6 +899,7 @@ caja_navigation_window_set_search_button (CajaNavigationWindow *window,
 {
     GtkAction *action;
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (window->details->navigation_action_group,
                                           "Search");
 
@@ -849,6 +908,7 @@ caja_navigation_window_set_search_button (CajaNavigationWindow *window,
     g_object_set_data (G_OBJECT (action), "blocked", GINT_TO_POINTER (1));
     gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), state);
     g_object_set_data (G_OBJECT (action), "blocked", NULL);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 static void
@@ -883,7 +943,7 @@ add_sidebar_panels (CajaNavigationWindow *window)
     GtkWidget *current;
     GList *providers;
     GList *p;
-    CajaSidebar *sidebar_panel;
+    CajaSidebar *sidebar_panel = NULL;
 
     g_assert (CAJA_IS_NAVIGATION_WINDOW (window));
 
@@ -1120,13 +1180,14 @@ caja_navigation_window_show (GtkWidget *widget)
 static void
 caja_navigation_window_save_geometry (CajaNavigationWindow *window)
 {
-    char *geometry_string;
     gboolean is_maximized;
 
     g_assert (CAJA_IS_WINDOW (window));
 
     if (gtk_widget_get_window (GTK_WIDGET (window)))
     {
+        char *geometry_string;
+
         geometry_string = eel_gtk_window_get_geometry_string (GTK_WINDOW (window));
         is_maximized = gdk_window_get_state (gtk_widget_get_window (GTK_WIDGET (window)))
                        & GDK_WINDOW_STATE_MAXIMIZED;
@@ -1240,8 +1301,6 @@ caja_navigation_window_class_init (CajaNavigationWindowClass *class)
     CAJA_WINDOW_CLASS (class)->open_slot = real_open_slot;
     CAJA_WINDOW_CLASS (class)->close_slot = real_close_slot;
 
-    g_type_class_add_private (G_OBJECT_CLASS (class), sizeof (CajaNavigationWindowDetails));
-
     g_signal_connect_swapped (caja_preferences,
                               "changed::" CAJA_PREFERENCES_MOUSE_BACK_BUTTON,
                               G_CALLBACK(mouse_back_button_changed),
@@ -1328,6 +1387,7 @@ caja_navigation_window_split_view_on (CajaNavigationWindow *window)
     caja_window_slot_go_to (slot, location, FALSE);
     g_object_unref (location);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (CAJA_NAVIGATION_WINDOW (CAJA_WINDOW_PANE (pane)->window)->details->navigation_action_group,
                                           CAJA_ACTION_SHOW_HIDE_LOCATION_BAR);
     if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
@@ -1338,14 +1398,16 @@ caja_navigation_window_split_view_on (CajaNavigationWindow *window)
     {
         caja_navigation_window_pane_hide_location_bar (pane, TRUE);
     }
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 void
 caja_navigation_window_split_view_off (CajaNavigationWindow *window)
 {
     CajaWindow *win;
-    CajaWindowPane *pane, *active_pane;
     GList *l, *next;
+    CajaWindowPane *active_pane;
+    CajaWindowPane *pane = NULL;
 
     win = CAJA_WINDOW (window);
 
