@@ -24,7 +24,13 @@
  *
  */
 
-#include "config.h"
+#include <config.h>
+
+#include <glib/gi18n.h>
+#include <gio/gio.h>
+#include <gtk/gtk.h>
+
+#include <libcaja-private/caja-dnd.h>
 
 #include "caja-notebook.h"
 #include "caja-navigation-window.h"
@@ -32,16 +38,9 @@
 #include "caja-window-private.h"
 #include "caja-window-slot.h"
 #include "caja-navigation-window-pane.h"
-#include <libcaja-private/caja-dnd.h>
-
-#include <glib/gi18n.h>
-#include <gio/gio.h>
-#include <gtk/gtk.h>
 
 #define AFTER_ALL_TABS -1
 
-static void caja_notebook_init		 (CajaNotebook *notebook);
-static void caja_notebook_class_init	 (CajaNotebookClass *klass);
 static int  caja_notebook_insert_page	 (GtkNotebook *notebook,
         GtkWidget *child,
         GtkWidget *tab_label,
@@ -50,12 +49,6 @@ static int  caja_notebook_insert_page	 (GtkNotebook *notebook,
 static void caja_notebook_remove	 (GtkContainer *container,
                                       GtkWidget *tab_widget);
 
-static const GtkTargetEntry url_drag_types[] =
-{
-    { CAJA_ICON_DND_MATE_ICON_LIST_TYPE, 0, CAJA_ICON_DND_MATE_ICON_LIST },
-    { CAJA_ICON_DND_URI_LIST_TYPE, 0, CAJA_ICON_DND_URI_LIST },
-};
-
 enum
 {
     TAB_CLOSE_REQUEST,
@@ -182,19 +175,6 @@ caja_notebook_init (CajaNotebook *notebook)
 
     g_signal_connect (notebook, "button-press-event",
                       (GCallback)button_press_cb, NULL);
-
-    /* Set up drag-and-drop target */
-    /* TODO this would be used for opening a new tab.
-     * It will only work properly as soon as GtkNotebook
-     * supports to find out whether a particular point
-     * is on a tab button or not.
-     */
-#if 0
-    gtk_drag_dest_set (GTK_WIDGET (notebook), 0,
-                       url_drag_types, G_N_ELEMENTS (url_drag_types),
-                       GDK_ACTION_LINK);
-    gtk_drag_dest_set_track_motion (GTK_WIDGET (notebook), TRUE);
-#endif
 }
 
 void
@@ -240,7 +220,6 @@ caja_notebook_sync_tab_label (CajaNotebook *notebook,
                               CajaWindowSlot *slot)
 {
     GtkWidget *hbox, *label;
-    char *location_name;
 
     g_return_if_fail (CAJA_IS_NOTEBOOK (notebook));
     g_return_if_fail (CAJA_IS_WINDOW_SLOT (slot));
@@ -256,6 +235,8 @@ caja_notebook_sync_tab_label (CajaNotebook *notebook,
 
     if (slot->location != NULL)
     {
+        char *location_name;
+
         /* Set the tooltip on the label's parent (the tab label hbox),
          * so it covers all of the tab label.
          */
