@@ -30,7 +30,13 @@
 
 #include <config.h>
 #include <math.h>
-#include "caja-property-browser.h"
+
+#include <libxml/parser.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n.h>
+#include <glib/gstdio.h>
+#include <gio/gio.h>
+#include <atk/atkrelationset.h>
 
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
@@ -41,11 +47,7 @@
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-xml-extensions.h>
-#include <libxml/parser.h>
-#include <gtk/gtk.h>
-#include <glib/gi18n.h>
-#include <glib/gstdio.h>
-#include <gio/gio.h>
+
 #include <libcaja-private/caja-customization-data.h>
 #include <libcaja-private/caja-directory.h>
 #include <libcaja-private/caja-emblem-utils.h>
@@ -54,7 +56,8 @@
 #include <libcaja-private/caja-global-preferences.h>
 #include <libcaja-private/caja-metadata.h>
 #include <libcaja-private/caja-signaller.h>
-#include <atk/atkrelationset.h>
+
+#include "caja-property-browser.h"
 
 /* property types */
 
@@ -66,7 +69,7 @@ typedef enum
     CAJA_PROPERTY_EMBLEM
 } CajaPropertyType;
 
-struct CajaPropertyBrowserDetails
+struct _CajaPropertyBrowserPrivate
 {
     GtkWidget *container;
 
@@ -194,7 +197,7 @@ static GtkTargetEntry drag_types[] =
 };
 
 
-G_DEFINE_TYPE (CajaPropertyBrowser, caja_property_browser, GTK_TYPE_WINDOW)
+G_DEFINE_TYPE_WITH_PRIVATE (CajaPropertyBrowser, caja_property_browser, GTK_TYPE_WINDOW)
 
 
 /* Destroy the three dialogs for adding patterns/colors/emblems if any of them
@@ -253,8 +256,6 @@ caja_property_browser_class_init (CajaPropertyBrowserClass *klass)
     widget_class->drag_begin = caja_property_browser_drag_begin;
     widget_class->drag_data_get  = caja_property_browser_drag_data_get;
     widget_class->drag_end  = caja_property_browser_drag_end;
-
-    g_type_class_add_private (klass, sizeof (CajaPropertyBrowserDetails));
 }
 
 /* initialize the instance's fields, create the necessary subviews, etc. */
@@ -270,9 +271,7 @@ caja_property_browser_init (CajaPropertyBrowser *property_browser)
 
     widget = GTK_WIDGET (property_browser);
 
-    property_browser->details = G_TYPE_INSTANCE_GET_PRIVATE (property_browser,
-    							     CAJA_TYPE_PROPERTY_BROWSER,
-    							     CajaPropertyBrowserDetails);
+    property_browser->details = caja_property_browser_get_instance_private (property_browser);
 
     property_browser->details->category = g_strdup ("patterns");
     property_browser->details->category_type = CAJA_PROPERTY_PATTERN;
@@ -537,7 +536,6 @@ caja_property_browser_drag_begin (GtkWidget *widget,
     CajaPropertyBrowser *property_browser;
     GtkWidget *child;
     GdkPixbuf *pixbuf;
-    int x_delta, y_delta;
     char *element_name;
 
     property_browser = CAJA_PROPERTY_BROWSER (widget);
@@ -569,6 +567,8 @@ caja_property_browser_drag_begin (GtkWidget *widget,
     /* set the pixmap and mask for dragging */
     if (pixbuf != NULL)
     {
+        int x_delta, y_delta;
+
         x_delta = gdk_pixbuf_get_width (pixbuf) / 2;
         y_delta = gdk_pixbuf_get_height (pixbuf) / 2;
 
@@ -722,9 +722,7 @@ make_drag_image (CajaPropertyBrowser *property_browser, const char* file_name)
 {
     GdkPixbuf *pixbuf, *orig_pixbuf;
     char *image_file_name;
-    char *icon_name;
     gboolean is_reset;
-    CajaIconInfo *info;
 
     if (property_browser->details->category_type == CAJA_PROPERTY_EMBLEM)
     {
@@ -741,6 +739,9 @@ make_drag_image (CajaPropertyBrowser *property_browser, const char* file_name)
         }
         else
         {
+            char *icon_name;
+            CajaIconInfo *info;
+
             icon_name = caja_emblem_get_icon_name_from_keyword (file_name);
             info = caja_icon_info_lookup_from_name (icon_name, CAJA_ICON_SIZE_STANDARD, 1);
             pixbuf = caja_icon_info_get_pixbuf_at_size (info, CAJA_ICON_SIZE_STANDARD);
@@ -808,7 +809,7 @@ make_color_drag_image (CajaPropertyBrowser *property_browser, const char *color_
     GdkPixbuf *color_square;
     GdkPixbuf *ret;
     int row, col, stride;
-    char *pixels, *row_pixels;
+    char *pixels;
     GdkColor color;
 
     color_square = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, COLOR_SQUARE_SIZE, COLOR_SQUARE_SIZE);
@@ -824,7 +825,10 @@ make_color_drag_image (CajaPropertyBrowser *property_browser, const char *color_
     /* loop through and set each pixel */
     for (row = 0; row < COLOR_SQUARE_SIZE; row++)
     {
+        char *row_pixels;
+
         row_pixels =  (pixels + (row * stride));
+
         for (col = 0; col < COLOR_SQUARE_SIZE; col++)
         {
             *row_pixels++ = color.red;
@@ -1034,11 +1038,13 @@ update_preview_cb (GtkFileChooser *fc,
                    GtkImage *preview)
 {
     char *filename;
-    GdkPixbuf *pixbuf;
 
     filename = gtk_file_chooser_get_preview_filename (fc);
+
     if (filename)
     {
+        GdkPixbuf *pixbuf;
+
         pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
 
         gtk_file_chooser_set_preview_widget_active (fc, pixbuf != NULL);
@@ -1236,7 +1242,7 @@ caja_color_selection_dialog_new (CajaPropertyBrowser *property_browser)
 
 /* add the newly selected file to the browser images */
 static void
-add_pattern_to_browser (GtkDialog *dialog, gint response_id, gpointer *data)
+add_pattern_to_browser (GtkDialog *dialog, gint response_id, gpointer data)
 {
     char *directory_path, *destination_name;
     char *basename;
@@ -1309,8 +1315,6 @@ static void
 add_new_pattern (CajaPropertyBrowser *property_browser)
 {
     GtkWidget *dialog;
-    GtkFileFilter *filter;
-    GtkWidget *preview;
 
     if (property_browser->details->patterns_dialog)
     {
@@ -1318,6 +1322,9 @@ add_new_pattern (CajaPropertyBrowser *property_browser)
     }
     else
     {
+        GtkFileFilter *filter;
+        GtkWidget *preview;
+
         property_browser->details->patterns_dialog = dialog =
                     eel_file_chooser_dialog_new (_("Select an Image File to Add as a Pattern"),
                             GTK_WINDOW (property_browser),
@@ -1357,7 +1364,6 @@ add_color_to_file (CajaPropertyBrowser *property_browser, const char *color_spec
 {
     xmlNodePtr cur_node, new_color_node, children_node;
     xmlDocPtr document;
-    xmlChar *child_color_name;
     gboolean color_name_exists = FALSE;
 
     document = read_browser_xml (property_browser);
@@ -1374,6 +1380,8 @@ add_color_to_file (CajaPropertyBrowser *property_browser, const char *color_spec
         children_node = cur_node->xmlChildrenNode;
         while (children_node != NULL)
         {
+            xmlChar *child_color_name;
+
             child_color_name = xmlGetProp (children_node, "name");
             if (xmlStrcmp (color_name, child_color_name) == 0)
             {
@@ -1409,16 +1417,15 @@ add_color_to_file (CajaPropertyBrowser *property_browser, const char *color_spec
 
 /* handle the OK button being pushed on the color selection dialog */
 static void
-add_color_to_browser (GtkWidget *widget, gint which_button, gpointer *data)
+add_color_to_browser (GtkWidget *widget, gint which_button, gpointer data)
 {
-    char * color_spec;
-    const char *color_name;
-    char *stripped_color_name;
-
     CajaPropertyBrowser *property_browser = CAJA_PROPERTY_BROWSER (data);
 
     if (which_button == GTK_RESPONSE_OK)
     {
+        char * color_spec;
+        const char *color_name;
+        char *stripped_color_name;
         GdkColor color;
 
         gtk_color_button_get_color (GTK_COLOR_BUTTON (property_browser->details->color_picker), &color);
@@ -1448,10 +1455,10 @@ add_color_to_browser (GtkWidget *widget, gint which_button, gpointer *data)
 
 /* create the color selection dialog, pre-set with the color that was just selected */
 static void
-show_color_selection_window (GtkWidget *widget, gpointer *data)
+show_color_selection_window (GtkWidget *widget, gpointer data)
 {
     GdkColor color;
-    CajaPropertyBrowser *property_browser = CAJA_PROPERTY_BROWSER(data);
+    CajaPropertyBrowser *property_browser = CAJA_PROPERTY_BROWSER (data);
 
     gtk_color_selection_get_current_color (GTK_COLOR_SELECTION
                                            (gtk_color_selection_dialog_get_color_selection (GTK_COLOR_SELECTION_DIALOG (property_browser->details->colors_dialog))),
@@ -1513,14 +1520,14 @@ add_new_color (CajaPropertyBrowser *property_browser)
 static void
 emblem_dialog_clicked (GtkWidget *dialog, int which_button, CajaPropertyBrowser *property_browser)
 {
-    const char *new_keyword;
-    char *stripped_keyword;
     char *emblem_path;
-    GFile *emblem_file;
-    GdkPixbuf *pixbuf;
 
     if (which_button == GTK_RESPONSE_OK)
     {
+        const char *new_keyword;
+        char *stripped_keyword;
+        GFile *emblem_file;
+        GdkPixbuf *pixbuf;
 
         /* update the image path from the file entry */
         if (property_browser->details->filename)
@@ -1665,7 +1672,6 @@ static void
 help_button_callback (GtkWidget *widget, GtkWidget *property_browser)
 {
     GError *error = NULL;
-    GtkWidget *dialog;
 
     gtk_show_uri_on_window (GTK_WINDOW (property_browser),
                             "help:mate-user-guide/goscaja-50",
@@ -1673,6 +1679,8 @@ help_button_callback (GtkWidget *widget, GtkWidget *property_browser)
 
     if (error)
     {
+        GtkWidget *dialog;
+
         dialog = gtk_message_dialog_new (GTK_WINDOW (property_browser),
                                          GTK_DIALOG_DESTROY_WITH_PARENT,
                                          GTK_MESSAGE_ERROR,
@@ -1713,9 +1721,7 @@ element_clicked_callback (GtkWidget *image_table,
 {
     CajaPropertyBrowser *property_browser;
     GtkTargetList *target_list;
-    GdkDragContext *context;
     const char *element_name;
-    GdkDragAction action;
 
     g_return_if_fail (EEL_IS_IMAGE_TABLE (image_table));
     g_return_if_fail (EEL_IS_LABELED_IMAGE (child));
@@ -1747,15 +1753,17 @@ element_clicked_callback (GtkWidget *image_table,
 
     target_list = gtk_target_list_new (drag_types, G_N_ELEMENTS (drag_types));
     caja_property_browser_set_dragged_file(property_browser, element_name);
-    action = event->button == 3 ? GDK_ACTION_ASK : GDK_ACTION_MOVE | GDK_ACTION_COPY;
 
     g_object_set_data (G_OBJECT (property_browser), "dragged-image", child);
 
-    context = gtk_drag_begin (GTK_WIDGET (property_browser),
-                              target_list,
-                              GDK_ACTION_ASK | GDK_ACTION_MOVE | GDK_ACTION_COPY,
-                              event->button,
-                              event->event);
+    gtk_drag_begin_with_coordinates (GTK_WIDGET (property_browser),
+                                     target_list,
+                                     GDK_ACTION_ASK | GDK_ACTION_MOVE | GDK_ACTION_COPY,
+                                     event->button,
+                                     event->event,
+                                     event->x,
+                                     event->y);
+
     gtk_target_list_unref (target_list);
 
     /* optionally (if the shift key is down) hide the property browser - it will later be destroyed when the drag ends */
@@ -1800,20 +1808,14 @@ labeled_image_new (const char *text,
 static void
 make_properties_from_directories (CajaPropertyBrowser *property_browser)
 {
-    CajaCustomizationData *customization_data;
     char *object_name;
     char *object_label;
     GdkPixbuf *object_pixbuf;
     EelImageTable *image_table;
     GtkWidget *reset_object = NULL;
     GList *icons, *l;
-    char *icon_name;
-    char *keyword;
     GtkWidget *property_image;
-    GtkWidget *blank;
     guint num_images;
-    char *path;
-    CajaIconInfo *info;
 
     g_return_if_fail (CAJA_IS_PROPERTY_BROWSER (property_browser));
     g_return_if_fail (EEL_IS_IMAGE_TABLE (property_browser->details->content_table));
@@ -1822,6 +1824,8 @@ make_properties_from_directories (CajaPropertyBrowser *property_browser)
 
     if (property_browser->details->category_type == CAJA_PROPERTY_EMBLEM)
     {
+        CajaIconInfo *info = NULL;
+
         g_list_free_full (property_browser->details->keywords, g_free);
         property_browser->details->keywords = NULL;
 
@@ -1831,6 +1835,9 @@ make_properties_from_directories (CajaPropertyBrowser *property_browser)
         l = icons;
         while (l != NULL)
         {
+            char *icon_name;
+            char *keyword;
+
             icon_name = (char *)l->data;
             l = l->next;
 
@@ -1880,6 +1887,8 @@ make_properties_from_directories (CajaPropertyBrowser *property_browser)
     }
     else
     {
+        CajaCustomizationData *customization_data;
+
         customization_data = caja_customization_data_new (property_browser->details->category,
                              !property_browser->details->remove_mode,
                              MAX_ICON_WIDTH,
@@ -1928,6 +1937,9 @@ make_properties_from_directories (CajaPropertyBrowser *property_browser)
      */
     if (property_browser->details->category_type == CAJA_PROPERTY_EMBLEM)
     {
+        GtkWidget *blank;
+        char *path;
+
         blank = eel_image_table_add_empty_image (image_table);
         labeled_image_configure (EEL_LABELED_IMAGE (blank));
 
@@ -2184,7 +2196,6 @@ caja_property_browser_update_contents (CajaPropertyBrowser *property_browser)
     GtkRadioButton *group;
     gboolean got_categories;
     char *name, *image, *type, *description, *display_name, *path, *mode;
-    const char *text;
 
     /* load the xml document corresponding to the path and selection */
     document = read_browser_xml (property_browser);
@@ -2304,8 +2315,10 @@ caja_property_browser_update_contents (CajaPropertyBrowser *property_browser)
     }
     else
     {
+        const char *text;
         char *label_text;
         char *icon_name;
+
         if (property_browser->details->remove_mode)
         {
             icon_name = "process-stop";
