@@ -22,20 +22,23 @@
  */
 
 #include <config.h>
-#include "caja-query-editor.h"
-#include "caja-src-marshal.h"
-#include "caja-window-slot.h"
-
 #include <string.h>
+
 #include <glib/gi18n.h>
 #include <gio/gio.h>
+#include <gdk/gdkkeysyms.h>
+#include <gtk/gtk.h>
+
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-stock-dialogs.h>
-#include <gdk/gdkkeysyms.h>
-#include <gtk/gtk.h>
+
 #include <libcaja-private/caja-global-preferences.h>
 
+#include "caja-query-editor.h"
+#include "caja-src-marshal.h"
+#include "caja-window-slot.h"
+
 enum
 {
         DURATION_INVALID,
@@ -54,6 +57,7 @@ typedef enum
     CAJA_QUERY_EDITOR_ROW_TAGS,
     CAJA_QUERY_EDITOR_ROW_TIME_MODIFIED,
     CAJA_QUERY_EDITOR_ROW_SIZE,
+    CAJA_QUERY_EDITOR_ROW_CONTAINED_TEXT,
 
     CAJA_QUERY_EDITOR_ROW_LAST
 } CajaQueryEditorRowType;
@@ -154,6 +158,13 @@ static void         size_row_free_data(CajaQueryEditorRow *row);
 static void         size_add_rows_from_query(CajaQueryEditor *editor,
                                              CajaQuery *query);
 
+static GtkWidget   *contained_text_row_create_widgets(CajaQueryEditorRow *row);
+static void         contained_text_row_add_to_query(CajaQueryEditorRow *row,
+                                             CajaQuery *query);
+static void         contained_text_row_free_data(CajaQueryEditorRow *row);
+static void         contained_text_add_rows_from_query(CajaQueryEditor *editor,
+                                                CajaQuery *query);
+
 static CajaQueryEditorRowOps row_type[] =
 {
     {
@@ -190,6 +201,13 @@ static CajaQueryEditorRowOps row_type[] =
         size_row_add_to_query,
         size_row_free_data,
         size_add_rows_from_query
+    },
+    {
+        N_("Contained text"),
+        contained_text_row_create_widgets,
+        contained_text_row_add_to_query,
+        contained_text_row_free_data,
+        contained_text_add_rows_from_query
     }
 };
 
@@ -980,7 +998,6 @@ type_add_rows_from_query (CajaQueryEditor    *editor,
 {
     GList *mime_types;
     char *mime_type;
-    const char *desc;
     CajaQueryEditorRow *row;
     GtkTreeIter iter;
     int i;
@@ -1015,6 +1032,8 @@ type_add_rows_from_query (CajaQueryEditor    *editor,
 
     for (l = mime_types; l != NULL; l = l->next)
     {
+        const char *desc;
+
         mime_type = l->data;
 
         desc = g_content_type_get_description (mime_type);
@@ -1319,6 +1338,41 @@ static void size_add_rows_from_query(CajaQueryEditor *editor, CajaQuery *query)
 {
 }
 
+static GtkWidget *
+contained_text_row_create_widgets (CajaQueryEditorRow *row)
+{
+    GtkWidget *entry = gtk_entry_new();
+    gtk_widget_set_tooltip_text (entry,
+        _("Matches files that contains specified text."));
+
+    gtk_entry_set_placeholder_text (GTK_ENTRY (entry),
+        _("Matches files that contains specified text."));
+
+    gtk_widget_show (entry);
+    gtk_box_pack_start (GTK_BOX (row->hbox), entry, TRUE, TRUE, 0);
+    g_signal_connect (entry, "activate", G_CALLBACK (go_search_cb), row->editor);
+
+    return entry;
+}
+
+static void
+contained_text_row_add_to_query (CajaQueryEditorRow *row, CajaQuery *query)
+{
+    GtkEntry *entry = GTK_ENTRY (row->type_widget);
+    const gchar *text = gtk_entry_get_text (entry);
+
+    caja_query_set_contained_text (query, text);
+}
+
+static void
+contained_text_row_free_data (CajaQueryEditorRow *row)
+{
+}
+
+static void
+contained_text_add_rows_from_query (CajaQueryEditor *editor, CajaQuery *query)
+{
+}
 
 static CajaQueryEditorRowType
 get_next_free_type (CajaQueryEditor *editor)
@@ -1648,8 +1702,6 @@ query_is_valid (CajaQueryEditor *editor)
 static void
 caja_query_editor_changed_force (CajaQueryEditor *editor, gboolean force_reload)
 {
-    CajaQuery *query;
-
     if (editor->details->change_frozen)
     {
         return;
@@ -1657,6 +1709,8 @@ caja_query_editor_changed_force (CajaQueryEditor *editor, gboolean force_reload)
 
     if (query_is_valid (editor))
     {
+        CajaQuery *query;
+
         query = caja_query_editor_get_query (editor);
         g_signal_emit (editor, signals[CHANGED], 0,
                        query, editor->details->is_indexed || force_reload);
@@ -1685,7 +1739,7 @@ caja_query_editor_get_query (CajaQueryEditor *editor)
     const char *query_text;
     CajaQuery *query;
     GList *l;
-    CajaQueryEditorRow *row;
+    CajaQueryEditorRow *row = NULL;
 
     if (editor == NULL || editor->details == NULL || editor->details->entry == NULL)
     {
