@@ -22,16 +22,16 @@
  */
 
 #include <config.h>
-#include "caja-search-bar.h"
 
 #include <glib/gi18n.h>
-#include <eel/eel-gtk-macros.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
-#endif
+#include <eel/eel-gtk-macros.h>
+
+#include <libcaja-private/caja-clipboard.h>
+
+#include "caja-search-bar.h"
 
 struct CajaSearchBarDetails
 {
@@ -154,42 +154,23 @@ focus_in_event_callback (GtkWidget *widget,
 static void
 caja_search_bar_init (CajaSearchBar *bar)
 {
-#if !GTK_CHECK_VERSION(3, 0, 0)
-    GtkWidget *alignment;
-#endif
     GtkWidget *hbox;
     GtkWidget *label;
-#if GTK_CHECK_VERSION(3, 0, 0)
     GtkStyleContext *context;
 
     context = gtk_widget_get_style_context (GTK_WIDGET (bar));
     gtk_style_context_add_class (context, "caja-search-bar");
-#endif
 
     bar->details = g_new0 (CajaSearchBarDetails, 1);
 
     gtk_event_box_set_visible_window (GTK_EVENT_BOX (bar), FALSE);
 
-#if GTK_CHECK_VERSION(3, 0, 0)
-    hbox = gtk_hbox_new (FALSE, 6);
+    hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
     gtk_widget_set_margin_start (hbox, 6);
     gtk_widget_set_margin_end (hbox, 6);
     gtk_widget_show (hbox);
     gtk_container_add (GTK_CONTAINER (bar), hbox);
 
-#else
-    alignment = gtk_alignment_new (0.5, 0.5,
-                                   1.0, 1.0);
-    gtk_alignment_set_padding (GTK_ALIGNMENT (alignment),
-                               0, 0, 6, 6);
-    gtk_widget_show (alignment);
-    gtk_container_add (GTK_CONTAINER (bar), alignment);
-
-    hbox = gtk_hbox_new (FALSE, 6);
-    gtk_widget_show (hbox);
-    gtk_container_add (GTK_CONTAINER (alignment), hbox);
-#endif
-
     label = gtk_label_new (_("Search:"));
     gtk_widget_show (label);
 
@@ -235,11 +216,19 @@ caja_search_bar_return_entry (CajaSearchBar *bar)
 }
 
 GtkWidget *
-caja_search_bar_new (void)
+caja_search_bar_new (CajaWindow *window)
 {
     GtkWidget *bar;
+    CajaSearchBar *search_bar;
 
     bar = g_object_new (CAJA_TYPE_SEARCH_BAR, NULL);
+    search_bar = CAJA_SEARCH_BAR(bar);
+
+    /* Clipboard */
+    caja_clipboard_set_up_editable
+    (GTK_EDITABLE (search_bar->details->entry),
+     caja_window_get_ui_manager (window),
+     FALSE);
 
     return bar;
 }
