@@ -26,9 +26,7 @@
 
 #include <gtk/gtk.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+G_BEGIN_DECLS
 
 #define CAJA_TYPE_SIDE_PANE caja_side_pane_get_type()
 #define CAJA_SIDE_PANE(obj) \
@@ -42,25 +40,17 @@ extern "C" {
 #define CAJA_SIDE_PANE_GET_CLASS(obj) \
   (G_TYPE_INSTANCE_GET_CLASS ((obj), CAJA_TYPE_SIDE_PANE, CajaSidePaneClass))
 
-    typedef struct _CajaSidePaneDetails CajaSidePaneDetails;
+    typedef struct _CajaSidePanePrivate CajaSidePanePrivate;
 
     typedef struct
     {
-#if GTK_CHECK_VERSION (3, 0, 0)
         GtkBox parent;
-#else
-        GtkVBox parent;
-#endif
-        CajaSidePaneDetails *details;
+        CajaSidePanePrivate *details;
     } CajaSidePane;
 
     typedef struct
     {
-#if GTK_CHECK_VERSION (3, 0, 0)
         GtkBoxClass parent_slot;
-#else
-        GtkVBoxClass parent_slot;
-#endif
 
         void (*close_requested) (CajaSidePane *side_pane);
         void (*switch_page) (CajaSidePane *side_pane,
@@ -83,8 +73,6 @@ extern "C" {
     GtkWidget             *caja_side_pane_get_current_panel (CajaSidePane *side_pane);
     GtkWidget             *caja_side_pane_get_title        (CajaSidePane *side_pane);
 
-#ifdef __cplusplus
-}
-#endif
+G_END_DECLS
 
 #endif /* CAJA_SIDE_PANE_H */
