@@ -26,24 +26,26 @@
 
 #include <config.h>
 #include <math.h>
-#include "caja-sidebar-title.h"
+#include <string.h>
+#include <stdlib.h>
 
-#include "caja-window.h"
+#include <gtk/gtk.h>
+#include <pango/pango.h>
+#include <glib/gi18n.h>
 
 #include <eel/eel-background.h>
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-extensions.h>
-#include <gtk/gtk.h>
-#include <pango/pango.h>
-#include <glib/gi18n.h>
+
 #include <libcaja-private/caja-file-attributes.h>
 #include <libcaja-private/caja-global-preferences.h>
 #include <libcaja-private/caja-metadata.h>
 #include <libcaja-private/caja-sidebar.h>
-#include <string.h>
-#include <stdlib.h>
+
+#include "caja-sidebar-title.h"
+#include "caja-window.h"
 
 /* maximum allowable size to be displayed as the title */
 #define MAX_TITLE_SIZE 		256
@@ -80,7 +82,7 @@ enum
     LAST_LABEL_COLOR
 };
 
-struct CajaSidebarTitleDetails
+struct _CajaSidebarTitlePrivate
 {
     CajaFile		*file;
     guint		 file_changed_connection;
@@ -97,7 +99,7 @@ struct CajaSidebarTitleDetails
     gboolean		 determined_icon;
 };
 
-G_DEFINE_TYPE (CajaSidebarTitle, caja_sidebar_title, GTK_TYPE_BOX)
+G_DEFINE_TYPE_WITH_PRIVATE (CajaSidebarTitle, caja_sidebar_title, GTK_TYPE_BOX)
 
 static void
 style_updated (GtkWidget *widget)
@@ -116,9 +118,7 @@ style_updated (GtkWidget *widget)
 static void
 caja_sidebar_title_init (CajaSidebarTitle *sidebar_title)
 {
-    sidebar_title->details = G_TYPE_INSTANCE_GET_PRIVATE (sidebar_title,
-    							  CAJA_TYPE_SIDEBAR_TITLE,
-    							  CajaSidebarTitleDetails);
+    sidebar_title->details = caja_sidebar_title_get_instance_private (sidebar_title);
 
     gtk_orientable_set_orientation (GTK_ORIENTABLE (sidebar_title), GTK_ORIENTATION_VERTICAL);
 
@@ -220,8 +220,6 @@ caja_sidebar_title_class_init (CajaSidebarTitleClass *klass)
                                 "Color used for information text against a light background",
                                 GDK_TYPE_RGBA,
                                 G_PARAM_READABLE));
-
-    g_type_class_add_private (klass, sizeof (CajaSidebarTitleDetails));
 }
 
 /* return a new index title object */
@@ -264,7 +262,7 @@ caja_sidebar_title_select_text_color (CajaSidebarTitle *sidebar_title,
 
     if (!dark_info_color)
     {
-        light_info_color = g_malloc (sizeof (GdkRGBA));
+        dark_info_color = g_malloc (sizeof (GdkRGBA));
         gdk_rgba_parse (dark_info_color, DEFAULT_DARK_INFO_COLOR);
     }
 
@@ -366,35 +364,37 @@ get_best_icon_size (CajaSidebarTitle *sidebar_title)
 static void
 update_icon (CajaSidebarTitle *sidebar_title)
 {
-    GdkPixbuf *pixbuf;
-    CajaIconInfo *info;
+    cairo_surface_t *surface;
     char *icon_name;
-    gboolean leave_pixbuf_unchanged;
+    gboolean leave_surface_unchanged;
     gint icon_scale;
 
-    leave_pixbuf_unchanged = FALSE;
+    leave_surface_unchanged = FALSE;
 
     /* see if the current content view is specifying an icon */
     icon_name = get_property_from_component (sidebar_title, "icon_name");
     icon_scale = gtk_widget_get_scale_factor (GTK_WIDGET (sidebar_title));
 
-    pixbuf = NULL;
+    surface = NULL;
+
     if (icon_name != NULL && icon_name[0] != '\0')
     {
+        CajaIconInfo *info;
+
         info = caja_icon_info_lookup_from_name (icon_name, CAJA_ICON_SIZE_LARGE, icon_scale);
-        pixbuf = caja_icon_info_get_pixbuf_at_size (info,  CAJA_ICON_SIZE_LARGE);
+        surface = caja_icon_info_get_surface_at_size (info, CAJA_ICON_SIZE_LARGE);
         g_object_unref (info);
     }
     else if (sidebar_title->details->file != NULL &&
              caja_file_check_if_ready (sidebar_title->details->file,
                                        CAJA_FILE_ATTRIBUTES_FOR_ICON))
     {
-        pixbuf = caja_file_get_icon_pixbuf (sidebar_title->details->file,
-                                            sidebar_title->details->best_icon_size,
-                                            TRUE,
-                                            icon_scale,
-                                            CAJA_FILE_ICON_FLAGS_USE_THUMBNAILS |
-                                            CAJA_FILE_ICON_FLAGS_USE_MOUNT_ICON_AS_EMBLEM);
+        surface = caja_file_get_icon_surface (sidebar_title->details->file,
+                                              sidebar_title->details->best_icon_size * icon_scale,
+                                              TRUE,
+                                              icon_scale,
+                                              CAJA_FILE_ICON_FLAGS_USE_THUMBNAILS |
+                                              CAJA_FILE_ICON_FLAGS_USE_MOUNT_ICON_AS_EMBLEM);
     }
     else if (sidebar_title->details->determined_icon)
     {
@@ -404,20 +404,20 @@ update_icon (CajaSidebarTitle *sidebar_title)
          * wrong (in fact, in practice it usually doesn't mean that). Keep showing
          * the one we last determined for now.
          */
-        leave_pixbuf_unchanged = TRUE;
+        leave_surface_unchanged = TRUE;
     }
 
     g_free (icon_name);
 
-    if (!leave_pixbuf_unchanged)
+    if (!leave_surface_unchanged)
     {
-        gtk_image_set_from_pixbuf (GTK_IMAGE (sidebar_title->details->icon), pixbuf);
+        gtk_image_set_from_surface (GTK_IMAGE (sidebar_title->details->icon), surface);
     }
 
-    if (pixbuf != NULL)
+    if (surface != NULL)
     {
         sidebar_title->details->determined_icon = TRUE;
-        g_object_unref (pixbuf);
+        cairo_surface_destroy (surface);
     }
 }
 
@@ -437,7 +437,7 @@ override_title_font (GtkWidget   *widget,
     g_strreverse (tempsize);
 
     gchar tempfont [strlen (font)];
-    strcpy (tempfont, font);
+    g_strlcpy (tempfont, font, sizeof (tempfont));
     tempfont [strlen (font) - strlen (tempsize)] = 0;
 
     css = g_strdup_printf ("label { font-family: %s; font-size: %spt; }", tempfont, tempsize);
@@ -563,10 +563,7 @@ update_more_info (CajaSidebarTitle *sidebar_title)
 {
     CajaFile *file;
     GString *info_string;
-    char *type_string, *component_info;
-    char *date_modified_str;
-    int sidebar_width;
-    PangoLayout *layout;
+    char *component_info;
     GtkAllocation allocation;
 
     file = sidebar_title->details->file;
@@ -580,9 +577,13 @@ update_more_info (CajaSidebarTitle *sidebar_title)
     }
     else
     {
+        char *type_string;
+        int sidebar_width;
+
         info_string = g_string_new (NULL);
 
         type_string = NULL;
+
         if (file != NULL && caja_file_should_show_type (file))
         {
             type_string = caja_file_get_string_attribute (file, "type");
@@ -604,6 +605,9 @@ update_more_info (CajaSidebarTitle *sidebar_title)
         sidebar_width = allocation.width - 2 * SIDEBAR_INFO_MARGIN;
         if (sidebar_width > MINIMUM_INFO_WIDTH)
         {
+            char *date_modified_str;
+            PangoLayout *layout;
+
             layout = pango_layout_copy (gtk_label_get_layout (GTK_LABEL (sidebar_title->details->more_info_label)));
             pango_layout_set_width (layout, -1);
             date_modified_str = caja_file_fit_modified_date_as_string
@@ -633,7 +637,7 @@ static void
 update_emblems (CajaSidebarTitle *sidebar_title)
 {
     GList *pixbufs, *p;
-    GdkPixbuf *pixbuf;
+    GdkPixbuf *pixbuf = NULL;
 
     /* exit if we don't have the file yet */
     if (sidebar_title->details->file == NULL)
