@@ -28,26 +28,16 @@
 /* caja-window.c: Implementation of the main window object */
 
 #include <config.h>
-#include "caja-spatial-window.h"
-#include "caja-window-private.h"
-#include "caja-window-bookmarks.h"
 
-#include "caja-actions.h"
-#include "caja-application.h"
-#include "caja-desktop-window.h"
-#include "caja-bookmarks-window.h"
-#include "caja-location-dialog.h"
-#include "caja-query-editor.h"
-#include "caja-search-bar.h"
-#include "caja-window-manage-views.h"
-#include <eel/eel-gtk-extensions.h>
-#include <eel/eel-gtk-macros.h>
-#include <eel/eel-string.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+
+#include <eel/eel-gtk-extensions.h>
+#include <eel/eel-gtk-macros.h>
+#include <eel/eel-string.h>
+
 #include <libcaja-private/caja-dnd.h>
 #include <libcaja-private/caja-file-utilities.h>
 #include <libcaja-private/caja-ui-utilities.h>
@@ -60,6 +50,18 @@
 #include <libcaja-private/caja-search-engine.h>
 #include <libcaja-private/caja-signaller.h>
 
+#include "caja-spatial-window.h"
+#include "caja-window-private.h"
+#include "caja-window-bookmarks.h"
+#include "caja-actions.h"
+#include "caja-application.h"
+#include "caja-desktop-window.h"
+#include "caja-bookmarks-window.h"
+#include "caja-location-dialog.h"
+#include "caja-query-editor.h"
+#include "caja-search-bar.h"
+#include "caja-window-manage-views.h"
+
 #define MAX_TITLE_LENGTH 180
 #define MAX_SHORTNAME_PATH 16
 
@@ -69,7 +71,7 @@
 #define SPATIAL_ACTION_CLOSE_ALL_FOLDERS    "Close All Folders"
 #define MENU_PATH_SPATIAL_BOOKMARKS_PLACEHOLDER	"/MenuBar/Other Menus/Places/Bookmarks Placeholder"
 
-struct _CajaSpatialWindowDetails
+struct _CajaSpatialWindowPrivate
 {
     GtkActionGroup *spatial_action_group; /* owned by ui_manager */
     char *last_geometry;
@@ -88,8 +90,7 @@ static const GtkTargetEntry location_button_drag_types[] =
     { CAJA_ICON_DND_URI_LIST_TYPE, 0, CAJA_ICON_DND_URI_LIST },
 };
 
-G_DEFINE_TYPE(CajaSpatialWindow, caja_spatial_window, CAJA_TYPE_WINDOW)
-#define parent_class caja_spatial_window_parent_class
+G_DEFINE_TYPE_WITH_PRIVATE (CajaSpatialWindow, caja_spatial_window, CAJA_TYPE_WINDOW)
 
 static void caja_spatial_window_save_geometry (CajaSpatialWindow *window,
 						   CajaFile *viewed_file);
@@ -283,7 +284,6 @@ static void
 caja_spatial_window_save_show_hidden_files_mode (CajaSpatialWindow *window,
 						 CajaFile *viewed_file)
 {
-    char *show_hidden_file_setting;
     CajaWindowShowHiddenFilesMode mode;
 
     if (viewed_file == NULL) {
@@ -293,6 +293,8 @@ caja_spatial_window_save_show_hidden_files_mode (CajaSpatialWindow *window,
     mode = CAJA_WINDOW (window)->details->show_hidden_files_mode;
 
     if (mode != CAJA_WINDOW_SHOW_HIDDEN_FILES_DEFAULT) {
+        char *show_hidden_file_setting;
+
         if (mode == CAJA_WINDOW_SHOW_HIDDEN_FILES_ENABLE) {
             show_hidden_file_setting = "1";
         } else {
@@ -392,6 +394,10 @@ sync_window_title (CajaWindow *window)
 
     slot = caja_window_get_active_slot (window);
 
+    /* Don't change desktop's title, it would override the one already defined */
+    if (CAJA_IS_DESKTOP_WINDOW (window))
+        return;
+
     if (slot->title == NULL || slot->title[0] == '\0')
     {
         gtk_window_set_title (GTK_WINDOW (window), _("Caja"));
@@ -457,9 +463,11 @@ real_set_allow_up (CajaWindow *window, gboolean allow)
 
     spatial = CAJA_SPATIAL_WINDOW (window);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action = gtk_action_group_get_action (spatial->details->spatial_action_group,
                                           SPATIAL_ACTION_CLOSE_PARENT_FOLDERS);
     gtk_action_set_sensitive (action, allow);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     CAJA_WINDOW_CLASS (caja_spatial_window_parent_class)->set_allow_up (window, allow);
 }
@@ -597,32 +605,6 @@ menu_deactivate_callback (GtkWidget *menu,
     }
 }
 
-static void
-menu_popup_pos (GtkMenu   *menu,
-                gint      *x,
-                gint      *y,
-                gboolean  *push_in,
-                gpointer	user_data)
-{
-    GtkWidget *widget;
-    GtkRequisition menu_requisition, button_requisition;
-    GtkAllocation allocation;
-
-    widget = user_data;
-
-    gtk_widget_get_preferred_size (GTK_WIDGET (menu), &menu_requisition, NULL);
-    gtk_widget_get_preferred_size (widget, &button_requisition, NULL);
-    gtk_widget_get_allocation (widget, &allocation);
-
-    gdk_window_get_origin (gtk_widget_get_window (widget), x, y);
-    *x += allocation.x;
-    *y += allocation.y;
-
-    *y -= menu_requisition.height - button_requisition.height;
-
-    *push_in = TRUE;
-}
-
 static gboolean
 location_button_pressed_callback (GtkWidget      *widget,
                                   GdkEventButton *event,
@@ -648,7 +630,7 @@ location_button_clicked_callback (GtkWidget         *widget,
 {
     CajaWindowSlot *slot;
     GtkWidget *popup, *menu_item, *first_item = NULL;
-    GdkPixbuf *pixbuf;
+    cairo_surface_t *surface = NULL;
     GFile *location;
     GFile *child_location;
     GMainLoop *loop;
@@ -673,18 +655,18 @@ location_button_clicked_callback (GtkWidget         *widget,
 
         name = caja_file_get_display_name (file);
 
-        pixbuf = NULL;
+        surface = NULL;
 
-        pixbuf = caja_file_get_icon_pixbuf (file,
-                                            caja_get_icon_size_for_stock_size (GTK_ICON_SIZE_MENU),
-                                            TRUE,
-                                            gtk_widget_get_scale_factor (widget),
-                                            CAJA_FILE_ICON_FLAGS_IGNORE_VISITING);
+        surface = caja_file_get_icon_surface (file,
+                                              caja_get_icon_size_for_stock_size (GTK_ICON_SIZE_MENU),
+                                              TRUE,
+                                              gtk_widget_get_scale_factor (widget),
+                                              CAJA_FILE_ICON_FLAGS_IGNORE_VISITING);
 
-        if (pixbuf != NULL)
+        if (surface != NULL)
         {
-            menu_item = eel_image_menu_item_new_from_pixbuf (pixbuf, name);
-            g_object_unref (pixbuf);
+            menu_item = eel_image_menu_item_new_from_surface (surface, name);
+            cairo_surface_destroy (surface);
         }
         else
         {
@@ -737,7 +719,12 @@ location_button_clicked_callback (GtkWidget         *widget,
                       loop);
 
     gtk_grab_add (popup);
-    gtk_menu_popup (GTK_MENU (popup), NULL, NULL, menu_popup_pos, widget, 1, GDK_CURRENT_TIME);
+    gtk_menu_popup_at_widget (GTK_MENU (popup),
+                              widget,
+                              GDK_GRAVITY_SOUTH_WEST,
+                              GDK_GRAVITY_NORTH_WEST,
+                              NULL);
+
     gtk_menu_shell_select_item (GTK_MENU_SHELL (popup), first_item);
     g_main_loop_run (loop);
     gtk_grab_remove (popup);
@@ -773,19 +760,19 @@ location_button_drag_begin_callback (GtkWidget             *widget,
                                      CajaSpatialWindow *window)
 {
     CajaWindowSlot *slot;
-    GdkPixbuf *pixbuf;
+    cairo_surface_t *surface;
 
     slot = CAJA_WINDOW (window)->details->active_pane->active_slot;
 
-    pixbuf = caja_file_get_icon_pixbuf (slot->viewed_file,
-                                        get_dnd_icon_size (window),
-                                        FALSE,
-                                        gtk_widget_get_scale_factor (widget),
-                                        CAJA_FILE_ICON_FLAGS_IGNORE_VISITING | CAJA_FILE_ICON_FLAGS_FOR_DRAG_ACCEPT);
+    surface = caja_file_get_icon_surface (slot->viewed_file,
+                                          get_dnd_icon_size (window),
+                                          FALSE,
+                                          gtk_widget_get_scale_factor (widget),
+                                          CAJA_FILE_ICON_FLAGS_IGNORE_VISITING | CAJA_FILE_ICON_FLAGS_FOR_DRAG_ACCEPT);
 
-    gtk_drag_set_icon_pixbuf (context, pixbuf, 0, 0);
+    gtk_drag_set_icon_surface (context, surface);
 
-    g_object_unref (pixbuf);
+    cairo_surface_destroy (surface);
 }
 
 /* build MATE icon list, which only contains the window's URI.
@@ -853,18 +840,18 @@ caja_spatial_window_set_location_button  (CajaSpatialWindow *window,
         error = caja_file_get_file_info_error (file);
         if (error == NULL)
         {
-            GdkPixbuf *pixbuf;
+            cairo_surface_t *surface;
 
-            pixbuf = caja_file_get_icon_pixbuf (file,
-                                                caja_get_icon_size_for_stock_size (GTK_ICON_SIZE_MENU),
-                                                TRUE,
-                                                gtk_widget_get_scale_factor (window->details->location_button),
-                                                CAJA_FILE_ICON_FLAGS_IGNORE_VISITING);
+            surface = caja_file_get_icon_surface (file,
+                                                  caja_get_icon_size_for_stock_size (GTK_ICON_SIZE_MENU),
+                                                  TRUE,
+                                                  gtk_widget_get_scale_factor (window->details->location_button),
+                                                  CAJA_FILE_ICON_FLAGS_IGNORE_VISITING);
 
-            if (pixbuf != NULL)
+            if (surface != NULL)
             {
-                gtk_image_set_from_pixbuf (GTK_IMAGE (window->details->location_icon),  pixbuf);
-                g_object_unref (pixbuf);
+                gtk_image_set_from_surface (GTK_IMAGE (window->details->location_icon), surface);
+                cairo_surface_destroy (surface);
             }
             else
             {
@@ -964,15 +951,6 @@ static const GtkActionEntry spatial_entries[] =
     },
 };
 
-static const char* icon_entries[] =
-{
-    "/MenuBar/Other Menus/Places/Home",
-    "/MenuBar/Other Menus/Places/Go to Computer",
-    "/MenuBar/Other Menus/Places/Go to Templates",
-    "/MenuBar/Other Menus/Places/Go to Trash",
-    "/MenuBar/Other Menus/Places/Go to Network"
-};
-
 static void
 caja_spatial_window_init (CajaSpatialWindow *window)
 {
@@ -982,14 +960,10 @@ caja_spatial_window_init (CajaSpatialWindow *window)
     GtkUIManager *ui_manager;
     GtkTargetList *targets;
     const char *ui;
-    int i;
-    GtkWidget *menuitem;
     CajaWindow *win;
     CajaWindowPane *pane;
 
-    window->details = G_TYPE_INSTANCE_GET_PRIVATE (window,
-                      CAJA_TYPE_SPATIAL_WINDOW,
-                      CajaSpatialWindowDetails);
+    window->details = caja_spatial_window_get_instance_private (window);
 
     win = CAJA_WINDOW (window);
 
@@ -1069,12 +1043,14 @@ caja_spatial_window_init (CajaSpatialWindow *window)
     gtk_box_reorder_child (GTK_BOX (CAJA_WINDOW (window)->details->statusbar),
                            window->details->location_button, 0);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action_group = gtk_action_group_new ("SpatialActions");
     gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
     window->details->spatial_action_group = action_group;
     gtk_action_group_add_actions (action_group,
                                   spatial_entries, G_N_ELEMENTS (spatial_entries),
                                   window);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     ui_manager = caja_window_get_ui_manager (CAJA_WINDOW (window));
     gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
@@ -1083,10 +1059,6 @@ caja_spatial_window_init (CajaSpatialWindow *window)
     ui = caja_ui_string_get ("caja-spatial-window-ui.xml");
     gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, NULL);
 
-    for (i = 0; i < G_N_ELEMENTS (icon_entries); i++)
-    {
-        menuitem = gtk_ui_manager_get_widget (ui_manager, icon_entries[i]);
-    }
     caja_window_set_active_pane (win, pane);
 }
 
@@ -1124,6 +1096,4 @@ caja_spatial_window_class_init (CajaSpatialWindowClass *klass)
 	gtk_binding_entry_add_signal (binding_set, GDK_KEY_Up, GDK_SHIFT_MASK | GDK_MOD1_MASK,
                                   "go_up", 1,
                                   G_TYPE_BOOLEAN, TRUE);
-
-	g_type_class_add_private (klass, sizeof(CajaSpatialWindowDetails));
 }
