@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 
 /*
  *  Caja
@@ -26,19 +26,11 @@
  */
 
 #include <config.h>
-#include "caja-window-manage-views.h"
 
-#include "caja-actions.h"
-#include "caja-application.h"
-#include "caja-location-bar.h"
-#include "caja-search-bar.h"
-#include "caja-pathbar.h"
-#include "caja-window-private.h"
-#include "caja-window-slot.h"
-#include "caja-navigation-window-slot.h"
-#include "caja-trash-bar.h"
-#include "caja-x-content-bar.h"
-#include "caja-navigation-window-pane.h"
+#include <gtk/gtk.h>
+#include <gdk/gdkx.h>
+#include <glib/gi18n.h>
+
 #include <eel/eel-accessibility.h>
 #include <eel/eel-debug.h>
 #include <eel/eel-gdk-extensions.h>
@@ -48,10 +40,7 @@
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
-#include <gtk/gtk.h>
-#include <gdk/gdkx.h>
-#include <glib/gi18n.h>
-#include <libcaja-extension/caja-location-widget-provider.h>
+
 #include <libcaja-private/caja-debug-log.h>
 #include <libcaja-private/caja-extensions.h>
 #include <libcaja-private/caja-file-attributes.h>
@@ -68,6 +57,21 @@
 #include <libcaja-private/caja-window-slot-info.h>
 #include <libcaja-private/caja-autorun.h>
 
+#include <libcaja-extension/caja-location-widget-provider.h>
+
+#include "caja-window-manage-views.h"
+#include "caja-actions.h"
+#include "caja-application.h"
+#include "caja-location-bar.h"
+#include "caja-search-bar.h"
+#include "caja-pathbar.h"
+#include "caja-window-private.h"
+#include "caja-window-slot.h"
+#include "caja-navigation-window-slot.h"
+#include "caja-trash-bar.h"
+#include "caja-x-content-bar.h"
+#include "caja-navigation-window-pane.h"
+
 /* FIXME bugzilla.gnome.org 41243:
  * We should use inheritance instead of these special cases
  * for the desktop window.
@@ -125,9 +129,7 @@ caja_window_report_selection_changed (CajaWindowInfo *window)
 static void
 set_displayed_location (CajaWindowSlot *slot, GFile *location)
 {
-    GFile *bookmark_location;
     gboolean recreate;
-    char *name;
 
     if (slot->current_location_bookmark == NULL || location == NULL)
     {
@@ -135,6 +137,8 @@ set_displayed_location (CajaWindowSlot *slot, GFile *location)
     }
     else
     {
+        GFile *bookmark_location;
+
         bookmark_location = caja_bookmark_get_location (slot->current_location_bookmark);
         recreate = !g_file_equal (bookmark_location, location);
         g_object_unref (bookmark_location);
@@ -142,6 +146,8 @@ set_displayed_location (CajaWindowSlot *slot, GFile *location)
 
     if (recreate)
     {
+        char *name;
+
         /* We've changed locations, must recreate bookmark for current location. */
         if (slot->last_location_bookmark != NULL)
         {
@@ -159,11 +165,12 @@ static void
 check_bookmark_location_matches (CajaBookmark *bookmark, GFile *location)
 {
     GFile *bookmark_location;
-    char *bookmark_uri, *uri;
 
     bookmark_location = caja_bookmark_get_location (bookmark);
     if (!g_file_equal (location, bookmark_location))
     {
+        char *bookmark_uri, *uri;
+
         bookmark_uri = g_file_get_uri (bookmark_location);
         uri = g_file_get_uri (location);
         g_warning ("bookmark uri is %s, but expected %s", bookmark_uri, uri);
@@ -191,7 +198,7 @@ handle_go_back (CajaNavigationWindowSlot *navigation_slot,
     CajaWindowSlot *slot;
     guint i;
     GList *link;
-    CajaBookmark *bookmark;
+    CajaBookmark *bookmark = NULL;
 
     slot = CAJA_WINDOW_SLOT (navigation_slot);
 
@@ -235,7 +242,7 @@ handle_go_forward (CajaNavigationWindowSlot *navigation_slot,
     CajaWindowSlot *slot;
     guint i;
     GList *link;
-    CajaBookmark *bookmark;
+    CajaBookmark *bookmark = NULL;
 
     slot = CAJA_WINDOW_SLOT (navigation_slot);
 
@@ -274,11 +281,10 @@ handle_go_forward (CajaNavigationWindowSlot *navigation_slot,
 static void
 handle_go_elsewhere (CajaWindowSlot *slot, GFile *location)
 {
-#if !NEW_UI_COMPLETE
-    CajaNavigationWindowSlot *navigation_slot;
-
     if (CAJA_IS_NAVIGATION_WINDOW_SLOT (slot))
     {
+        CajaNavigationWindowSlot *navigation_slot;
+
         navigation_slot = CAJA_NAVIGATION_WINDOW_SLOT (slot);
 
         /* Clobber the entire forward list, and move displayed location to back list */
@@ -301,7 +307,6 @@ handle_go_elsewhere (CajaWindowSlot *slot, GFile *location)
             }
         }
     }
-#endif
 }
 
 void
@@ -523,7 +528,6 @@ caja_window_slot_open_location_full (CajaWindowSlot *slot,
     gboolean existing = FALSE;
     GFile *old_location;
     char *old_uri, *new_uri;
-    int new_slot_position;
     GList *l;
     gboolean target_navigation = FALSE;
     gboolean target_same = FALSE;
@@ -638,6 +642,8 @@ caja_window_slot_open_location_full (CajaWindowSlot *slot,
     {
         g_assert (target_window == window);
 
+        int new_slot_position;
+
         slot_flags = 0;
 
         new_slot_position = g_settings_get_enum (caja_preferences, CAJA_PREFERENCES_NEW_TAB_POSITION);
@@ -773,18 +779,6 @@ caja_window_slot_go_home (CajaWindowSlot *slot, gboolean new_tab)
     g_object_unref (home);
 }
 
-#if 0
-static char *
-caja_window_slot_get_view_label (CajaWindowSlot *slot)
-{
-    const CajaViewInfo *info;
-
-    info = caja_view_factory_lookup (caja_window_slot_get_content_view_id (slot));
-
-    return g_strdup (info->label);
-}
-#endif
-
 static char *
 caja_window_slot_get_view_error_label (CajaWindowSlot *slot)
 {
@@ -907,10 +901,7 @@ begin_location_change (CajaWindowSlot *slot,
 {
     CajaWindow *window;
     CajaDirectory *directory;
-    CajaFile *file;
     gboolean force_reload;
-    char *current_pos;
-    GFile *from_folder;
     GFile *parent;
 
     g_assert (slot != NULL);
@@ -924,6 +915,8 @@ begin_location_change (CajaWindowSlot *slot,
      * select the folder the previous location was in */
     if (new_selection == NULL && previous_location != NULL &&
         g_file_has_prefix (previous_location, location)) {
+        GFile *from_folder;
+
         from_folder = g_object_ref (previous_location);
         parent = g_file_get_parent (from_folder);
         while (parent != NULL && !g_file_equal (parent, location)) {
@@ -954,7 +947,7 @@ begin_location_change (CajaWindowSlot *slot,
     slot->location_change_type = type;
     slot->location_change_distance = distance;
     slot->tried_mount = FALSE;
-    slot->pending_selection = eel_g_object_list_copy (new_selection);
+    slot->pending_selection = g_list_copy_deep (new_selection, (GCopyFunc) g_object_ref, NULL);
 
     slot->pending_scroll_to = g_strdup (scroll_pos);
 
@@ -982,6 +975,8 @@ begin_location_change (CajaWindowSlot *slot,
 
     if (force_reload)
     {
+        CajaFile *file;
+
         caja_directory_force_reload (directory);
         file = caja_directory_get_corresponding_file (directory);
         caja_file_invalidate_all_attributes (file);
@@ -994,6 +989,8 @@ begin_location_change (CajaWindowSlot *slot,
     if (slot->current_location_bookmark != NULL &&
             slot->content_view != NULL)
     {
+        char *current_pos;
+
         current_pos = caja_view_get_first_visible_file (slot->content_view);
         caja_bookmark_set_scroll_pos (slot->current_location_bookmark, current_pos);
         g_free (current_pos);
@@ -1021,22 +1018,24 @@ static void
 setup_new_spatial_window (CajaWindowSlot *slot, CajaFile *file)
 {
     CajaWindow *window;
-    char *show_hidden_file_setting;
-    char *geometry_string;
     char *scroll_string;
     gboolean maximized, sticky, above;
-    GtkAction *action;
 
     window = slot->pane->window;
 
     if (CAJA_IS_SPATIAL_WINDOW (window) && !CAJA_IS_DESKTOP_WINDOW (window))
     {
+        char *show_hidden_file_setting;
+        char *geometry_string;
+
         /* load show hidden state */
         show_hidden_file_setting = caja_file_get_metadata
                                    (file, CAJA_METADATA_KEY_WINDOW_SHOW_HIDDEN_FILES,
                                     NULL);
         if (show_hidden_file_setting != NULL)
         {
+            GtkAction *action;
+
             if (strcmp (show_hidden_file_setting, "1") == 0)
             {
                 window->details->show_hidden_files_mode = CAJA_WINDOW_SHOW_HIDDEN_FILES_ENABLE;
@@ -1046,12 +1045,14 @@ setup_new_spatial_window (CajaWindowSlot *slot, CajaFile *file)
                 window->details->show_hidden_files_mode = CAJA_WINDOW_SHOW_HIDDEN_FILES_DISABLE;
             }
 
+            G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
             /* Update the UI, since we initialize it to the default */
             action = gtk_action_group_get_action (window->details->main_action_group, CAJA_ACTION_SHOW_HIDDEN_FILES);
             gtk_action_block_activate (action);
             gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action),
                                           window->details->show_hidden_files_mode == CAJA_WINDOW_SHOW_HIDDEN_FILES_ENABLE);
             gtk_action_unblock_activate (action);
+            G_GNUC_END_IGNORE_DEPRECATIONS;
         }
         else
         {
@@ -1186,14 +1187,10 @@ got_file_info_for_view_selection_callback (CajaFile *file,
 {
     GError *error;
     char *view_id;
-    char *mimetype;
     CajaWindow *window;
     CajaWindowSlot *slot;
-    CajaFile *viewed_file;
     GFile *location;
-    GMountOperation *mount_op;
     MountNotMountedData *data;
-    CajaApplication *app;
     slot = callback_data;
     g_assert (CAJA_IS_WINDOW_SLOT (slot));
     g_assert (slot->determine_view_file == file);
@@ -1215,6 +1212,8 @@ got_file_info_for_view_selection_callback (CajaFile *file,
     if (error && error->domain == G_IO_ERROR && error->code == G_IO_ERROR_NOT_MOUNTED &&
             !slot->tried_mount)
     {
+        GMountOperation *mount_op;
+
         slot->tried_mount = TRUE;
 
         mount_op = gtk_mount_operation_new (GTK_WINDOW (window));
@@ -1241,6 +1240,8 @@ got_file_info_for_view_selection_callback (CajaFile *file,
     if (error == NULL ||
             (error->domain == G_IO_ERROR && error->code == G_IO_ERROR_NOT_SUPPORTED))
     {
+        char *mimetype;
+
         /* We got the information we need, now pick what view to use: */
 
         mimetype = caja_file_get_mime_type (file);
@@ -1265,7 +1266,20 @@ got_file_info_for_view_selection_callback (CajaFile *file,
         /* Otherwise, use default */
         if (view_id == NULL)
         {
-            view_id = caja_global_preferences_get_default_folder_viewer_preference_as_iid ();
+            char *uri;
+            uri = caja_file_get_uri (file);
+
+            /* Use same view settings for search results as the current folder */
+            if (eel_uri_is_search (uri))
+            {
+                view_id = g_strdup (caja_view_get_view_id (slot->content_view));
+            }
+            else
+            {
+                view_id = caja_global_preferences_get_default_folder_viewer_preference_as_iid ();
+            }
+
+            g_free (uri);
 
             if (view_id != NULL &&
                     !caja_view_factory_view_supports_uri (view_id,
@@ -1295,19 +1309,21 @@ got_file_info_for_view_selection_callback (CajaFile *file,
     }
     else
     {
-    	if (!report_callback (slot, error)) {
-        	display_view_selection_failure (window, file,
-                	                        location, error);
+        if (!report_callback (slot, error)) {
+            display_view_selection_failure (window, file,
+                                            location, error);
         }
 
         if (!gtk_widget_get_visible (GTK_WIDGET (window)))
         {
+            CajaApplication *app;
+
             /* Destroy never-had-a-chance-to-be-seen window. This case
              * happens when a new window cannot display its initial URI.
              */
             /* if this is the only window, we don't want to quit, so we redirect it to home */
             app = CAJA_APPLICATION (g_application_get_default ());
-			
+
             if (g_list_length (gtk_application_get_windows (GTK_APPLICATION (app))) == 1) {
 
                 /* the user could have typed in a home directory that doesn't exist,
@@ -1358,6 +1374,8 @@ got_file_info_for_view_selection_callback (CajaFile *file,
             }
             else
             {
+                CajaFile *viewed_file;
+
                 /* We disconnected this, so we need to re-connect it */
                 viewed_file = caja_file_get (slot->location);
                 caja_window_slot_set_viewed_file (slot, viewed_file);
@@ -1480,7 +1498,7 @@ load_new_location (CajaWindowSlot *slot,
     window = slot->pane->window;
     g_assert (CAJA_IS_WINDOW (window));
 
-    selection_copy = eel_g_object_list_copy (selection);
+    selection_copy = g_list_copy_deep (selection, (GCopyFunc) g_object_ref, NULL);
 
     view = NULL;
 
@@ -1591,13 +1609,14 @@ static void
 location_has_really_changed (CajaWindowSlot *slot)
 {
     CajaWindow *window;
-    GtkWidget *widget;
     GFile *location_copy;
 
     window = slot->pane->window;
 
     if (slot->new_content_view != NULL)
     {
+        GtkWidget *widget;
+
         widget = caja_view_get_widget (slot->new_content_view);
         /* Switch to the new content view. */
         if (gtk_widget_get_parent (widget) == NULL)
@@ -1641,8 +1660,8 @@ static void
 slot_add_extension_extra_widgets (CajaWindowSlot *slot)
 {
     GList *providers, *l;
-    GtkWidget *widget;
     char *uri;
+    GtkWidget *widget = NULL;
 
     providers = caja_extensions_get_for_type (CAJA_TYPE_LOCATION_WIDGET_PROVIDER);
 
@@ -1783,7 +1802,6 @@ update_for_new_location (CajaWindowSlot *slot)
     CajaWindow *window;
     GFile *new_location;
     CajaFile *file;
-    CajaDirectory *directory;
     gboolean location_really_changed;
     FindMountData *data;
 
@@ -1836,6 +1854,8 @@ update_for_new_location (CajaWindowSlot *slot)
 
     if (location_really_changed)
     {
+        CajaDirectory *directory;
+
         caja_window_slot_remove_extra_location_widgets (slot);
 
         directory = caja_directory_get (slot->location);
@@ -1999,12 +2019,11 @@ free_location_change (CajaWindowSlot *slot)
 static void
 cancel_location_change (CajaWindowSlot *slot)
 {
-    GList *selection;
-
     if (slot->pending_location != NULL
             && slot->location != NULL
             && slot->content_view != NULL)
     {
+        GList *selection;
 
         /* No need to tell the new view - either it is the
          * same as the old view, in which case it will already
@@ -2287,7 +2306,6 @@ caja_navigation_window_back_or_forward (CajaNavigationWindow *window,
     CajaNavigationWindowSlot *navigation_slot;
     GList *list;
     GFile *location;
-    GFile *old_location;
     guint len;
     CajaBookmark *bookmark;
 
@@ -2318,6 +2336,7 @@ caja_navigation_window_back_or_forward (CajaNavigationWindow *window,
     }
     else
     {
+        GFile *old_location;
         char *scroll_pos;
 
         old_location = caja_window_slot_get_location (slot);
