@@ -21,24 +21,20 @@
 
    Author: Christian Neumair <cneumair@gnome.org>
 */
-#include "caja-window-slot.h"
-#include "caja-navigation-window-slot.h"
 
-#include "caja-desktop-window.h"
-#include "caja-window-private.h"
-#include "caja-window-manage-views.h"
-#include <libcaja-private/caja-file.h>
-#include <libcaja-private/caja-file-utilities.h>
-#include <libcaja-private/caja-window-slot-info.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-string.h>
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
-#endif
+#include <libcaja-private/caja-file.h>
+#include <libcaja-private/caja-file-utilities.h>
+#include <libcaja-private/caja-window-slot-info.h>
+
+#include "caja-window-slot.h"
+#include "caja-navigation-window-slot.h"
+#include "caja-desktop-window.h"
+#include "caja-window-private.h"
+#include "caja-window-manage-views.h"
 
-static void caja_window_slot_init       (CajaWindowSlot *slot);
-static void caja_window_slot_class_init (CajaWindowSlotClass *class);
 static void caja_window_slot_dispose    (GObject *object);
 
 static void caja_window_slot_info_iface_init (CajaWindowSlotInfoIface *iface);
@@ -48,6 +44,7 @@ G_DEFINE_TYPE_WITH_CODE (CajaWindowSlot,
                          G_TYPE_OBJECT,
                          G_IMPLEMENT_INTERFACE (CAJA_TYPE_WINDOW_SLOT_INFO,
                                  caja_window_slot_info_iface_init))
+
 #define parent_class caja_window_slot_parent_class
 
 static void
@@ -74,15 +71,16 @@ query_editor_changed_callback (CajaSearchBar *bar,
 static void
 real_update_query_editor (CajaWindowSlot *slot)
 {
-    GtkWidget *query_editor;
-    CajaQuery *query;
     CajaDirectory *directory;
-    CajaSearchDirectory *search_directory;
 
     directory = caja_directory_get (slot->location);
 
     if (CAJA_IS_SEARCH_DIRECTORY (directory))
     {
+        GtkWidget *query_editor;
+        CajaQuery *query;
+        CajaSearchDirectory *search_directory;
+
         search_directory = CAJA_SEARCH_DIRECTORY (directory);
 
         query_editor = caja_query_editor_new (caja_search_directory_is_saved_search (search_directory),
@@ -184,7 +182,7 @@ caja_window_slot_init (CajaWindowSlot *slot)
 {
     GtkWidget *content_box, *eventbox, *extras_vbox, *frame;
 
-    content_box = gtk_vbox_new (FALSE, 0);
+    content_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     slot->content_box = content_box;
     gtk_widget_show (content_box);
 
@@ -198,13 +196,13 @@ caja_window_slot_init (CajaWindowSlot *slot)
     gtk_container_add (GTK_CONTAINER (frame), eventbox);
     gtk_widget_show (eventbox);
 
-    extras_vbox = gtk_vbox_new (FALSE, 6);
+    extras_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
     gtk_container_set_border_width (GTK_CONTAINER (extras_vbox), 6);
     slot->extra_location_widgets = extras_vbox;
     gtk_container_add (GTK_CONTAINER (eventbox), extras_vbox);
     gtk_widget_show (extras_vbox);
 
-    slot->view_box = gtk_vbox_new (FALSE, 0);
+    slot->view_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_box_pack_start (GTK_BOX (content_box), slot->view_box, TRUE, TRUE, 0);
     gtk_widget_show (slot->view_box);
 
@@ -372,7 +370,6 @@ caja_window_slot_update_icon (CajaWindowSlot *slot)
     CajaWindow *window;
     CajaIconInfo *info;
     const char *icon_name;
-    GdkPixbuf *pixbuf;
 
     window = slot->pane->window;
 
@@ -381,6 +378,9 @@ caja_window_slot_update_icon (CajaWindowSlot *slot)
     info = EEL_CALL_METHOD_WITH_RETURN_VALUE (CAJA_WINDOW_CLASS, window,
             get_icon, (window, slot));
 
+    if (slot != slot->pane->active_slot)
+        return;
+
     icon_name = NULL;
     if (info)
     {
@@ -393,11 +393,16 @@ caja_window_slot_update_icon (CajaWindowSlot *slot)
              */
             if (g_strcmp0 (icon_name, gtk_window_get_icon_name (GTK_WINDOW (window))) != 0)
             {
-                gtk_window_set_icon_name (GTK_WINDOW (window), icon_name);
+                if (g_strcmp0 (icon_name, "text-x-generic") == 0)
+                    gtk_window_set_icon_name (GTK_WINDOW (window), "folder-saved-search");
+                else
+                    gtk_window_set_icon_name (GTK_WINDOW (window), icon_name);
             }
         }
         else
         {
+            GdkPixbuf *pixbuf;
+
             pixbuf = caja_icon_info_get_pixbuf_nodefault (info);
 
             if (pixbuf)
@@ -483,13 +488,8 @@ caja_window_slot_set_content_view_widget (CajaWindowSlot *slot,
     if (new_view != NULL)
     {
         widget = caja_view_get_widget (new_view);
-#if GTK_CHECK_VERSION (3, 0, 0)
         gtk_box_pack_start (GTK_BOX (slot->view_box), widget,
                             TRUE, TRUE, 0);
-#else
-        gtk_container_add (GTK_CONTAINER (slot->view_box),
-                           GTK_WIDGET (new_view));
-#endif
 
         gtk_widget_show (widget);
 
