@@ -28,22 +28,25 @@
  */
 
 #include <config.h>
-#include "caja-zoom-control.h"
+#include <math.h>
+#include <stdlib.h>
+#include <string.h>
 
 #include <atk/atkaction.h>
 #include <glib/gi18n.h>
+#include <gtk/gtk.h>
+#include <gtk/gtk-a11y.h>
+#include <gdk/gdkkeysyms.h>
+
 #include <eel/eel-accessibility.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-graphic-effects.h>
 #include <eel/eel-gtk-extensions.h>
-#include <gtk/gtk.h>
-#include <gtk/gtk-a11y.h>
-#include <gdk/gdkkeysyms.h>
+
 #include <libcaja-private/caja-file-utilities.h>
 #include <libcaja-private/caja-global-preferences.h>
-#include <math.h>
-#include <stdlib.h>
-#include <string.h>
+
+#include "caja-zoom-control.h"
 
 enum
 {
@@ -55,7 +58,7 @@ enum
     LAST_SIGNAL
 };
 
-struct CajaZoomControlDetails
+struct _CajaZoomControlPrivate
 {
     GtkWidget *zoom_in;
     GtkWidget *zoom_out;
@@ -107,7 +110,7 @@ static GType caja_zoom_control_accessible_get_type (void);
 
 #define NUM_ACTIONS ((int)G_N_ELEMENTS (caja_zoom_control_accessible_action_names))
 
-G_DEFINE_TYPE (CajaZoomControl, caja_zoom_control, GTK_TYPE_BOX);
+G_DEFINE_TYPE_WITH_PRIVATE (CajaZoomControl, caja_zoom_control, GTK_TYPE_BOX);
 
 static void
 caja_zoom_control_finalize (GObject *object)
@@ -230,7 +233,7 @@ caja_zoom_control_init (CajaZoomControl *zoom_control)
     GtkWidget *image;
     int i;
 
-    zoom_control->details = G_TYPE_INSTANCE_GET_PRIVATE (zoom_control, CAJA_TYPE_ZOOM_CONTROL, CajaZoomControlDetails);
+    zoom_control->details = caja_zoom_control_get_instance_private (zoom_control);
 
     zoom_control->details->zoom_level = CAJA_ZOOM_LEVEL_STANDARD;
     zoom_control->details->min_zoom_level = CAJA_ZOOM_LEVEL_SMALLEST;
@@ -648,7 +651,7 @@ caja_zoom_control_class_init (CajaZoomControlClass *class)
     binding_set = gtk_binding_set_by_class (class);
 
     gtk_binding_entry_add_signal (binding_set,
-				      GDK_KEY_KP_Subtract, 0, 
+				      GDK_KEY_KP_Subtract, 0,
                                   "change_value",
                                   1, GTK_TYPE_SCROLL_TYPE,
                                   GTK_SCROLL_STEP_DOWN);
@@ -659,26 +662,24 @@ caja_zoom_control_class_init (CajaZoomControlClass *class)
                                   GTK_SCROLL_STEP_DOWN);
 
     gtk_binding_entry_add_signal (binding_set,
-				      GDK_KEY_KP_Equal, 0, 
+				      GDK_KEY_KP_Equal, 0,
                                   "zoom_to_default",
                                   0);
     gtk_binding_entry_add_signal (binding_set,
-				      GDK_KEY_KP_Equal, 0, 
+				      GDK_KEY_KP_Equal, 0,
                                   "zoom_to_default",
                                   0);
 
     gtk_binding_entry_add_signal (binding_set,
-				      GDK_KEY_KP_Add, 0, 
+				      GDK_KEY_KP_Add, 0,
                                   "change_value",
                                   1, GTK_TYPE_SCROLL_TYPE,
                                   GTK_SCROLL_STEP_UP);
     gtk_binding_entry_add_signal (binding_set,
-				      GDK_KEY_plus, 0, 
+				      GDK_KEY_plus, 0,
                                   "change_value",
                                   1, GTK_TYPE_SCROLL_TYPE,
                                   GTK_SCROLL_STEP_UP);
-
-    g_type_class_add_private (G_OBJECT_CLASS (class), sizeof (CajaZoomControlDetails));
 }
 
 static gboolean
