@@ -25,18 +25,24 @@
 */
 
 #include <config.h>
-#include "fm-icon-container.h"
-#include "fm-desktop-icon-view.h"
-#include "fm-actions.h"
+#include <fcntl.h>
+#include <limits.h>
+#include <stddef.h>
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
 
 #include <X11/Xatom.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkx.h>
+#include <glib/gi18n.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-vfs-extensions.h>
-#include <fcntl.h>
-#include <gdk/gdkx.h>
-#include <glib/gi18n.h>
+
 #include <libcaja-private/caja-desktop-icon-file.h>
 #include <libcaja-private/caja-directory-background.h>
 #include <libcaja-private/caja-directory-notify.h>
@@ -51,18 +57,15 @@
 #include <libcaja-private/caja-monitor.h>
 #include <libcaja-private/caja-program-choosing.h>
 #include <libcaja-private/caja-trash-monitor.h>
-#include <limits.h>
-#include <stddef.h>
-#include <stdio.h>
-#include <string.h>
-#include <sys/stat.h>
-#include <sys/types.h>
-#include <unistd.h>
+
+#include "fm-icon-container.h"
+#include "fm-desktop-icon-view.h"
+#include "fm-actions.h"
 
 /* Timeout to check the desktop directory for updates */
 #define RESCAN_TIMEOUT 4
 
-struct FMDesktopIconViewDetails
+struct _FMDesktopIconViewPrivate
 {
     GdkWindow *root_window;
     GtkActionGroup *desktop_action_group;
@@ -86,7 +89,7 @@ static gboolean real_supports_zooming                             (FMDirectoryVi
 static void     fm_desktop_icon_view_update_icon_container_fonts  (FMDesktopIconView      *view);
 static void     font_changed_callback                             (gpointer                callback_data);
 
-G_DEFINE_TYPE (FMDesktopIconView, fm_desktop_icon_view, FM_TYPE_ICON_VIEW)
+G_DEFINE_TYPE_WITH_PRIVATE (FMDesktopIconView, fm_desktop_icon_view, FM_TYPE_ICON_VIEW)
 
 static char *desktop_directory;
 static time_t desktop_dir_modify_time;
@@ -156,7 +159,6 @@ net_workarea_changed (FMDesktopIconView *icon_view,
     int format_returned;
     int length_returned;
     CajaIconContainer *icon_container;
-    GdkScreen *screen;
 
     g_return_if_fail (FM_IS_DESKTOP_ICON_VIEW (icon_view));
 
@@ -222,6 +224,8 @@ net_workarea_changed (FMDesktopIconView *icon_view,
     }
     else
     {
+        GdkScreen *screen;
+
         screen = gdk_window_get_screen (window);
 
         icon_container_set_workarea (
@@ -267,24 +271,24 @@ fm_desktop_icon_view_dispose (GObject *object)
     icon_view = FM_DESKTOP_ICON_VIEW (object);
 
     /* Remove desktop rescan timeout. */
-    if (icon_view->details->reload_desktop_timeout != 0)
+    if (icon_view->priv->reload_desktop_timeout != 0)
     {
-        g_source_remove (icon_view->details->reload_desktop_timeout);
-        icon_view->details->reload_desktop_timeout = 0;
+        g_source_remove (icon_view->priv->reload_desktop_timeout);
+        icon_view->priv->reload_desktop_timeout = 0;
     }
 
     ui_manager = fm_directory_view_get_ui_manager (FM_DIRECTORY_VIEW (icon_view));
     if (ui_manager != NULL)
     {
         caja_ui_unmerge_ui (ui_manager,
-                            &icon_view->details->desktop_merge_id,
-                            &icon_view->details->desktop_action_group);
+                            &icon_view->priv->desktop_merge_id,
+                            &icon_view->priv->desktop_action_group);
     }
 
     g_signal_handlers_disconnect_by_func (caja_icon_view_preferences,
                                           default_zoom_level_changed,
                                           icon_view);
-    g_signal_handlers_disconnect_by_func (caja_preferences,
+    g_signal_handlers_disconnect_by_func (caja_desktop_preferences,
                                           font_changed_callback,
                                           icon_view);
 
@@ -311,8 +315,6 @@ fm_desktop_icon_view_class_init (FMDesktopIconViewClass *class)
     FM_ICON_VIEW_CLASS (class)->supports_scaling = real_supports_scaling;
     FM_ICON_VIEW_CLASS (class)->supports_keep_aligned = real_supports_keep_aligned;
     FM_ICON_VIEW_CLASS (class)->supports_labels_beside_icons = real_supports_labels_beside_icons;
-
-    g_type_class_add_private (class, sizeof (FMDesktopIconViewDetails));
 }
 
 static void
@@ -321,7 +323,7 @@ fm_desktop_icon_view_handle_middle_click (CajaIconContainer *icon_container,
         FMDesktopIconView *desktop_icon_view)
 {
     XButtonEvent x_event;
-    GdkDevice *keyboard = NULL, *pointer = NULL, *cur;
+    GdkDevice *keyboard = NULL, *pointer = NULL;
     GdkSeat *seat;
     GdkDisplay *display;
 
@@ -329,16 +331,6 @@ fm_desktop_icon_view_handle_middle_click (CajaIconContainer *icon_container,
     pointer = gdk_seat_get_pointer (seat);
     keyboard = gdk_seat_get_keyboard (seat);
 
-    {
-        if (pointer == NULL && (gdk_device_get_source (cur) == GDK_SOURCE_MOUSE)) {
-                pointer = cur;
-        }
-
-        if (keyboard == NULL && (gdk_device_get_source (cur) == GDK_SOURCE_KEYBOARD)) {
-                keyboard = cur;
-        }
-    }
-
     /* During a mouse click we have the pointer and keyboard grab.
      * We will send a fake event to the root window which will cause it
      * to try to get the grab so we need to let go ourselves.
@@ -381,13 +373,13 @@ fm_desktop_icon_view_handle_middle_click (CajaIconContainer *icon_container,
 static void
 unrealized_callback (GtkWidget *widget, FMDesktopIconView *desktop_icon_view)
 {
-    g_return_if_fail (desktop_icon_view->details->root_window != NULL);
+    g_return_if_fail (desktop_icon_view->priv->root_window != NULL);
 
     /* Remove the property filter */
-    gdk_window_remove_filter (desktop_icon_view->details->root_window,
+    gdk_window_remove_filter (desktop_icon_view->priv->root_window,
                               desktop_icon_view_property_filter,
                               desktop_icon_view);
-    desktop_icon_view->details->root_window = NULL;
+    desktop_icon_view->priv->root_window = NULL;
 }
 
 static void
@@ -398,7 +390,7 @@ realized_callback (GtkWidget *widget, FMDesktopIconView *desktop_icon_view)
     GtkAllocation allocation;
     gint scale;
 
-    g_return_if_fail (desktop_icon_view->details->root_window == NULL);
+    g_return_if_fail (desktop_icon_view->priv->root_window == NULL);
 
     screen = gtk_widget_get_screen (widget);
     scale = gtk_widget_get_scale_factor (widget);
@@ -418,7 +410,7 @@ realized_callback (GtkWidget *widget, FMDesktopIconView *desktop_icon_view)
 
     root_window = gdk_screen_get_root_window (screen);
 
-    desktop_icon_view->details->root_window = root_window;
+    desktop_icon_view->priv->root_window = root_window;
 
     /* Read out the workarea geometry and update the icon container accordingly */
     net_workarea_changed (desktop_icon_view, root_window);
@@ -468,7 +460,7 @@ do_desktop_rescan (gpointer data)
     struct stat buf;
 
     desktop_icon_view = FM_DESKTOP_ICON_VIEW (data);
-    if (desktop_icon_view->details->pending_rescan)
+    if (desktop_icon_view->priv->pending_rescan)
     {
         return TRUE;
     }
@@ -483,7 +475,7 @@ do_desktop_rescan (gpointer data)
         return TRUE;
     }
 
-    desktop_icon_view->details->pending_rescan = TRUE;
+    desktop_icon_view->priv->pending_rescan = TRUE;
 
     caja_directory_force_reload (
         fm_directory_view_get_model (
@@ -497,7 +489,7 @@ done_loading (CajaDirectory *model,
 {
     struct stat buf;
 
-    desktop_icon_view->details->pending_rescan = FALSE;
+    desktop_icon_view->priv->pending_rescan = FALSE;
     if (stat (desktop_directory, &buf) == -1)
     {
         return;
@@ -519,13 +511,13 @@ delayed_init (FMDesktopIconView *desktop_icon_view)
                              G_CALLBACK (done_loading), desktop_icon_view, 0);
 
     /* Monitor desktop directory. */
-    desktop_icon_view->details->reload_desktop_timeout =
+    desktop_icon_view->priv->reload_desktop_timeout =
         g_timeout_add_seconds (RESCAN_TIMEOUT, do_desktop_rescan, desktop_icon_view);
 
     g_signal_handler_disconnect (desktop_icon_view,
-                                 desktop_icon_view->details->delayed_init_signal);
+                                 desktop_icon_view->priv->delayed_init_signal);
 
-    desktop_icon_view->details->delayed_init_signal = 0;
+    desktop_icon_view->priv->delayed_init_signal = 0;
 }
 
 static void
@@ -559,9 +551,7 @@ fm_desktop_icon_view_init (FMDesktopIconView *desktop_icon_view)
     GtkAllocation allocation;
     GtkAdjustment *hadj, *vadj;
 
-    desktop_icon_view->details = G_TYPE_INSTANCE_GET_PRIVATE (desktop_icon_view,
-    							      FM_TYPE_DESKTOP_ICON_VIEW,
-    							      FMDesktopIconViewDetails);
+    desktop_icon_view->priv = fm_desktop_icon_view_get_instance_private (desktop_icon_view);
 
     if (desktop_directory == NULL)
     {
@@ -581,7 +571,7 @@ fm_desktop_icon_view_init (FMDesktopIconView *desktop_icon_view)
      */
     if (!caja_monitor_active ())
     {
-        desktop_icon_view->details->delayed_init_signal = g_signal_connect_object
+        desktop_icon_view->priv->delayed_init_signal = g_signal_connect_object
                 (desktop_icon_view, "begin_loading",
                  G_CALLBACK (delayed_init), desktop_icon_view, 0);
     }
@@ -692,7 +682,6 @@ static gboolean
 trash_link_is_selection (FMDirectoryView *view)
 {
     GList *selection;
-    CajaDesktopLink *link;
     gboolean result;
 
     result = FALSE;
@@ -702,6 +691,8 @@ trash_link_is_selection (FMDirectoryView *view)
     if (eel_g_list_exactly_one_item (selection) &&
             CAJA_IS_DESKTOP_ICON_FILE (selection->data))
     {
+        CajaDesktopLink *link;
+
         link = caja_desktop_icon_file_get_link (CAJA_DESKTOP_ICON_FILE (selection->data));
         /* link may be NULL if the link was recently removed (unmounted) */
         if (link != NULL &&
@@ -724,7 +715,6 @@ static void
 real_update_menus (FMDirectoryView *view)
 {
     FMDesktopIconView *desktop_view;
-    char *label;
     gboolean disable_command_line;
     gboolean include_empty_trash;
     GtkAction *action;
@@ -737,23 +727,31 @@ real_update_menus (FMDirectoryView *view)
 
     /* New Launcher */
     disable_command_line = g_settings_get_boolean (mate_lockdown_preferences, CAJA_PREFERENCES_LOCKDOWN_COMMAND_LINE);
-    action = gtk_action_group_get_action (desktop_view->details->desktop_action_group,
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
+    action = gtk_action_group_get_action (desktop_view->priv->desktop_action_group,
                                           FM_ACTION_NEW_LAUNCHER_DESKTOP);
     gtk_action_set_visible (action,
                             !disable_command_line);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
 
     /* Empty Trash */
     include_empty_trash = trash_link_is_selection (view);
-    action = gtk_action_group_get_action (desktop_view->details->desktop_action_group,
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
+    action = gtk_action_group_get_action (desktop_view->priv->desktop_action_group,
                                           FM_ACTION_EMPTY_TRASH_CONDITIONAL);
     gtk_action_set_visible (action,
                             include_empty_trash);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
     if (include_empty_trash)
     {
+        char *label;
+
         label = g_strdup (_("E_mpty Trash"));
         g_object_set (action , "label", label, NULL);
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
         gtk_action_set_sensitive (action,
                                   !caja_trash_monitor_is_empty ());
+        G_GNUC_END_IGNORE_DEPRECATIONS;
         g_free (label);
     }
 }
@@ -803,18 +801,21 @@ real_merge_menus (FMDirectoryView *view)
 
     ui_manager = fm_directory_view_get_ui_manager (view);
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
     action_group = gtk_action_group_new ("DesktopViewActions");
     gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
-    desktop_view->details->desktop_action_group = action_group;
+    desktop_view->priv->desktop_action_group = action_group;
     gtk_action_group_add_actions (action_group,
                                   desktop_view_entries, G_N_ELEMENTS (desktop_view_entries),
                                   view);
+    G_GNUC_END_IGNORE_DEPRECATIONS;
+
 
     gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
     g_object_unref (action_group); /* owned by ui manager */
 
     ui = caja_ui_string_get ("caja-desktop-icon-view-ui.xml");
-    desktop_view->details->desktop_merge_id =
+    desktop_view->priv->desktop_merge_id =
         gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, NULL);
 }
 
@@ -881,14 +882,14 @@ fm_desktop_icon_view_supports_uri (const char *uri,
 
 static CajaViewInfo fm_desktop_icon_view =
 {
-    FM_DESKTOP_ICON_VIEW_ID,
-    "Desktop View",
-    "_Desktop",
-    N_("The desktop view encountered an error."),
-    N_("The desktop view encountered an error while starting up."),
-    "Display this location with the desktop view.",
-    fm_desktop_icon_view_create,
-    fm_desktop_icon_view_supports_uri
+    .id = FM_DESKTOP_ICON_VIEW_ID,
+    .view_combo_label = N_("Desktop View"),
+    .view_menu_label_with_mnemonic = N_("_Desktop"),
+    .error_label = N_("The desktop view encountered an error."),
+    .startup_error_label = N_("The desktop view encountered an error while starting up."),
+    .display_location_label = N_("Display this location with the desktop view."),
+    .create = fm_desktop_icon_view_create,
+    .supports_uri = fm_desktop_icon_view_supports_uri
 };
 
 void
