@@ -23,16 +23,19 @@
 */
 
 #include <config.h>
-#include "fm-empty-view.h"
-
 #include <string.h>
-#include <libcaja-private/caja-file-utilities.h>
-#include <libcaja-private/caja-view.h>
-#include <libcaja-private/caja-view-factory.h>
+#include <glib/gi18n.h>
+
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-vfs-extensions.h>
 
+#include <libcaja-private/caja-file-utilities.h>
+#include <libcaja-private/caja-view.h>
+#include <libcaja-private/caja-view-factory.h>
+
+#include "fm-empty-view.h"
+
 struct FMEmptyViewDetails
 {
     int number_of_files;
@@ -390,14 +393,14 @@ fm_empty_view_supports_uri (const char *uri,
 
 static CajaViewInfo fm_empty_view =
 {
-    FM_EMPTY_VIEW_ID,
-    "Empty",
-    "Empty View",
-    "_Empty View",
-    "The empty view encountered an error.",
-    "Display this location with the empty view.",
-    fm_empty_view_create,
-    fm_empty_view_supports_uri
+    .id = FM_EMPTY_VIEW_ID,
+    .view_combo_label = N_("Empty View"),
+    .view_menu_label_with_mnemonic = N_("_Empty"),
+    .error_label = N_("Empty View"),
+    .startup_error_label = N_("The empty view encountered an error."),
+    .display_location_label = N_("Display this location with the empty view."),
+    .create = fm_empty_view_create,
+    .supports_uri =fm_empty_view_supports_uri
 };
 
 void
